@@ -76,7 +76,7 @@ CDFid id;
 * Main.
 ******************************************************************************/
 
-int main () {
+int main (void) {
 /* CDFid id; */
 CDFstatus status;
 int dim_n;
@@ -1199,9 +1199,9 @@ return EXIT_SUCCESS_;
 * QuitCDF.
 ******************************************************************************/
 
-void QuitCDF (where, status)
-char *where;
-CDFstatus status;
+void QuitCDF (
+char *where,
+CDFstatus status)
 {
   char text[CDF_STATUSTEXT_LEN+1];
   printf ("Aborting at %s...\n", where);
