@@ -67,7 +67,7 @@ void QuitCDF PROTOARGs((char *where, CDFstatus status));
 * Main.
 ******************************************************************************/
 
-int main () {
+int main (void) {
 CDFid id;
 CDFstatus status;
 int dim_n;
@@ -224,6 +224,7 @@ status = CDFlib (CREATE_, zVAR_, zVarAname, zVarAdataType, zVarAnumElements,
 		 PUT_, zVAR_PADVALUE_, pad3,
                  NULL_);
 if (status < CDF_OK) QuitCDF ("2.0", status);
+
 status = CDFlib (SELECT_, CDF_, id,
 		          zVAR_, zVarAnum_out,
 		 GET_, zVAR_PADVALUE_, pad3out,
@@ -741,9 +742,9 @@ return EXIT_SUCCESS_;
 * QuitCDF.
 ******************************************************************************/
 
-void QuitCDF (where, status)
-char *where;
-CDFstatus status;
+void QuitCDF (
+char *where,
+CDFstatus status)
 {
   char text[CDF_STATUSTEXT_LEN+1];
   printf ("Program failed at %s...\n", where);
