@@ -31,6 +31,7 @@ C   V1.10  20-Dec-94, J Love	CDF V2.5.
 C   V1.11  28-Mar-95, J Love	Multi-file format.
 C   V1.11a 13-Jun-95, J Love	Linux.
 C   V1.12  20-May-96, J Love	CDF V2.6.
+C   V1.13   8-Sep-23, M Liu 	Changed from rVars to zVars.
 C
 C-----------------------------------------------------------------------
 
@@ -124,7 +125,7 @@ C-----------------------------------------------------------------------
 C Create CDF.
 C-----------------------------------------------------------------------
 
-        STATUS = CDF_LIB    (CREATE_, CDF_, CDFNAME, NUM_DIMS,
+        STATUS = CDF_LIB    (CREATE_, CDF_, CDFNAME, 0,
      .				            DIM_SIZES, ID,
 C    .		             PUT_, CDF_ENCODING_, ENCODING,
      .			     PUT_, CDF_MAJORITY_, MAJORITY,
@@ -139,7 +140,7 @@ C    .		             PUT_, CDF_ENCODING_, ENCODING,
      .			        NULL_, STATUS)
 	    IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '1.1')
 
-            STATUS = CDF_LIB    (CREATE_, CDF_, CDFNAME, NUM_DIMS,
+            STATUS = CDF_LIB    (CREATE_, CDF_, CDFNAME, 0,
      .					        DIM_SIZES, ID,
 C    .			         PUT_, CDF_ENCODING_, ENCODING,
      .				 PUT_, CDF_MAJORITY_, MAJORITY,
@@ -154,8 +155,10 @@ C-----------------------------------------------------------------------
 C Create variable.
 C-----------------------------------------------------------------------
 
-        STATUS = CDF_LIB    (CREATE_, rVAR_, VARNAME, VAR_DATA_TYPE,
+        STATUS = CDF_LIB    (CREATE_, zVAR_, VARNAME, VAR_DATA_TYPE,
      .				             VAR_NUM_ELEMENTS,
+     .				             NUM_DIMS,
+     .				             DIM_SIZES,
      .				             VAR_REC_VARIANCE,
      .				             VAR_DIM_VARIANCES,
      .				             VAR_NUM_OUT,
@@ -200,7 +203,7 @@ C-----------------------------------------------------------------------
 C Create CDF again (previous delete will allow this).
 C-----------------------------------------------------------------------
 
-        STATUS = CDF_LIB    (CREATE_, CDF_, CDFNAME, NUM_DIMS,
+        STATUS = CDF_LIB    (CREATE_, CDF_, CDFNAME, 0,
      .				            DIM_SIZES, ID,
 C    .		             PUT_, CDF_ENCODING_, ENCODING,
      .			     PUT_, CDF_MAJORITY_, MAJORITY,
@@ -221,22 +224,22 @@ C Inquire CDF.
 C-----------------------------------------------------------------------
 
         STATUS = CDF_LIB    (GET_, rVARs_NUMDIMS_, NUM_DIMS_OUT,
-     .			           rVARs_DIMSIZES_, DIM_SIZES_OUT,
+C    .			           zVARs_DIMSIZES_, DIM_SIZES_OUT,
      .			           CDF_ENCODING_, ENCODING_OUT,
      .			           CDF_MAJORITY_, MAJORITY_OUT,
-     .			           rVARs_MAXREC_, MAX_REC_OUT,
-     .			           CDF_NUMrVARS_, NUM_VARS_OUT,
+     .			           zVARs_MAXREC_, MAX_REC_OUT,
+     .			           CDF_NUMzVARS_, NUM_VARS_OUT,
      .			           CDF_NUMATTRS_, NUM_ATTRS_OUT,
      .		             NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '6a.0')
 
-	IF (NUM_DIMS_OUT .NE. NUM_DIMS)
+	IF (NUM_DIMS_OUT .NE. 0)
      .	  CALL QUIT_CDF (STATUS, '6a.1')
 
-	DO X = 1, 2
-	  IF (DIM_SIZES_OUT(X) .NE. DIM_SIZES(X))
-     .	    CALL QUIT_CDF (STATUS, '6a.2')
-	END DO
+C	DO X = 1, 2
+C	  IF (DIM_SIZES_OUT(X) .NE. DIM_SIZES(X))
+C     .	    CALL QUIT_CDF (STATUS, '6a.2')
+C	END DO
 
 C	IF (ENCODING_OUT .NE. ENCODING)
 C    .	  CALL QUIT_CDF (STATUS, '6a.3')
@@ -250,24 +253,30 @@ C-----------------------------------------------------------------------
 C Create variables.
 C-----------------------------------------------------------------------
 
-        STATUS = CDF_LIB    (CREATE_, rVAR_, VARNAME, VAR_DATA_TYPE,
+        STATUS = CDF_LIB    (CREATE_, zVAR_, VARNAME, VAR_DATA_TYPE,
      .				             VAR_NUM_ELEMENTS,
+     .				             NUM_DIMS,
+     .				             DIM_SIZES,
      .				             VAR_REC_VARIANCE,
      .				             VAR_DIM_VARIANCES,
      .				             VAR_NUM_OUT,
-     .			     PUT_, rVAR_COMPRESSION_, cType, cParms,
-     .			           rVAR_SPARSERECORDS_, sRecordsType,
-     .			           rVAR_SPARSEARRAYS_, sArraysType,
+     .			     PUT_, zVAR_COMPRESSION_, cType, cParms,
+     .			           zVAR_SPARSERECORDS_, sRecordsType,
+     .			           zVAR_SPARSEARRAYS_, sArraysType,
      .						       sArraysParms,
-     .			     SELECT_, rVAR_RESERVEPERCENT_, cReserve,
+     .			     SELECT_, zVAR_RESERVEPERCENT_, cReserve,
      .		             NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '7.0')
 
-        STATUS = CDF_LIB    (CREATE_, rVAR_, 'VAR2a', CDF_INT4, 1,
+        STATUS = CDF_LIB    (CREATE_, zVAR_, 'VAR2a', CDF_INT4, 1,
+     .				             NUM_DIMS,
+     .				             DIM_SIZES,
      .					     VAR_REC_VARIANCE,
      .					     VAR_DIM_VARIANCES,
      .					     varNums(1),
-     .			     CREATE_, rVAR_, 'VAR2b', CDF_INT4, 1,
+     .			     CREATE_, zVAR_, 'VAR2b', CDF_INT4, 1,
+     .				             NUM_DIMS,
+     .				             DIM_SIZES,
      .					     VAR_REC_VARIANCE,
      .					     VAR_DIM_VARIANCES,
      .					     varNums(2),
@@ -278,12 +287,12 @@ C-----------------------------------------------------------------------
 C Alocate/inquire records for a variable.
 C-----------------------------------------------------------------------
 
-        STATUS = CDF_LIB    (SELECT_, rVAR_, varNums(1),
-     .			     PUT_, rVAR_ALLOCATEBLOCK_, 1, 10,
-     .			     GET_, rVAR_NUMallocRECS_, nAllocOUT,
-     .			           rVAR_ALLOCATEDFROM_, 5, fromOUT,
-     .			           rVAR_ALLOCATEDTO_, 5, toOUT,
-     .			           rVAR_nINDEXLEVELS_, nLevelsOUT,
+        STATUS = CDF_LIB    (SELECT_, zVAR_, varNums(1),
+     .			     PUT_, zVAR_ALLOCATEBLOCK_, 1, 10,
+     .			     GET_, zVAR_NUMallocRECS_, nAllocOUT,
+     .			           zVAR_ALLOCATEDFROM_, 5, fromOUT,
+     .			           zVAR_ALLOCATEDTO_, 5, toOUT,
+     .			           zVAR_nINDEXLEVELS_, nLevelsOUT,
      .			     NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '7b.0')
 
@@ -301,11 +310,11 @@ C-----------------------------------------------------------------------
 C PUT to variable.
 C-----------------------------------------------------------------------
 
-        STATUS = CDF_LIB   (SELECT_, rVAR_, VAR_NUM_OUT,
+        STATUS = CDF_LIB   (SELECT_, zVAR_, VAR_NUM_OUT,
      .		            NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '8.0')
 
-        STATUS = CDF_LIB   (SELECT_, rVARs_RECNUMBER_, REC_NUM,
+        STATUS = CDF_LIB   (SELECT_, zVAR_RECNUMBER_, REC_NUM,
      .		            NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '8.0a')
 
@@ -313,8 +322,8 @@ C-----------------------------------------------------------------------
 	  DO X1 = 1, 2
 	    INDICES(1) = X1
 	    INDICES(2) = X2
-            STATUS = CDF_LIB   (SELECT_, rVARs_DIMINDICES_, INDICES,
-     .			        PUT_, rVAR_DATA_, VAR_VALUES(X1,X2),
+            STATUS = CDF_LIB   (SELECT_, zVAR_DIMINDICES_, INDICES,
+     .			        PUT_, zVAR_DATA_, VAR_VALUES(X1,X2),
      .			        NULL_, STATUS)
 	    IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '8.1')
 	  END DO
@@ -324,7 +333,7 @@ C-----------------------------------------------------------------------
 C GET from the variable.
 C-----------------------------------------------------------------------
 
-        STATUS = CDF_LIB   (SELECT_, rVARs_RECNUMBER_, REC_NUM,
+        STATUS = CDF_LIB   (SELECT_, zVAR_RECNUMBER_, REC_NUM,
      .		            NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '9.0')
 
@@ -332,8 +341,8 @@ C-----------------------------------------------------------------------
 	  DO X1 = 1, 2
 	    INDICES(1) = X1
 	    INDICES(2) = X2
-            STATUS = CDF_LIB   (SELECT_, rVARs_DIMINDICES_, INDICES,
-     .			        GET_, rVAR_DATA_, VAR_VALUE_OUT,
+            STATUS = CDF_LIB   (SELECT_, zVAR_DIMINDICES_, INDICES,
+     .			        GET_, zVAR_DATA_, VAR_VALUE_OUT,
      .			        NULL_, STATUS)
 	    IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '9.1')
 	    IF (VAR_VALUE_OUT .NE. VAR_VALUES(X1,X2)) THEN
@@ -358,16 +367,16 @@ C-----------------------------------------------------------------------
 	INDICES(1) = 1
 	INDICES(2) = 1
 
-        STATUS = CDF_LIB    (SELECT_, rVARs_RECNUMBER_, REC_START,
-     .			              rVARs_RECCOUNT_, REC_COUNT,
-     .			              rVARs_RECINTERVAL_, REC_INTERVAL,
-     .			              rVARs_DIMINDICES_, INDICES,
-     .			              rVARs_DIMCOUNTS_, COUNTS,
-     .			              rVARs_DIMINTERVALS_, INTERVALS,
+        STATUS = CDF_LIB    (SELECT_, zVAR_RECNUMBER_, REC_START,
+     .			              zVAR_RECCOUNT_, REC_COUNT,
+     .			              zVAR_RECINTERVAL_, REC_INTERVAL,
+     .			              zVAR_DIMINDICES_, INDICES,
+     .			              zVAR_DIMCOUNTS_, COUNTS,
+     .			              zVAR_DIMINTERVALS_, INTERVALS,
      .		             NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '10.0a')
 
-        STATUS = CDF_LIB   (PUT_, rVAR_HYPERDATA_, VAR_VALUES,
+        STATUS = CDF_LIB   (PUT_, zVAR_HYPERDATA_, VAR_VALUES,
      .		            NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '10.0b')
 
@@ -375,7 +384,7 @@ C-----------------------------------------------------------------------
 C HyperGET from variable.
 C-----------------------------------------------------------------------
 
-        STATUS = CDF_LIB   (GET_, rVAR_HYPERDATA_, VAR_BUFFER_OUT,
+        STATUS = CDF_LIB   (GET_, zVAR_HYPERDATA_, VAR_BUFFER_OUT,
      .		            NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '11.0')
 
@@ -390,12 +399,15 @@ C-----------------------------------------------------------------------
 C Confirm indices, counts, etc.
 C-----------------------------------------------------------------------
 
-        STATUS = CDF_LIB    (CONFIRM_, rVARs_RECNUMBER_, recnum_out,
-     .			               rVARs_RECCOUNT_, reccount_out,
-     .			               rVARs_RECINTERVAL_, recinterval_out,
-     .			               rVARs_DIMINDICES_, dimindices_out,
-     .			               rVARs_DIMCOUNTS_, dimcounts_out,
-     .			               rVARs_DIMINTERVALS_,dimintervals_out,
+        STATUS = CDF_LIB    (CONFIRM_, zVAR_RECNUMBER_, recnum_out,
+     .			               zVAR_RECCOUNT_, reccount_out,
+     .			               zVAR_RECINTERVAL_,
+     .			                                recinterval_out,
+     .			               zVAR_DIMINDICES_,
+     .			                                 dimindices_out,
+     .			               zVAR_DIMCOUNTS_, dimcounts_out,
+     .			               zVAR_DIMINTERVALS_,
+     .			                               dimintervals_out,
      .		             NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '10a.0')
 
@@ -432,19 +444,19 @@ C-----------------------------------------------------------------------
 	INDICES(1) = 1
 	INDICES(2) = 1
 
-        STATUS = CDF_LIB   (SELECT_, rVAR_SEQPOS_, REC_NUM, INDICES,
+        STATUS = CDF_LIB   (SELECT_, zVAR_SEQPOS_, REC_NUM, INDICES,
      .		            NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '11a.0')
 
 	DO X2 = 1, 3
 	  DO X1 = 1, 2
-            STATUS = CDF_LIB   (PUT_, rVAR_SEQDATA_, VAR_VALUES(X1,X2),
+            STATUS = CDF_LIB   (PUT_, zVAR_SEQDATA_, VAR_VALUES(X1,X2),
      .			        NULL_, STATUS)
 	    IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '11a.1')
 	  END DO
 	END DO
 
-        STATUS = CDF_LIB   (CONFIRM_, rVAR_SEQPOS_, REC_NUM, INDICES,
+        STATUS = CDF_LIB   (CONFIRM_, zVAR_SEQPOS_, REC_NUM, INDICES,
      .		            NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '11c.0')
 
@@ -460,13 +472,13 @@ C-----------------------------------------------------------------------
 	INDICES(1) = 1
 	INDICES(2) = 1
 
-        STATUS = CDF_LIB   (SELECT_, rVAR_SEQPOS_, REC_NUM, INDICES,
+        STATUS = CDF_LIB   (SELECT_, zVAR_SEQPOS_, REC_NUM, INDICES,
      .		            NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '11b.0')
 
 	DO X2 = 1, 3
 	  DO X1 = 1, 2
-            STATUS = CDF_LIB   (GET_, rVAR_SEQDATA_, VAR_VALUE_OUT,
+            STATUS = CDF_LIB   (GET_, zVAR_SEQDATA_, VAR_VALUE_OUT,
      .			        NULL_, STATUS)
 	    IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '11b.1')
 	    IF (VAR_VALUE_OUT .NE. VAR_VALUES(X1,X2))
@@ -478,14 +490,14 @@ C-----------------------------------------------------------------------
 C Record access.
 C-----------------------------------------------------------------------
 
-        STATUS = CDF_LIB    (SELECT_, rVARs_RECNUMBER_, 10,
-     .			     PUT_, rVARs_RECDATA_, numVars,
+        STATUS = CDF_LIB    (SELECT_, zVARs_RECNUMBER_, 10,
+     .			     PUT_, zVARs_RECDATA_, numVars,
      .						   varNums,
      .					           recBuffer,
      .		             NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, 'RA.1')
 
-        STATUS = CDF_LIB   (GET_, rVARs_RECDATA_, numVars,
+        STATUS = CDF_LIB   (GET_, zVARs_RECDATA_, numVars,
      .						  varNums,
      .					          recBufferOUT,
      .		        NULL_, STATUS)
@@ -572,11 +584,11 @@ C Inquire CDF.
 C-----------------------------------------------------------------------
 
         STATUS = CDF_LIB    (GET_, rVARs_NUMDIMS_, NUM_DIMS_OUT,
-     .			           rVARs_DIMSIZES_, DIM_SIZES_OUT,
+C    .			           zVARs_DIMSIZES_, DIM_SIZES_OUT,
      .			           CDF_ENCODING_, ENCODING_OUT,
      .			           CDF_MAJORITY_, MAJORITY_OUT,
-     .			           rVARs_MAXREC_, MAX_REC_OUT,
-     .			           CDF_NUMrVARS_, NUM_VARS_OUT,
+     .			           zVARs_MAXREC_, MAX_REC_OUT,
+     .			           CDF_NUMzVARS_, NUM_VARS_OUT,
      .			           CDF_NUMATTRS_, NUM_ATTRS_OUT,
 C    .			           CDF_COMPRESSION_, cTypeOUT,
 C    .						     cParmsOUT,
@@ -584,14 +596,14 @@ C    .						     cPctOUT,
      .		             NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '16.0')
 
-	IF (NUM_DIMS_OUT .NE. NUM_DIMS)
+	IF (NUM_DIMS_OUT .NE. 0)
      .	  CALL QUIT_CDF (STATUS, '16.1')
 
-	DO X = 1, 2
-	  IF (DIM_SIZES_OUT(X) .NE. DIM_SIZES(X)) THEN
-	    CALL QUIT_CDF (STATUS, '16.2')
-	  ENDIF
-	END DO
+C	DO X = 1, 2
+C	  IF (DIM_SIZES_OUT(X) .NE. DIM_SIZES(X)) THEN
+C	    CALL QUIT_CDF (STATUS, '16.2')
+C	  ENDIF
+C	END DO
 
 C	IF (ENCODING_OUT .NE. ENCODING)
 C    .	  CALL QUIT_CDF (STATUS, '16.3')
@@ -606,8 +618,8 @@ C-----------------------------------------------------------------------
 C Rename variable.
 C-----------------------------------------------------------------------
 
-        STATUS = CDF_LIB   (SELECT_, rVAR_NAME_, VARNAME,
-     .		            PUT_, rVAR_NAME_, NEW_VARNAME,
+        STATUS = CDF_LIB   (SELECT_, zVAR_NAME_, VARNAME,
+     .		            PUT_, zVAR_NAME_, NEW_VARNAME,
      .		            NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '17.0')
 
@@ -615,23 +627,23 @@ C-----------------------------------------------------------------------
 C Inquire variable.
 C-----------------------------------------------------------------------
 
-        STATUS = CDF_LIB    (GET_, rVAR_NAME_, VARNAME_OUT,
-     .			           rVAR_DATATYPE_, VAR_DATA_TYPE_OUT,
-     .			           rVAR_NUMELEMS_, VAR_NUM_ELEMENTS_OUT,
-     .			           rVAR_COMPRESSION_, cTypeOUT,
+        STATUS = CDF_LIB    (GET_, zVAR_NAME_, VARNAME_OUT,
+     .			           zVAR_DATATYPE_, VAR_DATA_TYPE_OUT,
+     .			           zVAR_NUMELEMS_, VAR_NUM_ELEMENTS_OUT,
+     .			           zVAR_COMPRESSION_, cTypeOUT,
      .						      cParmsOUT,
      .						      cPctOUT,
-     .			     CONFIRM_, rVAR_RESERVEPERCENT_,cReserveOUT,
-     .			     GET_, rVAR_SPARSERECORDS_, sRecordsTypeOUT,
-     .			           rVAR_SPARSEARRAYS_, sArraysTypeOUT,
+     .			     CONFIRM_, zVAR_RESERVEPERCENT_,cReserveOUT,
+     .			     GET_, zVAR_SPARSERECORDS_, sRecordsTypeOUT,
+     .			           zVAR_SPARSEARRAYS_, sArraysTypeOUT,
      .						       sArraysParmsOUT,
      .						       sArraysPctOUT,
-     .			           rVAR_NUMRECS_, nRecordsOUT,
+     .			           zVAR_NUMRECS_, nRecordsOUT,
      .		             NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '18.0')
 
-        STATUS = CDF_LIB   (GET_, rVAR_RECVARY_, VAR_REC_VARIANCE_OUT,
-     .			          rVAR_DIMVARYS_, VAR_DIM_VARIANCES_OUT,
+        STATUS = CDF_LIB   (GET_, zVAR_RECVARY_, VAR_REC_VARIANCE_OUT,
+     .			          zVAR_DIMVARYS_, VAR_DIM_VARIANCES_OUT,
      .		            NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '18.0')
 
@@ -696,7 +708,8 @@ C Inquire attribute entry.
 C-----------------------------------------------------------------------
 
         STATUS = CDF_LIB   (GET_, gENTRY_DATATYPE_, ENTRY_DATA_TYPE_OUT,
-     .			          gENTRY_NUMELEMS_, ENTRY_NUM_ELEMENTS_OUT,
+     .			          gENTRY_NUMELEMS_,
+     .			                         ENTRY_NUM_ELEMENTS_OUT,
      .		            NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '23.0')
 
