@@ -1869,7 +1869,7 @@ CDFlib (SELECT_, CDF_, id, \
 #if defined(PROTOs_)
 #  define PROTOARGs(args) args
 #else
-#  define PROTOARGs(args) ()
+#  define PROTOARGs(args) (void)
 #endif
 
 #if defined(BUILDINGforIDL)
@@ -2017,6 +2017,9 @@ VISIBLE_PREFIX CDFstatus CDFgetzVarSpec PROTOARGs((
 VISIBLE_PREFIX CDFstatus CDFreadzVarPadValue PROTOARGs((
   CDFid id, long varNum, long *dataType, long *numElms, CDFdata *buffer
 ));
+VISIBLE_PREFIX CDFstatus CDFreadzVarValue PROTOARGs((
+  CDFid id, long varNum, long recNum, long *indices, CDFdata *buffer
+));
 VISIBLE_PREFIX CDFstatus CDFreadzVarAllByVarID PROTOARGs((
   CDFid id, long varNum, long *numRecs, long *dataType, long *numElems,
   long *numDims, long *dimSizes, long *recVary, long *dimsVary, 
@@ -2081,16 +2084,16 @@ VISIBLE_PREFIX void CDFsetFileBackward2 PROTOARGs((
 VISIBLE_PREFIX void CDFsetFileBackwardFlag PROTOARGs((
   int flag
 ));
-VISIBLE_PREFIX int CDFgetFileBackward PROTOARGs(());
-VISIBLE_PREFIX int CDFgetFileBackwardFlag PROTOARGs(());
+VISIBLE_PREFIX int CDFgetFileBackward PROTOARGs((void));
+VISIBLE_PREFIX int CDFgetFileBackwardFlag PROTOARGs((void));
 VISIBLE_PREFIX void CDFsetChecksumMode PROTOARGs((
   long flag
 ));
-VISIBLE_PREFIX long CDFgetChecksumMode PROTOARGs(());
-VISIBLE_PREFIX int CDFgetFileBackwardEnvVar PROTOARGs(());
+VISIBLE_PREFIX long CDFgetChecksumMode PROTOARGs((void));
+VISIBLE_PREFIX int CDFgetFileBackwardEnvVar PROTOARGs((void));
 VISIBLE_PREFIX void CDFsetValidate PROTOARGs((long mode));
-VISIBLE_PREFIX int CDFgetValidate PROTOARGs(());
-VISIBLE_PREFIX int CDFgetValidateDebug PROTOARGs(());
+VISIBLE_PREFIX int CDFgetValidate PROTOARGs((void));
+VISIBLE_PREFIX int CDFgetValidateDebug PROTOARGs((void));
 VISIBLE_PREFIX void ROWtoCOL PROTOARGs((
   void *iBuffer, void *oBuffer, long numDims, long dimSizes[], long nValueBytes
 ));
@@ -2281,11 +2284,11 @@ VISIBLE_PREFIX void UnixTimetoTT2000 PROTOARGs((
   long long *epoch,
   int    numTimes
 ));
-VISIBLE_PREFIX void CDFClearLeapSecondsTable PROTOARGs(());
+VISIBLE_PREFIX void CDFClearLeapSecondsTable PROTOARGs((void));
 VISIBLE_PREFIX void CDFfillLeapSecondsTable PROTOARGs((
   double **table
 ));
-VISIBLE_PREFIX int CDFgetRowsinLeapSecondsTable PROTOARGs(());
+VISIBLE_PREFIX int CDFgetRowsinLeapSecondsTable PROTOARGs((void));
 #if defined(vms)
 VISIBLE_PREFIX void CDFgetLastDateinLeapSecondsTBL PROTOARGs((
   long *year, long *month, long *day
@@ -2295,8 +2298,8 @@ VISIBLE_PREFIX void CDFgetLastDateinLeapSecondsTable PROTOARGs((
   long *year, long *month, long *day
 ));
 #endif
-VISIBLE_PREFIX char *CDFgetLeapSecondsTableEnvVar PROTOARGs(());
-VISIBLE_PREFIX int CDFgetLeapSecondsTableStatus PROTOARGs(());
+VISIBLE_PREFIX char *CDFgetLeapSecondsTableEnvVar PROTOARGs((void));
+VISIBLE_PREFIX int CDFgetLeapSecondsTableStatus PROTOARGs((void));
 #endif
 VISIBLE_PREFIX void CDF_Free_String PROTOARGs((
   long numStrings, char **strings
