@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2014 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF					Header file for CDFconvert.
 *
@@ -70,6 +75,14 @@
 #define EPOCH2TT2000qual 28
 #define TT20002EPOCHqual 29
 #define TT20002EPOCH16qual 30
+#define SORTqual        31
+#define BLOCKINGFACTORqual 32
+#define ADJUSTTT2000qual 33
+#define LEAPSECONDLASTUPDATEDqual 34
+#define COMPRESSNONEPOCHqual 35
+#define REMOVEDIMqual	36
+#define PADTOFILLEDqual	37
+#define NOVALIDATEqual  38
 
 /******************************************************************************
 * Macro constants.
@@ -77,8 +90,8 @@
 
 #define MAX_COL_TO_USE		70
 #define INDENT_CDF_STATUS	6
-#define MAX_OUTPUT_TEXT_LEN	200
-#define MINnHYPERS		5
+#define MAX_OUTPUT_TEXT_LEN	512
+#define MINnHYPERS		1
 
 #define SOURCEformat		(-1L)
 #define SOURCEmajority		(-1L)
@@ -156,8 +169,10 @@ Logical ConvertCDF PROTOARGs((char *, char *));
 Logical ConvertCDFx PROTOARGs((char *, char *));
 Logical ConvertAttributes PROTOARGs((void));
 Logical ConvertEntry PROTOARGs((char *, long, int));
+Logical HasDepend PROTOARGs((CDFid id, int entryType, long varNum, char *depend));
 Logical ConvertVariables PROTOARGs((long, long));
-Logical ConvertVariable PROTOARGs((long, Logical, long, long));
+Logical CreateVariable PROTOARGs((long, Logical));
+Logical ConvertVarData PROTOARGs((long, Logical, long, long));
 struct CompressionStruct *ParseCompressionOptions PROTOARGs((char *options));
 Logical ParseCompressionTokenAndBF PROTOARGs((
   char **p1, char **p2, long *cType, long cParms[CDF_MAX_PARMS], long *bf,
