@@ -279,6 +279,12 @@
 #  define unix
 #endif
 
+#if defined(__unix)
+#  if !defined(unix)
+#    define unix
+#  endif
+#endif
+
 /******************************************************************************
 * Determine variable argument list type - `stdarg' or `varargs'.  Currently,
 * only SunOS/bsd doesn't have `stdarg.h' (but SunOS/gnu and all Solaris do).
@@ -615,13 +621,13 @@ typedef sChar sByte;
 #  if defined(PROTOs_)
 #    define VARPROTOARGs(args) args
 #  else
-#    define VARPROTOARGs(args) ()
+#    define VARPROTOARGs(args) (void)
 #  endif
 #else
 #  if defined(PROTOs_)
-#    define VARPROTOARGs(args) ()
+#    define VARPROTOARGs(args) (void)
 #  else
-#    define VARPROTOARGs(args) ()
+#    define VARPROTOARGs(args) (void)
 #  endif
 #endif
 
@@ -1091,7 +1097,8 @@ VISIBLE_PREFIX CDFid cdfid_getCDFid PROTOARGs((
   Int32 id, void (*fatalFnc) PROTOARGs((char *msg))
 ));
 VISIBLE_PREFIX char *strcpyX PROTOARGs((char *dst, char *src, size_t max));
-VISIBLE_PREFIX char *strcatX PROTOARGs((char *dst, char *src, size_t max));
+VISIBLE_PREFIX char *strcatX PROTOARGs((char *dst, char *src, size_t byteSrc,
+                                        size_t usedDest, size_t byteDest));
 #if defined(__cplusplus)
   }
 #endif
