@@ -72,7 +72,7 @@ Logical LoadMastergAttributes (CDFid, CDFid, long);
 Logical LoadMasterVariables (CDFid, CDFid, long, long, long);
 Logical LoadVariableData(int, CDFid);
 Logical LoadgAttributes (CDFid, int);
-Logical LoadgAttributes2 ();
+Logical LoadgAttributes2 (void);
 Logical LoadMasterTextFile (char *);
 Logical LoadMasterTextFile2 (char *);
 
