@@ -33,7 +33,11 @@
 * Include files.
 ******************************************************************************/
 
+#include "cdflib.h"
 #include "widgets.h"
+#if defined(WIN32)
+#  include <Windows.h>
+#endif
 
 #if defined(mac)
 #  include "cdfxp.rh"
@@ -70,6 +74,7 @@
 #define EPOCHRANGEqual          22
 #define RECORDRANGEqual         23
 #define ZISO8601qual            24
+#define NOVALIDATEqual          25
 
 #define FORMATopt               0
 #define NOFORMATopt             1
@@ -170,9 +175,9 @@
 #define MAX_CHECKSUM            MD5_CHECKSUM
 #define MAX_SETTINGS_LEN        200
 
-#define PASSED                  1
-#define FAILED                  2
-#define FATAL                   3
+#define PASSEDx                 1
+#define FAILEDx                 2
+#define FATALx                  3
 
 #define SUCCESS                 1
 #define FATALin                 2
@@ -259,7 +264,7 @@
 
 #if defined(alphaosf) || defined(IRIX64bit) || defined(_LP64) || \
     defined(__amd64) || defined(__x86_64__) || defined(__ia64__) || \
-    defined(__PPC64__) || defined(__ppc64__)
+    defined(__PPC64__) || defined(__ppc64__) || defined(__arm64__)
 #  define Int32FORMATstandard     "%11d"
 #  define Int32uFORMATstandard    "%10d"
 #  define Int64FORMATstandard     "%20lld"
@@ -300,7 +305,7 @@
 #define OUTPUTitemLEN           6
 
 #define MINitemCOLn             22
-#define MINitemLEN              24      /* Maximum of the possible styles. */
+#define MINitemLEN              24      /* Minimum of the possible styles. */
 #define MAXitemCOLn             47
 #define MAXitemLEN              24      /* Maximum of the possible styles. */
 #define FILTERitemCOLn          72
@@ -461,7 +466,6 @@
 #define OUTPUTtoFILEh           3
 #define OUTPUTtoFILEv           4
 #define OUTPUTtoCDF             5
-#define OUTPUTtoFILEcdaweb      6
 
 /******************************************************************************
 * Monotonicities.
@@ -638,7 +642,7 @@ struct IndicesStruct {
 * Variable structure.
 ******************************************************************************/
 
-struct VarStruct {
+struct VarStructXP {
   long varN;            /* Number. */
   long numDims;         /* Number of dimensions. */
   long dimSizes[CDF_MAX_DIMS];
@@ -694,7 +698,7 @@ struct ItemStruct {
   Logical output;               /* If item should be output. */
   Logical filter;               /* If item should be filtered. */
   Logical inclusive;
-  struct VarStruct *Var;
+  struct VarStructXP *Var;
   struct RecordStruct *Record;
   struct IndicesStruct *Indices;
   struct ItemStruct *nextItem;
@@ -791,7 +795,6 @@ char outputCDF[CDF_PATHNAME_LEN+1] = "default";
 long includeVars;
 char varsList[50*(CDF_VAR_NAME_LEN256+1)];
 long outputVars;
-Logical cdaweb;
 int  poundedheading;
 char **vars;
 int  numVars;
@@ -811,6 +814,7 @@ char ***varsInGroup;
 struct ItemStruct ***varPtrsInGroup;
 int *numVarsInGroup;
 Logical ziso8601;
+Logical toValidate;
 #else
 extern int batchMode;
 extern Logical simpleMode;
@@ -847,13 +851,12 @@ extern char outputText[DU_MAX_PATH_LEN+1];
 extern char outputCDF[CDF_PATHNAME_LEN+1];
 extern long includeVars;
 extern long outputVars;
-extern Logical cdaweb;
 extern int  poundedheading;
 extern char varsList[50*(CDF_VAR_NAME_LEN256+1)];
 extern char **vars;
 extern int  numVars;
 extern int  numVarsO;
-extern Logical range;
+extern long range;
 extern double epochStart, epochEnd;
 extern double epoch16Start[2], epoch16End[2];
 extern long long tt2000Start, tt2000End;
@@ -868,6 +871,7 @@ extern char ***varsInGroup;
 extern struct ItemStruct ***varPtrsInGroup;
 extern int *numVarsInGroup;
 extern Logical ziso8601;
+extern Logical toValidate;
 #endif
 
 /******************************************************************************
@@ -883,7 +887,7 @@ void ExportCDFsSpec PROTOARGs((
   char *varHeader0[]
 ));
 void ExportCDF PROTOARGs((char *path, long zMode, Logical negToPosFp0));
-Logical LoadCDF PROTOARGs((void));
+Logical LoadCDF PROTOARGs((CDFid id));
 Logical LoadSelectionWindow PROTOARGs((int part));
 void LoadCDFwindow PROTOARGs((char *path));
 void SelectionWindow PROTOARGs((Logical *noMoreAccess));
@@ -909,24 +913,23 @@ Logical PromptFor PROTOARGs((
   char *value, int valueL, int cursorAt, char *label, int helpID
 ));
 Logical PromptForMinMax PROTOARGs((struct ItemStruct *Item, Logical min));
-Logical PromptForFill PROTOARGs((struct VarStruct *Var));
-Logical PromptForReserve PROTOARGs((struct VarStruct *Var));
-Logical PromptForBlocking PROTOARGs((struct VarStruct *Var));
+Logical PromptForFill PROTOARGs((struct VarStructXP *Var));
+Logical PromptForReserve PROTOARGs((struct VarStructXP *Var));
+Logical PromptForBlocking PROTOARGs((struct VarStructXP *Var));
 Logical PromptForWidth PROTOARGs((struct ItemStruct *Item));
 Logical PromptForFormat PROTOARGs((struct ItemStruct *Item));
 Logical PromptForCompression PROTOARGs((
   long *cType, long cParms[CDF_MAX_PARMS]
 ));
-Logical PromptForSparseness PROTOARGs((struct VarStruct *Var));
+Logical PromptForSparseness PROTOARGs((struct VarStructXP *Var));
 Logical PromptForChecksum PROTOARGs((long *checksum));
 Logical FlipItems PROTOARGs((int itemX));
-int VariableWidth PROTOARGs((struct VarStruct *Var));
+int VariableWidth PROTOARGs((struct VarStructXP *Var));
 void SaveSettings PROTOARGs((void));
 void RestoreSettings PROTOARGs((void));
 Logical ToWalk PROTOARGs((void));
 Logical ToScreenHori PROTOARGs((void));
 Logical ToFileHori PROTOARGs((void));
-Logical ToFileCDAweb PROTOARGs((void));
 CDFstatus EncodeLineHori PROTOARGs((
   char *line, long recN, int *filterStatus, struct ItemStruct *exportHead,
   Logical standard, size_t width
@@ -978,12 +981,12 @@ Logical FirstLastIndices PROTOARGs((
   long numDims, long dimSizes[], long firstIndices[], long lastIndices[],
   long *nValues, Logical toCDF, struct ItemStruct *exportHead
 ));
-Logical ScalarVariable PROTOARGs((struct VarStruct *Var));
-Logical DimensionalVariable PROTOARGs((struct VarStruct *Var, int *dimN));
-Logical OneDimensionVaries PROTOARGs((struct VarStruct *Var));
-Logical ReadScalarValue PROTOARGs((struct VarStruct *Var, long recN));
+Logical ScalarVariable PROTOARGs((struct VarStructXP *Var));
+Logical DimensionalVariable PROTOARGs((struct VarStructXP *Var, int *dimN));
+Logical OneDimensionVaries PROTOARGs((struct VarStructXP *Var));
+Logical ReadScalarValue PROTOARGs((struct VarStructXP *Var, long recN));
 Logical ReadDimensionalValue PROTOARGs((
-  struct VarStruct *Var, long indices[]
+  struct VarStructXP *Var, long indices[]
 ));
 Logical ValidFormat PROTOARGs((char *format));
 Logical SameDimensionalities PROTOARGs((
@@ -1003,7 +1006,7 @@ void UpdateToScreen PROTOARGs((
   struct EditWindowStruct *EWscr, char *trailerMsg, long at, long total
 ));
 Logical SetItemMonotonicities PROTOARGs((void));
-Logical SetVarMonotonicity PROTOARGs((struct VarStruct *Var));
+Logical SetVarMonotonicity PROTOARGs((struct VarStructXP *Var));
 void BuildExportList PROTOARGs((
   struct ItemStruct **exportHead, Logical walking
 ));
