@@ -104,8 +104,11 @@ struct ItemWindowStruct {
   * These are initialized/calculated/returned by `ItemWindow'.
   ***************************************************************************/
   int itemN;                    /* Current item number. */
-/*int key;*/                    /* Key entered causing exit from menu. */
+#if defined(WIN32)
+  int key;                      /* Key entered causing exit from menu. */
+#else
   wint_t key;                   /* Key entered causing exit from menu. */
+#endif
   /***************************************************************************
   * These are for internal use by `ItemWindow'.
   ***************************************************************************/
@@ -203,8 +206,11 @@ struct PromptWindowStruct {
   /***************************************************************************
   * These are initialized/calculated/returned by `PromptWindow'.
   ***************************************************************************/
-/*int key;*/                    /* Key entered causing exit from menu. */
+#if defined(WIN32)
+  int key;                      /* Key entered causing exit from menu. */
+#else
   wint_t key;                   /* Key entered causing exit from menu. */
+#endif
   /***************************************************************************
   * These are for internal use by `PromptWindow'.
   ***************************************************************************/
@@ -300,8 +306,11 @@ struct EditWindowStruct {
   /***************************************************************************
   * These are initialized/calculated/returned by `EditWindow'.
   ***************************************************************************/
-/*int key;*/                    /* Key entered causing exit from menu. */
+#if defined(WIN32)
+  int key;                      /* Key entered causing exit from menu. */
+#else
   wint_t key;                   /* Key entered causing exit from menu. */
+#endif
   /***************************************************************************
   * These are for internal use by `EditWindow'.
   ***************************************************************************/
@@ -396,8 +405,11 @@ struct FieldWindowStruct {
   * These are initialized/calculated/returned by `FieldWindow'.
   ***************************************************************************/
   int fieldN;                   /* Current field number. */
-/*int key;*/                    /* Key entered causing exit from menu. */
+#if defined(WIN32)
+  int key;                      /* Key entered causing exit from menu. */
+#else
   wint_t key;                   /* Key entered causing exit from menu. */
+#endif
   /***************************************************************************
   * These are for internal use by `FieldWindow'.
   ***************************************************************************/
