@@ -73,17 +73,17 @@ static CDFstatus AllocateVVR PROTOARGs((
   OFF_T *vvrOffset
 ));
 static CDFstatus AllocateCVVR PROTOARGs((
-  struct CDFstruct *CDF, OFF_T cSize, OFF_T xSize, OFF_T *cvvrOffset
+  struct CDFstruct *CDF, size_t cSize, size_t xSize, OFF_T *cvvrOffset
 ));
 
 /******************************************************************************
 * AllocateRecords64.
 ******************************************************************************/
 
-STATICforIDL CDFstatus AllocateRecords64 (CDF, Var, alloc)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct AllocStruct alloc;
+STATICforIDL CDFstatus AllocateRecords64 (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct AllocStruct alloc)
 {
   CDFstatus pStatus = CDF_OK;
   Int32 toRec; int count, newCount;
@@ -142,13 +142,13 @@ struct AllocStruct alloc;
 * InsertRecords.
 ******************************************************************************/
 
-static CDFstatus InsertRecords (CDF, Var, alloc, vxrStart, count, toRec)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct AllocStruct alloc;
-OFF_T vxrStart;
-int *count;
-Int32 *toRec;
+static CDFstatus InsertRecords (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct AllocStruct alloc,
+OFF_T vxrStart,
+int *count,
+Int32 *toRec)
 {
   CDFstatus pStatus = CDF_OK; struct VXRstruct64 VXR;
   OFF_T vxrOffset = vxrStart, vxrOffsetNew;
@@ -306,12 +306,12 @@ Int32 *toRec;
 * AppendRecords.
 ******************************************************************************/
 
-static CDFstatus AppendRecords (CDF, Var, alloc, vxrStart, count)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct AllocStruct *alloc;
-OFF_T vxrStart;
-int *count;
+static CDFstatus AppendRecords (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct AllocStruct *alloc,
+OFF_T vxrStart,
+int *count)
 {
   CDFstatus pStatus = CDF_OK; struct VXRstruct64 VXR;
   OFF_T vxrOffset = vxrStart, vxrOffsetNew;
@@ -374,13 +374,13 @@ int *count;
 * InsertEntry.
 ******************************************************************************/
 
-static CDFstatus InsertEntry (CDF, Var, alloc, vxrOffset, atEntryN, count)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct AllocStruct *alloc;
-OFF_T vxrOffset;
-int atEntryN;
-int *count;
+static CDFstatus InsertEntry (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct AllocStruct *alloc,
+OFF_T vxrOffset,
+int atEntryN,
+int *count)
 {
   CDFstatus pStatus = CDF_OK;
   OFF_T vxrOffsetNew, vrOffset, pushOffset; Int32 pushFirst, pushLast;
@@ -435,17 +435,16 @@ int *count;
 * InsertAtEntry.
 ******************************************************************************/
 
-static void InsertAtEntry (first, last, offset, VXR, atEntryN, push,
-			     pushFirst, pushLast, pushOffset)
-Int32 first;
-Int32 last;
-OFF_T offset;
-struct VXRstruct64 *VXR;
-int atEntryN;
-Logical *push;
-Int32 *pushFirst;
-Int32 *pushLast;
-OFF_T *pushOffset;
+static void InsertAtEntry (
+Int32 first,
+Int32 last,
+OFF_T offset,
+struct VXRstruct64 *VXR,
+int atEntryN,
+Logical *push,
+Int32 *pushFirst,
+Int32 *pushLast,
+OFF_T *pushOffset)
 {
   int startEntryN, entryN;
   if (VXR->NusedEntries < VXR->Nentries) {
@@ -476,12 +475,12 @@ OFF_T *pushOffset;
 *   It is assumed that the offset is for a VXR at the end of a linked list.
 ******************************************************************************/
 
-static CDFstatus AppendEntry (CDF, Var, alloc, vxrOffset, count)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct AllocStruct *alloc;
-OFF_T vxrOffset;
-int *count;
+static CDFstatus AppendEntry (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct AllocStruct *alloc,
+OFF_T vxrOffset,
+int *count)
 {
   CDFstatus pStatus = CDF_OK; Logical resized;
   struct VXRstruct64 VXR, newVXR; OFF_T offset, vxrOffsetNew;
@@ -499,7 +498,7 @@ int *count;
       int lastEntryN = (int) (VXR.NusedEntries - 1);
       if (alloc->first == VXR.Last[lastEntryN] + 1) {
 	Int32 newCount = alloc->last - VXR.First[lastEntryN] + 1;
-	OFF_T newSize = (OFF_T) (VVR_BASE_SIZE64 + 
+	size_t newSize = (size_t) (VVR_BASE_SIZE64 + 
 				 ((OFF_T)newCount) * Var->NphyRecBytes);
 	if (!sX(ResizeIR64(CDF,VXR.Offset[lastEntryN],
 			   newSize,NULL,
@@ -568,11 +567,11 @@ int *count;
 * PadSparseRecords.
 ******************************************************************************/
 
-static CDFstatus PadSparseRecords (CDF, Var, offset, nRecords)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-OFF_T offset;
-Int32 nRecords;
+static CDFstatus PadSparseRecords (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+OFF_T offset,
+Int32 nRecords)
 {
   CDFstatus pStatus = CDF_OK; int how; void *buffer;
   if (!sX(BuildPadBuffer64(CDF,Var,nRecords,
@@ -590,10 +589,10 @@ Int32 nRecords;
 * CountVXRs.
 ******************************************************************************/
 
-static CDFstatus CountVXRs (CDF, vxrStart, count)
-struct CDFstruct *CDF;
-OFF_T vxrStart;
-int *count;
+static CDFstatus CountVXRs (
+struct CDFstruct *CDF,
+OFF_T vxrStart,
+int *count)
 {
   CDFstatus pStatus = CDF_OK; OFF_T vxrOffset = vxrStart;
   *count = 0;
@@ -610,11 +609,11 @@ int *count;
 * InitNewVXR64.
 ******************************************************************************/
 
-STATICforIDL void InitNewVXR64 (VXR, firstRec, lastRec, offset)
-struct VXRstruct64 *VXR;
-Int32 firstRec;
-Int32 lastRec;
-OFF_T offset;
+STATICforIDL void InitNewVXR64 (
+struct VXRstruct64 *VXR,
+Int32 firstRec,
+Int32 lastRec,
+OFF_T offset)
 {
   int entryN;
   VXR->RecordSize = VXR_BASE_SIZE64;
@@ -637,8 +636,8 @@ OFF_T offset;
 * InitNewVXRx.
 ******************************************************************************/
 
-static void InitNewVXRx (VXRx)
-struct VXRstruct64 *VXRx;
+static void InitNewVXRx (
+struct VXRstruct64 *VXRx)
 {
   int entryN;
   VXRx->RecordSize = VXRx_BASE_SIZE64;
@@ -658,10 +657,10 @@ struct VXRstruct64 *VXRx;
 * FirstRecords.
 ******************************************************************************/
 
-static CDFstatus FirstRecords (CDF, Var, alloc)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct AllocStruct *alloc;
+static CDFstatus FirstRecords (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct AllocStruct *alloc)
 {
   CDFstatus pStatus = CDF_OK;
   struct VXRstruct64 VXR; OFF_T offset, vxrOffset;
@@ -683,14 +682,13 @@ struct AllocStruct *alloc;
 * ExtendLevel.
 ******************************************************************************/
 
-static CDFstatus ExtendLevel (CDF, vxrOffset, count, vxrOffsetHead, lastNew,
-			        countNew)
-struct CDFstruct *CDF;
-OFF_T vxrOffset;
-int count;
-OFF_T *vxrOffsetHead;
-Int32 *lastNew;
-int *countNew;
+static CDFstatus ExtendLevel (
+struct CDFstruct *CDF,
+OFF_T vxrOffset,
+int count,
+OFF_T *vxrOffsetHead,
+Int32 *lastNew,
+int *countNew)
 {
   CDFstatus pStatus = CDF_OK; struct VXRstruct64 VXR;
   if (!sX(ReadVXR64(CDF->fp,vxrOffset,
@@ -710,12 +708,12 @@ int *countNew;
 * CreateLevel.
 ******************************************************************************/
 
-static CDFstatus CreateLevel (CDF, vxrOffset, count, vxrOffsetHead, newCount)
-struct CDFstruct *CDF;
-OFF_T vxrOffset;
-int count;
-OFF_T *vxrOffsetHead;
-int *newCount;
+static CDFstatus CreateLevel (
+struct CDFstruct *CDF,
+OFF_T vxrOffset,
+int count,
+OFF_T *vxrOffsetHead,
+int *newCount)
 {
   CDFstatus pStatus = CDF_OK;
   Int32 sizeOfVXRx = VXRx_BASE_SIZE64;
@@ -807,11 +805,11 @@ int *newCount;
 * AllocateVR.
 ******************************************************************************/
 
-static CDFstatus AllocateVR (CDF, Var, alloc, offset)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-struct AllocStruct *alloc;
-OFF_T *offset;
+static CDFstatus AllocateVR (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+struct AllocStruct *alloc,
+OFF_T *offset)
 {
   CDFstatus pStatus = CDF_OK;
   switch (alloc->type) {
@@ -847,11 +845,11 @@ OFF_T *offset;
 * AllocateVVR.
 ******************************************************************************/
 
-static CDFstatus AllocateVVR (CDF, Var, nRecords, vvrOffset)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-Int32 nRecords;
-OFF_T *vvrOffset;
+static CDFstatus AllocateVVR (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+Int32 nRecords,
+OFF_T *vvrOffset)
 {
   CDFstatus pStatus = CDF_OK; struct VVRstruct64 VVR;
   VVR.RecordSize = (OFF_T) (VVR_BASE_SIZE64 + 
@@ -870,11 +868,11 @@ OFF_T *vvrOffset;
 * AllocateCVVR.
 ******************************************************************************/
 
-static CDFstatus AllocateCVVR (CDF, cSize, xSize, cvvrOffset)
-struct CDFstruct *CDF;
-OFF_T cSize;
-OFF_T xSize;
-OFF_T *cvvrOffset;
+static CDFstatus AllocateCVVR (
+struct CDFstruct *CDF,
+size_t cSize,
+size_t xSize,
+OFF_T *cvvrOffset)
 {
   CDFstatus pStatus = CDF_OK; struct CVVRstruct64 CVVR;
   CVVR.RecordSize = (OFF_T) (CVVR_BASE_SIZE64 + cSize + xSize);
@@ -895,9 +893,9 @@ OFF_T *cvvrOffset;
 * UpdateVXRtailInVDR64.
 ******************************************************************************/
 
-STATICforIDL CDFstatus UpdateVXRtailInVDR64 (CDF, Var)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
+STATICforIDL CDFstatus UpdateVXRtailInVDR64 (
+struct CDFstruct *CDF,
+struct VarStruct *Var)
 {
   CDFstatus pStatus = CDF_OK; struct VXRstruct64 VXR;
   OFF_T vxrOffset; Int32 irType; int lastEntryN;
