@@ -45,10 +45,10 @@ CDFstatus VerifyChecksum64 PROTOARGs((struct CDFstruct *CDF));
 * AddChecksumMD5.
 ******************************************************************************/
 
-CDFstatus AddChecksumMD5 (vFp, size, signature)
-vFILE *vFp;
-long  size;
-uChar signature[16];
+CDFstatus AddChecksumMD5 (
+vFILE *vFp,
+long  size,
+uChar signature[16])
 {
   
 #if defined(vms)
@@ -120,10 +120,10 @@ uChar signature[16];
 * AddChecksumMD5_64.
 ******************************************************************************/
      
-CDFstatus AddChecksumMD5_64 (vFp, size, signature)
-vFILE *vFp;
-OFF_T  size;
-uChar signature[16];
+CDFstatus AddChecksumMD5_64 (
+vFILE *vFp,
+OFF_T  size,
+uChar signature[16])
 {    
 
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
@@ -215,10 +215,10 @@ uChar signature[16];
 * ComputeChecksumMD5.
 ******************************************************************************/
 
-CDFstatus ComputeChecksumMD5 (vFp, size, signature)
-vFILE *vFp;
-long  size;
-uChar  signature[16];
+CDFstatus ComputeChecksumMD5 (
+vFILE *vFp,
+long  size,
+uChar  signature[16])
 {
   uChar *buffer;
   struct MD5Context md5c;
@@ -226,20 +226,20 @@ uChar  signature[16];
 
   MD5Init(&md5c);
   if (fseek(vFp->fp, 0, vSEEK_SET) == EOF) return FALSE;
-  buffer = (uChar *) malloc (BLOCKSIZE + 72);
+  buffer = (uChar *) cdf_AllocateMemory (BLOCKSIZE + 72, NULL);
   if (!buffer) return FALSE; 
   while (jj < size) {
      if (jj+BLOCKSIZE < size) readBytes = BLOCKSIZE;
      else readBytes = size - jj;
      if (fread(buffer,1,readBytes,vFp->fp) != (size_t) readBytes) {
-	free (buffer);
+	cdf_FreeMemory (buffer, NULL);
 	return FALSE;
      }
      MD5Update(&md5c, buffer, (unsigned) readBytes);
      jj = jj + readBytes;
   }
   MD5FinalZ(signature, &md5c);
-  free (buffer);
+  cdf_FreeMemory (buffer, NULL);
   buffer = NULL;
   return TRUE;
 
@@ -249,10 +249,10 @@ uChar  signature[16];
 * ComputeChecksumMD5_64.
 ******************************************************************************/
 
-CDFstatus ComputeChecksumMD5_64 (vFp, size, signature)
-vFILE *vFp;
-OFF_T  size;
-uChar  signature[16];
+CDFstatus ComputeChecksumMD5_64 (
+vFILE *vFp,
+OFF_T  size,
+uChar  signature[16])
 {
   uChar *buffer;
   struct MD5Context md5c;
@@ -265,14 +265,14 @@ uChar  signature[16];
 #else
      if (FSEEK64(vFp->fp,(OFF_T) 0,vSEEK_SET) == EOF) return FALSE;
 #endif
-  buffer = (uChar *) malloc (BLOCKSIZE + 72);
+  buffer = (uChar *) cdf_AllocateMemory (BLOCKSIZE + 72, NULL);
   if (!buffer) return FALSE;
   while (jj < size) {
      if (jj+BLOCKSIZE < size) readBytes = BLOCKSIZE;
      else readBytes = (int) (size - jj);
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
      if (FREAD64(vFp->fh,buffer,(unsigned int) readBytes) != (int) readBytes) {
-	free (buffer);
+	cdf_FreeMemory (buffer, NULL);
         return FALSE;
      }
 #else
@@ -282,7 +282,7 @@ uChar  signature[16];
      jj = jj + readBytes;
   }
   MD5FinalZ(signature, &md5c);
-  free (buffer);
+  cdf_FreeMemory (buffer, NULL);
   buffer = NULL;
   return TRUE;
 }
@@ -291,10 +291,10 @@ uChar  signature[16];
 * GetChecksumMD5.
 ******************************************************************************/
 
-CDFstatus GetChecksumMD5 (vFp, size, signature)
-vFILE *vFp;
-long  size;
-uChar signature[16];
+CDFstatus GetChecksumMD5 (
+vFILE *vFp,
+long  size,
+uChar signature[16])
 { 
 
   if (fseek(vFp->fp,size,vSEEK_SET) == EOF) return FALSE;
@@ -306,10 +306,10 @@ uChar signature[16];
 * GetChecksumMD5_64.
 ******************************************************************************/
      
-CDFstatus GetChecksumMD5_64 (vFp, size, signature)
-vFILE *vFp;
-OFF_T  size;
-uChar *signature;
+CDFstatus GetChecksumMD5_64 (
+vFILE *vFp,
+OFF_T  size,
+uChar *signature)
 {
 
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
@@ -326,8 +326,8 @@ uChar *signature;
 * CDFVerifyChecksum.
 ******************************************************************************/
 
-CDFstatus CDFVerifyChecksum (CDF)
-struct CDFstruct *CDF;
+CDFstatus CDFVerifyChecksum (
+struct CDFstruct *CDF)
 {
   
   if (!CDF->largeFile)
@@ -341,8 +341,8 @@ struct CDFstruct *CDF;
 * VerifyChecksum.
 ******************************************************************************/
 
-CDFstatus VerifyChecksum (CDF)
-struct CDFstruct *CDF;
+CDFstatus VerifyChecksum (
+struct CDFstruct *CDF)
 {
   long GDRoffset, CPRoffset;
   Int32 CDRflags;
@@ -401,8 +401,8 @@ struct CDFstruct *CDF;
 * VerifyChecksum64.
 ******************************************************************************/
 
-CDFstatus VerifyChecksum64 (CDF)
-struct CDFstruct *CDF;
+CDFstatus VerifyChecksum64 (
+struct CDFstruct *CDF)
 {
   OFF_T GDRoffset, CPRoffset;
   Int32 CDRflags;
@@ -459,8 +459,8 @@ struct CDFstruct *CDF;
 * CDFAddChecksum.
 ******************************************************************************/
 
-CDFstatus CDFAddChecksum (CDF)
-struct CDFstruct *CDF;
+CDFstatus CDFAddChecksum (
+struct CDFstruct *CDF)
 {
   if (!CDF->largeFile)
     return AddChecksum (CDF);
@@ -472,8 +472,8 @@ struct CDFstruct *CDF;
 * AddChecksum.
 ******************************************************************************/
 
-CDFstatus AddChecksum (CDF)
-struct CDFstruct *CDF;
+CDFstatus AddChecksum (
+struct CDFstruct *CDF)
 {
   long GDRoffset, CPRoffset;
   Int32 CDRflags;
@@ -531,8 +531,8 @@ struct CDFstruct *CDF;
 * AddChecksum64.
 ******************************************************************************/
 
-CDFstatus AddChecksum64 (CDF)
-struct CDFstruct *CDF;
+CDFstatus AddChecksum64 (
+struct CDFstruct *CDF)
 {
   OFF_T GDRoffset, CPRoffset;
   Int32 CDRflags;
