@@ -40,9 +40,9 @@
 * CDFcre64.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CDFcre64 (Va, Cur)
-struct VAstruct *Va;
-struct CurStruct *Cur;
+STATICforIDL CDFstatus CDFcre64 (
+struct VAstruct *Va,
+struct CurStruct *Cur)
 {
 CDFstatus tStatus, pStatus = CDF_OK;
 
@@ -227,7 +227,7 @@ switch (Va->item) {
     /**************************************************************************
     * Write CDR.
     **************************************************************************/
-    CDR.RecordSize = (OFF_T) (CDR_BASE_SIZE64 + CDF_COPYRIGHT_LEN);
+    CDR.RecordSize = (size_t) (CDR_BASE_SIZE64 + CDF_COPYRIGHT_LEN);
     CDR.RecordType = CDR_;
     CDR.GDRoffset = CDF->CDRoffset64 + CDR.RecordSize;
     CDR.Version = CDF_LIBRARY_VERSION;
@@ -260,7 +260,7 @@ switch (Va->item) {
     GDR.rVDRhead = (OFF_T) 0;
     GDR.zVDRhead = (OFF_T) 0;
     GDR.ADRhead = (OFF_T) 0;
-    GDR.eof = (OFF_T) (CDR.GDRoffset + GDR.RecordSize);
+    GDR.eof = (size_t) (CDR.GDRoffset + GDR.RecordSize);
     GDR.NrVars = CDF->NrVars;
     GDR.NumAttr = 0;
     GDR.rMaxRec = CDF->rMaxRec;
