@@ -83,9 +83,9 @@ static CDFstatus WriteCVVRorVVR PROTOARGs((
 * CDFdel.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CDFdel (Va, Cur)
-struct VAstruct *Va;
-struct CurStruct *Cur;
+STATICforIDL CDFstatus CDFdel (
+struct VAstruct *Va, 
+struct CurStruct *Cur)
 {
 CDFstatus tStatus, pStatus = CDF_OK;
 switch (Va->item) {
@@ -300,6 +300,8 @@ switch (Va->item) {
       CDF->CURrVarNum = RESERVED_VARNUM;
       CDF->CURrVarOffset = 0;
     }
+    CDF->keptVarzOp = zOp;
+    CDF->keptVarNum = -1;
     /**************************************************************************
     * Delete the associated attribute entries and renumber the entries that
     * are associated with the variables that followed the variable that was
@@ -679,9 +681,9 @@ return pStatus;
 * WasteTree_r.
 ******************************************************************************/
 
-static CDFstatus WasteTree_r (CDF, vxrOffset)
-struct CDFstruct *CDF;
-Int32 vxrOffset;
+static CDFstatus WasteTree_r (
+struct CDFstruct *CDF,
+Int32 vxrOffset)
 {
   CDFstatus pStatus = CDF_OK;
   int e; struct VXRstruct VXR; Int32 irType, irSize;
@@ -720,12 +722,12 @@ Int32 vxrOffset;
 * DeleteVarRecords.
 ******************************************************************************/
 
-static CDFstatus DeleteVarRecords (CDF, Var, firstRec, lastRec, reNumber)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-Int32 firstRec;
-Int32 lastRec;
-Logical reNumber;
+static CDFstatus DeleteVarRecords (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+Int32 firstRec,
+Int32 lastRec,
+Logical reNumber)
 {
   CDFstatus pStatus = CDF_OK; Int32 deletedTo, recNum; Logical found;
   /****************************************************************************
@@ -1030,12 +1032,12 @@ Logical reNumber;
 * DeleteRecords.
 ******************************************************************************/
 
-static CDFstatus DeleteRecords (CDF, Var, firstRec, lastRec, deletedTo)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-Int32 firstRec;
-Int32 lastRec;
-Int32 *deletedTo;
+static CDFstatus DeleteRecords (
+struct CDFstruct *CDF, 
+struct VarStruct *Var,
+Int32 firstRec, 
+Int32 lastRec,
+Int32 *deletedTo)
 {
   CDFstatus pStatus = CDF_OK; Logical total = FALSE; Int32 vxrOffset;
   /****************************************************************************
@@ -1067,15 +1069,14 @@ Int32 *deletedTo;
 * DeleteRecords_r.
 ******************************************************************************/
 
-static CDFstatus DeleteRecords_r (CDF, Var, firstVXRoffset, firstRec, lastRec,
-				  deletedTo, total)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-Int32 firstVXRoffset;
-Int32 firstRec;
-Int32 lastRec;
-Int32 *deletedTo;
-Logical *total;
+static CDFstatus DeleteRecords_r (
+struct CDFstruct *CDF, 
+struct VarStruct *Var,
+Int32 firstVXRoffset, 
+Int32 firstRec,
+Int32 lastRec, 
+Int32 *deletedTo,
+Logical *total)
 {
   CDFstatus pStatus = CDF_OK; Int32 vxrOffset = firstVXRoffset;
   struct VXRstruct VXR; int entryN;
@@ -1229,15 +1230,14 @@ Logical *total;
 * DeleteFromFront.
 ******************************************************************************/
 
-static CDFstatus DeleteFromFront (CDF, Var, last, vxrOffset, VXR, entryN,
-				  irSize)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-Int32 last;
-Int32 vxrOffset;
-struct VXRstruct *VXR;
-int entryN;
-Int32 irSize;
+static CDFstatus DeleteFromFront (
+struct CDFstruct *CDF, 
+struct VarStruct *Var,
+Int32 last, 
+Int32 vxrOffset,
+struct VXRstruct *VXR, 
+int entryN,
+Int32 irSize)
 {
   CDFstatus pStatus = CDF_OK;
   switch (Var->vType) {
@@ -1355,16 +1355,15 @@ Int32 irSize;
 * DeleteFromMiddle.
 ******************************************************************************/
 
-static CDFstatus DeleteFromMiddle (CDF, Var, first, last, vxrOffset, VXR,
-				   entryN, irSize)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-Int32 first;
-Int32 last;
-Int32 vxrOffset;
-struct VXRstruct *VXR;
-int entryN;
-Int32 irSize;
+static CDFstatus DeleteFromMiddle (
+struct CDFstruct *CDF,
+struct VarStruct *Var, 
+Int32 first,
+Int32 last, 
+Int32 vxrOffset,
+struct VXRstruct *VXR, 
+int entryN,
+Int32 irSize)
 {
   CDFstatus pStatus = CDF_OK;
   switch (Var->vType) {
@@ -1579,15 +1578,14 @@ Int32 irSize;
 * DeleteFromEnd.
 ******************************************************************************/
 
-static CDFstatus DeleteFromEnd (CDF, Var, first, vxrOffset, VXR, entryN,
-				irSize)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-Int32 first;
-Int32 vxrOffset;
-struct VXRstruct *VXR;
-int entryN;
-Int32 irSize;
+static CDFstatus DeleteFromEnd (
+struct CDFstruct *CDF, 
+struct VarStruct *Var,
+Int32 first, 
+Int32 vxrOffset,
+struct VXRstruct *VXR, 
+int entryN,
+Int32 irSize)
 {
   CDFstatus pStatus = CDF_OK;
   switch (Var->vType) {
@@ -1688,13 +1686,12 @@ Int32 irSize;
 * DeleteVXRentry.
 ******************************************************************************/
 
-static CDFstatus DeleteVXRentry (CDF, firstVXRoffset, delVXRoffset, delEntryN,
-				 total)
-struct CDFstruct *CDF;
-Int32 firstVXRoffset;
-Int32 delVXRoffset;
-int delEntryN;
-Logical *total;
+static CDFstatus DeleteVXRentry (
+struct CDFstruct *CDF, 
+Int32 firstVXRoffset,
+Int32 delVXRoffset, 
+int delEntryN,
+Logical *total)
 {
   CDFstatus pStatus = CDF_OK;
   Int32 vxrOffset = firstVXRoffset, prevVXRoffset = ZERO_OFFSET;
@@ -1781,16 +1778,15 @@ Logical *total;
 * InsertIndexEntry.
 ******************************************************************************/
 
-static CDFstatus InsertIndexEntry (CDF, vxrOffset, entryN, after, first, last,
-				   offset)
-struct CDFstruct *CDF;
-Int32 vxrOffset;
-int entryN;
-Logical after;          /* TRUE: Insert the new entry after `entryN'.
-			   FALSE: Insert the new entry at `entryN'. */
-Int32 first;
-Int32 last;
-Int32 offset;
+static CDFstatus InsertIndexEntry (
+struct CDFstruct *CDF, 
+Int32 vxrOffset,
+int entryN, 
+Logical after,          /* TRUE: Insert the new entry after `entryN'.
+                           FALSE: Insert the new entry at `entryN'. */
+Int32 first,
+Int32 last, 
+Int32 offset)
 {
   CDFstatus pStatus = CDF_OK; struct VXRstruct VXR; int eN, lastEntryN;
   Int32 pushedFirst, pushedLast, pushedOffset, newVXRoffset;
@@ -1903,11 +1899,11 @@ Int32 offset;
 * UpdateIndexEntries_r.
 ******************************************************************************/
 
-static CDFstatus UpdateIndexEntries_r (fp, vxrOffset, aboveRecord, recordCount)
-vFILE *fp;
-Int32 vxrOffset;
-Int32 aboveRecord;
-Int32 recordCount;
+static CDFstatus UpdateIndexEntries_r (
+vFILE *fp, 
+Int32 vxrOffset,
+Int32 aboveRecord, 
+Int32 recordCount)
 {
   CDFstatus pStatus = CDF_OK; struct VXRstruct VXR; int entryN; Int32 irType;
   while (vxrOffset != ZERO_OFFSET) {
@@ -1950,12 +1946,12 @@ Int32 recordCount;
 * WriteCVVRorVVR.
 ******************************************************************************/
 
-static CDFstatus WriteCVVRorVVR (CDF, cSize, stageOffset, uSize, newOffset)
-struct CDFstruct *CDF;
-Int32 cSize;
-Int32 stageOffset;
-Int32 uSize;
-Int32 *newOffset;
+static CDFstatus WriteCVVRorVVR (
+struct CDFstruct *CDF, 
+Int32 cSize,
+Int32 stageOffset, 
+Int32 uSize,
+Int32 *newOffset)
 {
   CDFstatus pStatus = CDF_OK; Int32 recordSize, tOffset;
   if (CVVR_BASE_SIZE + cSize < VVR_BASE_SIZE + uSize) {
