@@ -38,9 +38,9 @@
 * CDFget.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CDFget (Va, Cur)
-struct VAstruct *Va;
-struct CurStruct *Cur;
+STATICforIDL CDFstatus CDFget (
+struct VAstruct *Va, 
+struct CurStruct *Cur)
 {
 CDFstatus tStatus, pStatus = CDF_OK;
 
@@ -1956,7 +1956,7 @@ switch (Va->item) {
       return pStatus;
     }
     if (!STRINGdataType(dataType)) return TRY_TO_READ_NONSTRING_DATA;
-    tmp = (char *) malloc((size_t)numElems+1);
+    tmp = (char *) cdf_AllocateMemory((size_t)numElems+1, NULL);
     if (!sX(ReadAEDR(CDF->fp,offset,
                      AEDR_NUMSTRINGS,numStrings,
                      AEDR_VALUE,tmp,
@@ -1968,7 +1968,7 @@ switch (Va->item) {
     /* Pre-3.7.0, the field was used and filled with 0. */
     if (*numStrings < 1) *numStrings = 1;
     StringBreakIntoStrings (tmp, numElems, *numStrings, strings);
-    free (tmp);
+    cdf_FreeMemory (tmp, NULL);
     tmp = NULL;
     break;
   }
