@@ -44,9 +44,9 @@
 * CDFget64.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CDFget64 (Va, Cur)
-struct VAstruct *Va;
-struct CurStruct *Cur;
+STATICforIDL CDFstatus CDFget64 (
+struct VAstruct *Va,
+struct CurStruct *Cur)
 {
 CDFstatus tStatus, pStatus = CDF_OK;
 
@@ -61,7 +61,7 @@ switch (Va->item) {
     long *cType, *cParms; 
     void *cFileSize, *uFileSize;
     long cSize2 = 0L, uSize2 = 0L;
-    OFF_T cSize3, uSize3;
+    size_t cSize3, uSize3;
     int whichVersion = 3;
     CDFpathP = va_arg (Va->ap, char *);
     cType = va_arg (Va->ap, long *);
@@ -210,7 +210,7 @@ switch (Va->item) {
 	      return CDF_READ_ERROR;
 	    }
 	    cSize3 = V_tell64 (dotFp);
-	    uSize3 = (OFF_T) CCR.uSize + MAGIC_NUMBERS_SIZE;
+	    uSize3 = CCR.uSize + MAGIC_NUMBERS_SIZE;
 	    V_close64 (dotFp, NULL, NULL);
 	    break;
 	  }
@@ -230,8 +230,8 @@ switch (Va->item) {
       memcpy((long *)cFileSize, &cSize2, sizeof(long));
       memcpy((long *)uFileSize, &uSize2, sizeof(long));
     } else {
-      memcpy((OFF_T *)cFileSize, &cSize3, sizeof(OFF_T));
-      memcpy((OFF_T *)uFileSize, &uSize3, sizeof(OFF_T));
+      memcpy((OFF_T *)cFileSize, &cSize3, sizeof(size_t));
+      memcpy((OFF_T *)uFileSize, &uSize3, sizeof(size_t));
     }
     break;
   }
@@ -367,7 +367,7 @@ switch (Va->item) {
     long *cParms = va_arg (Va->ap, long *);     /* Compression parameters. */
     long *cPct = va_arg (Va->ap, long *);	/* Compression percentage. */
     struct CDFstruct *CDF; struct CCRstruct64 CCR; struct CPRstruct64 CPR;
-    int i; OFF_T cTotal, uTotal;
+    int i; size_t cTotal, uTotal;
     SelectCDF (Cur->cdf, CDF)
     /**************************************************************************
     * If multi-file or uncompressed...
@@ -2065,7 +2065,7 @@ switch (Va->item) {
       return pStatus;
     }
     if (!STRINGdataType(dataType)) return TRY_TO_READ_NONSTRING_DATA;
-    tmp = (char *) malloc((size_t)numElems+1);
+    tmp = (char *) cdf_AllocateMemory((size_t)numElems+1, NULL);
     if (!sX(ReadAEDR64(CDF->fp,offset,
 		       AEDR_NUMSTRINGS,numStrings,
 		       AEDR_VALUE,tmp,
@@ -2077,7 +2077,7 @@ switch (Va->item) {
     /* Pre-3.7.0, the field was used and filled with 0. */ 
     if (*numStrings < 1) *numStrings = 1;
     StringBreakIntoStrings (tmp, numElems, *numStrings, strings);
-    free (tmp);
+    cdf_FreeMemory (tmp, NULL);
     tmp = NULL;
     break;
   }
