@@ -22,8 +22,8 @@
 *
 ******************************************************************************/
 
-#include "zlib/zconf.h"
-#include "zlib/zlib.h"
+#include "zconf.h"
+#include "zlib.h"
 #include "cdflib.h"
 
 #define CHUNK MIN_BLOCKING_BYTES_compressed
@@ -33,7 +33,7 @@
  ****************************************************************************/
 static int defgzip(vFILE *src, vFILE *dst, Int32 iSize, Int32 *osize,
                    int level);
-static int infgzip(vFILE *src, Int32 iSize, vFILE *dst);
+static int infgzip(vFILE *src, Int32 iSize, vFILE *dst, Int32 oSize);
 
 /* Compress from file source to file dest until EOF on source.
    defgzip() returns CDF_OK on success, or ZLIB_COMPRESS_ERROR for any error,
@@ -48,45 +48,43 @@ static int defgzip(vFILE *source, vFILE *dest, Int32 iSize, Int32 *osize,
     int ret, flush;
     unsigned have;
     z_stream strm;
-    uChar in[CHUNK];
-    uChar out[CHUNK];
-    Int32 remaining; 
-    unsigned mySize;
-    int nBytes;
+    uChar in[CHUNK+256];
+    uChar out[CHUNK+256];
+    Int32 remaining, iRead, oWrite, extra; 
 
-    nBytes = 0;
     *osize = 0;
     strm.zalloc = Z_NULL;
     strm.zfree = Z_NULL;
     strm.opaque = Z_NULL;
+    extra = CHUNK + 256;
     ret = deflateInit2(&strm, level, Z_DEFLATED, MAX_WBITS+16, 8, 0);
     if (ret != Z_OK) return ZLIB_COMPRESS_ERROR;
     remaining = iSize;
     do {
-        if (remaining > CHUNK) mySize = CHUNK;
-        else mySize = (unsigned) remaining;
-        strm.avail_in = (unsigned) V_read(in, (size_t) 1, (size_t) mySize,
+        if (remaining > extra) iRead = extra;
+        else iRead = remaining;
+        strm.avail_in = (unsigned) V_read(in, (size_t) 1, (size_t) iRead,
                                           source);
-        flush = (remaining == (Int32) mySize) ? Z_FINISH : Z_NO_FLUSH;
+        flush = (remaining == iRead) ? Z_FINISH : Z_NO_FLUSH;
         strm.next_in = in;
         do {
-            strm.avail_out = CHUNK;
+            strm.avail_out = extra;
             strm.next_out = out;
             ret = deflate(&strm, flush);
             if (ret == Z_STREAM_ERROR)
               return ZLIB_COMPRESS_ERROR;
-            have = CHUNK - strm.avail_out;
+            have = extra - strm.avail_out;
             if (have > 0) {
 	      if (V_write(out, 1, (size_t) have, dest) != (size_t) have) {
 		(void) deflateEnd(&strm);
-		return ZLIB_COMPRESS_ERROR;
+		return VAR_WRITE_ERROR;
 	      }
 	      *osize += have;
 	    }
         } while (strm.avail_out == 0);
         if (strm.avail_in != 0)
           return ZLIB_COMPRESS_ERROR;
-        remaining -= (OFF_T) mySize;
+        remaining -= iRead;
     } while (flush != Z_FINISH);
     if (ret != Z_STREAM_END)
       return ZLIB_COMPRESS_ERROR;
@@ -101,16 +99,19 @@ static int defgzip(vFILE *source, vFILE *dest, Int32 iSize, Int32 *osize,
    the version of the library linked do not match, or if there
    is an error reading or writing the files. */
 
-static int infgzip(vFILE *source, Int32 iSize, vFILE *dest)
+static int infgzip(vFILE *source, Int32 iSize, vFILE *dest, Int32 oSize)
 {
     int ret;
     unsigned int have;
     z_stream strm;
     uChar in[CHUNK];
     uChar out[CHUNK];
-    int nBytes;
+    Int32 iRead, oWrite;
 
-    nBytes = 0;
+    if (iSize > CHUNK) iRead = CHUNK;
+    else iRead = iSize;
+    if (oSize > CHUNK) oWrite = CHUNK;
+    else oWrite = oSize;
     strm.zalloc = Z_NULL;
     strm.zfree = Z_NULL;
     strm.opaque = Z_NULL;
@@ -119,13 +120,13 @@ static int infgzip(vFILE *source, Int32 iSize, vFILE *dest)
     ret = inflateInit2(&strm, 15+16);
     if (ret != Z_OK) return ZLIB_UNCOMPRESS_ERROR;
     do {
-        strm.avail_in = (unsigned) V_read(in, (size_t) 1, (size_t) CHUNK,
+        strm.avail_in = (unsigned) V_read(in, (size_t) 1, (size_t) iRead,
                                           source);
         ret = source->eof ? Z_STREAM_END : Z_NO_FLUSH;
         if (strm.avail_in == 0) break;
         strm.next_in = in;
         do {
-            strm.avail_out = CHUNK;
+            strm.avail_out = oWrite;
             strm.next_out = out;
             ret = inflate(&strm, Z_NO_FLUSH);
             if (ret == Z_STREAM_ERROR)
@@ -137,7 +138,7 @@ static int infgzip(vFILE *source, Int32 iSize, vFILE *dest)
                 (void) inflateEnd(&strm);
                 return ZLIB_UNCOMPRESS_ERROR;
             }
-            have = CHUNK - strm.avail_out;
+            have = oWrite - strm.avail_out;
             if (have > 0) {
               if (V_write(out, 1, (size_t) have, dest) != (size_t) have) {
                 (void) inflateEnd(&strm);
@@ -155,18 +156,16 @@ static int infgzip(vFILE *source, Int32 iSize, vFILE *dest)
 * CompressGZIP.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CompressGZIP (srcFp, srcOffset, srcSize, srcError,
-                                     destFp, destOffset, destSize, destError,
-                                     level)
-vFILE *srcFp;
-Int32 srcOffset;
-Int32 srcSize;
-CDFstatus srcError;
-vFILE *destFp;
-Int32 destOffset;
-Int32 *destSize;
-CDFstatus destError;
-Int32 level;
+STATICforIDL CDFstatus CompressGZIP (
+vFILE *srcFp,
+Int32 srcOffset,
+Int32 srcSize,
+CDFstatus srcError,
+vFILE *destFp,
+Int32 destOffset,
+Int32 *destSize,
+CDFstatus destError,
+Int32 level)
 {
 #if SUPPORT_GZIP
   CDFstatus pStatus = CDF_OK;
@@ -184,21 +183,21 @@ Int32 level;
 * DecompressGZIP.
 ******************************************************************************/
 
-STATICforIDL CDFstatus DecompressGZIP (srcFp, srcOffset, iSize, srcError,
-                                       destFp, destOffset, destError)
-vFILE *srcFp;
-Int32 srcOffset;
-Int32 iSize;
-CDFstatus srcError;
-vFILE *destFp;
-Int32 destOffset;
-CDFstatus destError;
+STATICforIDL CDFstatus DecompressGZIP (
+vFILE *srcFp,
+Int32 srcOffset,
+Int32 iSize,
+CDFstatus srcError,
+vFILE *destFp,
+Int32 destOffset,
+Int32 oSize,
+CDFstatus destError)
 {
 #if SUPPORT_GZIP
   CDFstatus pStatus = CDF_OK;
   if (!SEEKv(srcFp,srcOffset,vSEEK_SET)) return srcError;
   if (!SEEKv(destFp,destOffset,vSEEK_SET)) return destError;
-  if (!sX(infgzip(srcFp,iSize,destFp),&pStatus)) return pStatus;
+  if (!sX(infgzip(srcFp,iSize,destFp,oSize),&pStatus)) return pStatus;
   return pStatus;
 #else
   return UNKNOWN_COMPRESSION;
