@@ -205,16 +205,15 @@ static DWORD InputBits PROTOARGs((BIT_FILE *bit_file, int bit_count));
 * CompressHUFF0.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CompressHUFF0 (input, iOffset, iSize, iError,
-				      oFp, oOffset, oSize, oError)
-vFILE *input;
-Int32 iOffset;
-Int32 iSize;
-CDFstatus iError;
-vFILE *oFp;
-Int32 oOffset;
-Int32 *oSize;
-CDFstatus oError;
+STATICforIDL CDFstatus CompressHUFF0 (
+vFILE *input,
+Int32 iOffset,
+Int32 iSize,
+CDFstatus iError,
+vFILE *oFp,
+Int32 oOffset,
+Int32 *oSize,
+CDFstatus oError)
 {
 #if SUPPORT_HUFF
   BIT_FILE *output; DWORD *counts; NODE *nodes; CODE *codes; 
@@ -293,14 +292,13 @@ CDFstatus oError;
 * DecompressHUFF0.
 ******************************************************************************/
 
-STATICforIDL CDFstatus DecompressHUFF0 (iFp, iOffset, iError,
-					output, oOffset, oError)
-vFILE *iFp;
-Int32 iOffset;
-CDFstatus iError;
-vFILE *output;
-Int32 oOffset;
-CDFstatus oError;
+STATICforIDL CDFstatus DecompressHUFF0 (
+vFILE *iFp,
+Int32 iOffset,
+CDFstatus iError,
+vFILE *output,
+Int32 oOffset,
+CDFstatus oError)
 {
 #if SUPPORT_HUFF
   CDFstatus pStatus = CDF_OK; BIT_FILE *input; NODE *nodes; int root_node;
@@ -348,16 +346,15 @@ CDFstatus oError;
  * will later be able to use this symbol to know when to quit.
  */
 
-STATICforIDL CDFstatus CompressAHUFF0 (input, iOffset, iSize, iError,
-				       oFp, oOffset, oSize, oError)
-vFILE *input;
-Int32 iOffset;
-Int32 iSize;
-CDFstatus iError;
-vFILE *oFp;
-Int32 oOffset;
-Int32 *oSize;
-CDFstatus oError;
+STATICforIDL CDFstatus CompressAHUFF0 (
+vFILE *input,
+Int32 iOffset,
+Int32 iSize,
+CDFstatus iError,
+vFILE *oFp,
+Int32 oOffset,
+Int32 *oSize,
+CDFstatus oError)
 {
 #if SUPPORT_AHUFF
   CDFstatus pStatus = CDF_OK; BIT_FILE *output; TREE *Tree;
@@ -412,14 +409,13 @@ CDFstatus oError;
 * DecompressAHUFF0.
 ******************************************************************************/
 
-STATICforIDL CDFstatus DecompressAHUFF0 (iFp, iOffset, iError,
-					 output, oOffset, oError)
-vFILE *iFp;
-Int32 iOffset;
-CDFstatus iError;
-vFILE *output;
-Int32 oOffset;
-CDFstatus oError;
+STATICforIDL CDFstatus DecompressAHUFF0 (
+vFILE *iFp,
+Int32 iOffset,
+CDFstatus iError,
+vFILE *output,
+Int32 oOffset,
+CDFstatus oError)
 {
 #if SUPPORT_AHUFF
   CDFstatus pStatus = CDF_OK; BIT_FILE *input; TREE *Tree; int c;
@@ -488,9 +484,9 @@ CDFstatus oError;
  * simpler, but would hurt compression quite a bit on small files.
  *
  */
-static Logical output_counts (output, nodes)
-BIT_FILE *output;
-NODE *nodes;
+static Logical output_counts (
+BIT_FILE *output,
+NODE *nodes)
 {
     int first;
     int last;
@@ -552,10 +548,10 @@ NODE *nodes;
  * work.
  */
 
-static Logical count_bytes( input, counts, iSize )
-vFILE *input;
-DWORD *counts;
-Int32 iSize;
+static Logical count_bytes(
+vFILE *input,
+DWORD *counts,
+Int32 iSize)
 {
     long input_marker;
     int c;
@@ -585,9 +581,9 @@ Int32 iSize;
  * careful of is to make sure that a node with a non-zero count doesn't
  * get scaled down to 0.  Nodes with values of 0 don't get codes.
  */
-static void scale_counts( counts, nodes )
-DWORD *counts;
-NODE *nodes;
+static void scale_counts(
+DWORD *counts,
+NODE *nodes)
 {
     DWORD max_count;
     int i;
@@ -630,8 +626,8 @@ NODE *nodes;
  * nodes have been scanned, I can tell if there is only one active node
  * left by checking to see if min_1 is still 513.
  */
-static int build_tree( nodes )
-NODE *nodes;
+static int build_tree(
+NODE *nodes)
 {
     int next_free;
     int i;
@@ -679,12 +675,12 @@ NODE *nodes;
  * to a leaf, it stores the code value in the CODE element, and
  * returns.
  */
-static void convert_tree_to_code( nodes, codes, code_so_far, bits, node )
-NODE *nodes;
-CODE *codes;
-INT4 code_so_far;
-int bits;
-int node;
+static void convert_tree_to_code(
+NODE *nodes,
+CODE *codes,
+INT4 code_so_far,
+int bits,
+int node)
 {
   if (node <= END_OF_STREAM) {
     codes[node].code = (WORD) code_so_far;
@@ -710,13 +706,13 @@ int node;
  * Huffman code is sent out.
  */
 
-static CDFstatus compress_data( input, output, codes, iSize, iError, oError)
-vFILE *input;
-BIT_FILE *output;
-CODE *codes;
-Int32 iSize;
-CDFstatus iError;
-CDFstatus oError;
+static CDFstatus compress_data(
+vFILE *input,
+BIT_FILE *output,
+CODE *codes,
+Int32 iSize,
+CDFstatus iError,
+CDFstatus oError)
 {
     int c;
     long i;
@@ -738,8 +734,8 @@ CDFstatus oError;
 * StartBitFile.
 ******************************************************************************/
 
-static BIT_FILE *StartBitFile (fp)
-vFILE *fp;
+static BIT_FILE *StartBitFile (
+vFILE *fp)
 {
   BIT_FILE *bit_file;
   bit_file = (BIT_FILE *) CallocateMemory (1, sizeof(BIT_FILE), NULL);
@@ -756,8 +752,8 @@ vFILE *fp;
 * EndOutputBitFile.
 ******************************************************************************/
 
-static Logical EndOutputBitFile (bit_file)
-BIT_FILE *bit_file;
+static Logical EndOutputBitFile (
+BIT_FILE *bit_file)
 {
   Logical status = TRUE;
   if (bit_file->mask != 0x80) {
@@ -774,8 +770,8 @@ BIT_FILE *bit_file;
 * EndInputBitFile.
 ******************************************************************************/
 
-static Logical EndInputBitFile (bit_file)
-BIT_FILE *bit_file;
+static Logical EndInputBitFile (
+BIT_FILE *bit_file)
 {
   cdf_FreeMemory (bit_file, NULL);
   return TRUE;
@@ -787,10 +783,10 @@ BIT_FILE *bit_file;
 * OutputBits.
 ******************************************************************************/
 
-static Logical OutputBits( bit_file, code, count )
-BIT_FILE *bit_file;
-DWORD code;
-int count;
+static Logical OutputBits(
+BIT_FILE *bit_file,
+DWORD code,
+int count)
 {
     DWORD mask;
 
@@ -816,8 +812,8 @@ int count;
 * InputBit.
 ******************************************************************************/
 
-static int InputBit (bit_file)
-BIT_FILE *bit_file;
+static int InputBit (
+BIT_FILE *bit_file)
 {
     int value;
     if ( bit_file->mask == 0x80 ) {
@@ -836,9 +832,9 @@ BIT_FILE *bit_file;
 * InputBits.
 ******************************************************************************/
 
-static DWORD InputBits( bit_file, bit_count )
- BIT_FILE *bit_file;
- int bit_count;
+static DWORD InputBits(
+ BIT_FILE *bit_file,
+ int bit_count)
 {
     DWORD mask;
     DWORD return_value;
@@ -871,9 +867,9 @@ static DWORD InputBits( bit_file, bit_count )
  * counts.
  */
 
-static Logical input_counts( input, nodes )
-BIT_FILE *input;
-NODE *nodes;
+static Logical input_counts(
+BIT_FILE *input,
+NODE *nodes)
 {
     int first;
     int last;
@@ -910,13 +906,13 @@ NODE *nodes;
  * is the END_OF_STREAM symbol, it doesn't get written out, and
  * instead the whole process terminates.
  */
-static CDFstatus expand_data( input, output, nodes, root_node, iError, oError)
-BIT_FILE *input;
-vFILE *output;
-NODE *nodes;
-int root_node;
-CDFstatus iError;
-CDFstatus oError;
+static CDFstatus expand_data(
+BIT_FILE *input,
+vFILE *output,
+NODE *nodes,
+int root_node,
+CDFstatus iError,
+CDFstatus oError)
 {
     int node;
 
@@ -958,8 +954,8 @@ CDFstatus oError;
  * Huffman tree yet.
  */
 
-static void InitializeTree( tree )
-TREE *tree;
+static void InitializeTree(
+TREE *tree)
 {
     int i;
 
@@ -1003,10 +999,10 @@ TREE *tree;
  * if desired.
  */
 
-static Logical EncodeSymbol( tree, c, output )
-TREE *tree;
-INT4 c;
-BIT_FILE *output;
+static Logical EncodeSymbol(
+TREE *tree,
+INT4 c,
+BIT_FILE *output)
 {
     DWORD code;
     DWORD current_bit;
@@ -1048,9 +1044,9 @@ BIT_FILE *output;
  * and add the new symbol to the table.
  */
 
-static int DecodeSymbol (tree, input)
-TREE *tree;
-BIT_FILE *input;
+static int DecodeSymbol (
+TREE *tree,
+BIT_FILE *input)
 {
     int current_node;
     int c;
@@ -1088,9 +1084,9 @@ BIT_FILE *input;
  * place.
  */
 
-static void UpdateModel( tree, c )
-TREE *tree;
-int c;
+static void UpdateModel(
+TREE *tree,
+int c)
 {
     int current_node;
     int new_node;
@@ -1127,8 +1123,8 @@ int c;
  * up due to cumulative increases, while others may move down.
  */
 
-static void RebuildTree( tree )
-TREE *tree;
+static void RebuildTree(
+TREE *tree)
 {
     int i;
     int j;
@@ -1206,10 +1202,10 @@ TREE *tree;
  * tree by exchanging the children under i with the children under j.
  */
 
-static void swap_nodes( tree, i, j )
-TREE *tree;
-int i;
-int j;
+static void swap_nodes(
+TREE *tree,
+int i,
+int j)
 {
     struct node temp;
 
@@ -1251,9 +1247,9 @@ int j;
  * the tree would be broken.
  */
 
-static void add_new_node( tree, c )
-TREE *tree;
-int c;
+static void add_new_node(
+TREE *tree,
+int c)
 {
     int lightest_node;
     int new_node;
