@@ -63,8 +63,9 @@ typedef struct memSTRUCT {	/* Structure. */
   int id;
 } MEM;
 typedef MEM *MEMp;		/* Pointer (to structure). */
+#if MEMLOG
 static MEMp memHeadP = NULL;	/* Head of memory linked list. */
-
+#endif
 typedef struct CDFidSTRUCT {	/* Structure. */
   void *ptr;
   struct CDFidSTRUCT *next;
@@ -172,23 +173,21 @@ static uLongx TotalBytes PROTOARGs((MEMp memHeadP));
 * cdf_AllocateMemory.
 ******************************************************************************/
 
-VISIBLE_PREFIX void *cdf_AllocateMemory (nBytes, fatalFnc)
-size_t nBytes;
-void (*fatalFnc) PROTOARGs((char *msg));
+VISIBLE_PREFIX void *cdf_AllocateMemory (
+size_t nBytes,
+void (*fatalFnc) PROTOARGs((char *msg)))
 {
+void *p;
 #if defined(BUILDINGforIDL)
   /* ++numAllocs; */  /* printf("(+1)numAllocs=%ld\n",numAllocs); */
-  return malloc(nBytes);
+  return malloc (nBytes);
 #else
-  MEMp mem;
-#if defined(linux) || defined(__CYGWIN__)
-#endif
   if (nBytes < 1) {
     ALLOCFAILED("A",1,nBytes)
     return NULL;
   }
   /* ++numAllocs; */   /* printf("(+1)numAllocs=%ld\n",numAllocs); */
-  return malloc(nBytes);
+  return malloc (nBytes);
 #endif
 }
 
@@ -196,10 +195,10 @@ void (*fatalFnc) PROTOARGs((char *msg));
 * cdf_ReallocateMemory.
 ******************************************************************************/
 
-VISIBLE_PREFIX void *cdf_ReallocateMemory (ptr, nBytes, fatalFnc)
-void *ptr;
-size_t nBytes;
-void (*fatalFnc) PROTOARGs((char *msg));
+VISIBLE_PREFIX void *cdf_ReallocateMemory (
+void *ptr,
+size_t nBytes,
+void (*fatalFnc) PROTOARGs((char *msg)))
 {
 #if defined(BUILDINGforIDL)
   return realloc(ptr,nBytes);
@@ -220,9 +219,9 @@ void (*fatalFnc) PROTOARGs((char *msg));
 * allocated memory blocks.
 ******************************************************************************/
 
-VISIBLE_PREFIX int cdf_FreeMemory (ptr, fatalFnc)
-void *ptr;
-void (*fatalFnc) PROTOARGs((char *msg));
+VISIBLE_PREFIX int cdf_FreeMemory (
+void *ptr,
+void (*fatalFnc) PROTOARGs((char *msg)))
 {
 #if defined(BUILDINGforIDL)
   /* --numAllocs; */  /* printf("(-1)numAllocs=%ld\n",numAllocs); */
@@ -244,13 +243,13 @@ void (*fatalFnc) PROTOARGs((char *msg));
 * Used for saving the CDFid pointer in 64-bit mode for Fortran interface.
 ******************************************************************************/
 
-VISIBLE_PREFIX void cdfid_AllocateMemory (id, fatalFnc)
-void *id;
-void (*fatalFnc) PROTOARGs((char *msg));
+VISIBLE_PREFIX void cdfid_AllocateMemory (
+void *id,
+void (*fatalFnc) PROTOARGs((char *msg)))
 {
   CDFidMEMp mem;
   /* ++numAlloc3; */  /* printf("(+1)numAlloc3=%ld\n",numAlloc3); */
-  mem = (CDFidMEMp) malloc (sizeof(CDFidMEM));
+  mem = (CDFidMEMp) cdf_AllocateMemory (sizeof(CDFidMEM), NULL);
   if (mem == NULL) {
     if (fatalFnc != NULL) (*fatalFnc)("Unable to allocate memory buffer [1].");
     return;
@@ -265,9 +264,9 @@ void (*fatalFnc) PROTOARGs((char *msg));
 * Return 8-byte CDF id based on the 4-byte information from Fortran interface.
 ******************************************************************************/
 
-VISIBLE_PREFIX CDFid cdfid_getCDFid (shortId, fatalFnc)
-Int32 shortId;
-void (*fatalFnc) PROTOARGs((char *msg));
+VISIBLE_PREFIX CDFid cdfid_getCDFid (
+Int32 shortId,
+void (*fatalFnc) PROTOARGs((char *msg)))
 {
   CDFidMEMp mem = cdfidHeadP;
   union {
@@ -289,9 +288,9 @@ void (*fatalFnc) PROTOARGs((char *msg));
 * allocated memory blocks.
 ******************************************************************************/
 
-VISIBLE_PREFIX int cdfid_FreeMemory (ptr, fatalFnc)
-void *ptr;
-void (*fatalFnc) PROTOARGs((char *msg));
+VISIBLE_PREFIX int cdfid_FreeMemory (
+void *ptr,
+void (*fatalFnc) PROTOARGs((char *msg)))
 {
   if (ptr == NULL) {
     int count = 0;
@@ -300,7 +299,7 @@ void (*fatalFnc) PROTOARGs((char *msg));
       CDFidMEMp memX = mem;
       mem = mem->next;
       FREESUCCESS("NULL",memX->ptr,8)
-      free (memX);
+      cdf_FreeMemory (memX, NULL);
       memX = NULL;
       /* --numAlloc3; */  /* printf("(-1)numAlloc3=%ld\n",numAlloc3); */
       count++;
@@ -317,7 +316,7 @@ void (*fatalFnc) PROTOARGs((char *msg));
 	else
 	  memPrev->next = mem->next;
         FREESUCCESS("one",memX->ptr,8)
-	free (memX);
+	cdf_FreeMemory (memX, NULL);
 	memX = NULL;
         /* --numAlloc3; */   /* printf("(-1)numAlloc3=%ld\n",numAlloc3); */
 	return 1;
@@ -337,10 +336,10 @@ void (*fatalFnc) PROTOARGs((char *msg));
 * allocated memory blocks.
 ******************************************************************************/
 
-VISIBLE_PREFIX int cdf_FreeMemoryX (ptr, fatalFnc, loc)
-void *ptr;
-void (*fatalFnc) PROTOARGs((char *msg));
-int loc;
+VISIBLE_PREFIX int cdf_FreeMemoryX (
+void *ptr,
+void (*fatalFnc) PROTOARGs((char *msg)),
+int loc)
 {
 #if defined(BUILDINGforIDL)
    /* --numAlloc2; */  /* printf("(-1)numAlloc2=%ld\n",numAlloc2); */
@@ -363,10 +362,10 @@ int loc;
 * be cleared faster than the loop used here.
 ******************************************************************************/
 
-VISIBLE_PREFIX void *CallocateMemory (nObjects, objSize, fatalFnc)
-size_t nObjects;
-size_t objSize;
-void (*fatalFnc) PROTOARGs((char *msg));
+VISIBLE_PREFIX void *CallocateMemory (
+size_t nObjects,
+size_t objSize,
+void (*fatalFnc) PROTOARGs((char *msg)))
 {
 #if defined(BUILDINGforIDL)
   return calloc(nObjects,objSize);
@@ -476,7 +475,7 @@ MEMp memHeadP;
 * Display malloc/free counts.
 ******************************************************************************/
 
-VISIBLE_PREFIX void ShowMemoryAllocCounts ()
+VISIBLE_PREFIX void ShowMemoryAllocCounts (void)
 {
   if (numAllocs != 0 || numAlloc2 != 0 || numAlloc3 != 0)
     fprintf(stdout, "*** cdf_Allocate/cdf_Free: %ld\n    numAlloc2: %ld\n"
