@@ -49,8 +49,8 @@
 * CorrectV20eof.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CorrectV20eof (CDF)
-struct CDFstruct *CDF;
+STATICforIDL CDFstatus CorrectV20eof (
+struct CDFstruct *CDF)
 {
   CDFstatus pStatus = CDF_OK;
   Int32 eof = 0, size, vOffset, aOffset, eOffset, nAttrs, nEntries;
@@ -131,8 +131,8 @@ struct CDFstruct *CDF;
 * CorrectV20offsets.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CorrectV20offsets (CDF)
-struct CDFstruct *CDF;
+STATICforIDL CDFstatus CorrectV20offsets (
+struct CDFstruct *CDF)
 {
   CDFstatus pStatus = CDF_OK;
   Int32 zero = 0, size, vOffset, aOffset, eOffset, nAttrs, nEntries;
@@ -218,8 +218,8 @@ struct CDFstruct *CDF;
 * it, the data will be properly preserved.
 ******************************************************************************/
 
-VISIBLE_PREFIX CDFstatus UpdateDotCDF (CDF)
-struct CDFstruct *CDF;
+VISIBLE_PREFIX CDFstatus UpdateDotCDF (
+struct CDFstruct *CDF)
 {
   CDFstatus pStatus = CDF_OK; int varN; struct VarStruct *Var; Logical zVar;
   /**************************************************************************
@@ -269,9 +269,9 @@ struct CDFstruct *CDF;
 * FlushAllVarStages.
 ******************************************************************************/
 
-VISIBLE_PREFIX CDFstatus FlushAllVarStages (CDF, Vare)
-struct CDFstruct *CDF;
-struct VarStruct *Vare;
+VISIBLE_PREFIX CDFstatus FlushAllVarStages (
+struct CDFstruct *CDF,
+struct VarStruct *Vare)
 {
   CDFstatus pStatus = CDF_OK; int varN; struct VarStruct *Var; Logical zVar;
   /**************************************************************************
@@ -305,9 +305,9 @@ struct VarStruct *Vare;
 * would cause a temporary file(s) being created.
 ******************************************************************************/
 
-VISIBLE_PREFIX Logical CheckForOverCaches (CDF, Var)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
+VISIBLE_PREFIX Logical CheckForOverCaches (
+struct CDFstruct *CDF,
+struct VarStruct *Var)
 {
   Int32 numCaches, remaining, numRecs;
   Int32 totalBytes;
@@ -335,8 +335,8 @@ struct VarStruct *Var;
 * initialized when the CDF was aborted.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CloseVarFiles (CDF)
-struct CDFstruct *CDF;
+STATICforIDL CDFstatus CloseVarFiles (
+struct CDFstruct *CDF)
 {
   CDFstatus pStatus = CDF_OK; struct VarStruct *Var; int varN;
   /****************************************************************************
@@ -386,10 +386,10 @@ struct CDFstruct *CDF;
 * it would be a waste of time to do these things).
 ******************************************************************************/
 
-STATICforIDL Logical WriteAccess (CDF, forDelete, pStatus)
-struct CDFstruct *CDF;
-Logical forDelete;      /* Is the write access is needed to delete the CDF? */
-CDFstatus *pStatus;	/* Returned status. */
+STATICforIDL Logical WriteAccess (
+struct CDFstruct *CDF,
+Logical forDelete,      /* Is the write access is needed to delete the CDF? */
+CDFstatus *pStatus)	/* Returned status. */
 {
 #if BUILD_READ_ONLY_DISTRIBUTION
    *pStatus = READ_ONLY_DISTRIBUTION;
@@ -599,12 +599,12 @@ CDFstatus *pStatus;	/* Returned status. */
 * exceed 65535.
 ******************************************************************************/
 
-STATICforIDL CDFstatus WriteBuffer (CDF, fp, dataType, numElems, buffer)
-struct CDFstruct *CDF;
-vFILE *fp;
-Int32 dataType;
-Int32 numElems;
-void *buffer;
+STATICforIDL CDFstatus WriteBuffer (
+struct CDFstruct *CDF,
+vFILE *fp,
+Int32 dataType,
+Int32 numElems,
+void *buffer)
 {
   CDFstatus pStatus = CDF_OK;
   size_t nElemBytes = (size_t) CDFelemSize(dataType);
@@ -644,8 +644,8 @@ void *buffer;
 * Checks for -0.0 (on any type computer).  Assumed to be in host encoding.
 ******************************************************************************/
 
-VISIBLE_PREFIX Logical NegativeZeroReal4 (value)
-float *value;
+VISIBLE_PREFIX Logical NegativeZeroReal4 (
+float *value)
 {
 #if defined(FP1cpu) || defined(FP2cpu)
   return (*((uInt32 *) value) == (uInt32) 0x80000000);
@@ -657,6 +657,7 @@ float *value;
   ****************************************************************************/
   return ((*((uInt32 *) value) & (uInt32) 0x0000FF80) == (uInt32) 0x00008000);
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
@@ -664,8 +665,8 @@ float *value;
 * Checks for -0.0 (on any type computer).  Assumed to be in host encoding.
 ******************************************************************************/
 
-VISIBLE_PREFIX Logical NegativeZeroReal8 (value)
-double *value;
+VISIBLE_PREFIX Logical NegativeZeroReal8 (
+double *value)
 {
 #if defined(FP1cpu)
   return ((*((uInt32 *) value) == (uInt32) 0x80000000) &&
@@ -691,14 +692,15 @@ double *value;
   ****************************************************************************/
   return ((*((uInt32 *) value) & (uInt32) 0x0000FFF0) == (uInt32) 0x00008000);
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * StripTrailingBlanks.
 ******************************************************************************/
 
-STATICforIDL void StripTrailingBlanks (string)
-char *string;
+STATICforIDL void StripTrailingBlanks (
+char *string)
 {
   int i;
   for (i = strlen(string) - 1; i >= 0 && string[i] == ' '; i--) {
@@ -712,8 +714,8 @@ char *string;
 * Convert string to upper-case.
 ******************************************************************************/
 
-VISIBLE_PREFIX void MakeUpperString (string)
-char *string;
+VISIBLE_PREFIX void MakeUpperString (
+char *string)
 {
   int i;
   for (i = 0; string[i] != NUL; i++) {
@@ -727,8 +729,8 @@ char *string;
 * Convert string to lower-case.
 ******************************************************************************/
 
-VISIBLE_PREFIX void MakeLowerString (string)
-char *string;
+VISIBLE_PREFIX void MakeLowerString (
+char *string)
 {
   int i;
   for (i = 0; string[i] != NUL; i++) {
@@ -741,9 +743,9 @@ char *string;
 * SetBit32.
 ******************************************************************************/
 
-STATICforIDL void SetBit32 (value, bit)
-Int32 *value;
-int bit;
+STATICforIDL void SetBit32 (
+Int32 *value,
+int bit)
 {
   *value = *value | (1 << bit);
   return;
@@ -753,9 +755,9 @@ int bit;
 * ClearBit32.
 ******************************************************************************/
 
-STATICforIDL void ClearBit32 (value, bit)
-Int32 *value;
-int bit;
+STATICforIDL void ClearBit32 (
+Int32 *value,
+int bit)
 {
   *value = *value & ~(1 << bit);
   return;
@@ -770,11 +772,11 @@ int bit;
 * in case the CDF had been renamed with a different extension or no extension.
 ******************************************************************************/
 
-STATICforIDL CDFstatus FindCDF (path, no_append, upper, version)
-char *path;             /* Base pathname. */
-Logical *no_append;     /* Should extensions/version numbers be appended? */
-Logical *upper;         /* Should extensions be upper case? */
-Logical *version;       /* Should a version number of `;1' be appended? */
+STATICforIDL CDFstatus FindCDF (
+char *path,             /* Base pathname. */
+Logical *no_append,     /* Should extensions/version numbers be appended? */
+Logical *upper,         /* Should extensions be upper case? */
+Logical *version)       /* Should a version number of `;1' be appended? */
 {
   char pathT[DU_MAX_PATH_LEN+1];
   size_t pathLen;
@@ -783,7 +785,7 @@ Logical *version;       /* Should a version number of `;1' be appended? */
 
   strcpyX (pathT, path, DU_MAX_PATH_LEN);
   if (pathLen < 4 || strcmp(pathT+(pathLen-4), ".cdf") != 0)
-    strcatX (pathT, ".cdf", DU_MAX_PATH_LEN);
+    strcatX (pathT, ".cdf", 4, strlen(pathT), DU_MAX_PATH_LEN);
   if (IsReg(pathT)) {
     *no_append = FALSE;
     *upper = FALSE;
@@ -793,7 +795,7 @@ Logical *version;       /* Should a version number of `;1' be appended? */
 
   strcpyX (pathT, path, DU_MAX_PATH_LEN);
   if (pathLen < 4 || strcmp(pathT+(pathLen-4), ".CDF") != 0)
-    strcatX (pathT, ".CDF", DU_MAX_PATH_LEN);
+    strcatX (pathT, ".CDF", 4, strlen(pathT), DU_MAX_PATH_LEN);
   if (IsReg(pathT)) {
     *no_append = FALSE;
     *upper = TRUE;
@@ -803,7 +805,7 @@ Logical *version;       /* Should a version number of `;1' be appended? */
 
   strcpyX (pathT, path, DU_MAX_PATH_LEN);
   if (pathLen < 6 || !StrStrIgCaseX(pathT+(pathLen-6), ".cdf;1"))
-    strcatX (pathT, ".cdf;1", DU_MAX_PATH_LEN);
+    strcatX (pathT, ".cdf;1", 6, strlen(pathT), DU_MAX_PATH_LEN);
   if (IsReg(pathT)) {
     *no_append = FALSE;
     *upper = FALSE;
@@ -813,7 +815,7 @@ Logical *version;       /* Should a version number of `;1' be appended? */
 
   strcpyX (pathT, path, DU_MAX_PATH_LEN);
   if (pathLen < 6 || !StrStrIgCaseX(pathT+(pathLen-6), ".CDF;1"))
-    strcatX (pathT, ".CDF;1", DU_MAX_PATH_LEN);
+    strcatX (pathT, ".CDF;1", 6, strlen(pathT), DU_MAX_PATH_LEN);
   if (IsReg(pathT)) {
     *no_append = FALSE;
     *upper = TRUE;
@@ -828,7 +830,7 @@ Logical *version;       /* Should a version number of `;1' be appended? */
   strcpyX (pathT, path, DU_MAX_PATH_LEN);
   MakeUpperString (pathT);
   if (pathLen < 4 || !StrStrIgCaseX(pathT+(pathLen-4), ".CDF"))
-    strcatX (pathT, ".CDF", DU_MAX_PATH_LEN);
+    strcatX (pathT, ".CDF", 4, strlen(pathT), DU_MAX_PATH_LEN);
   if (IsReg(pathT)) {
     *no_append = FALSE;
     *upper = TRUE;
@@ -861,35 +863,38 @@ Logical *version;       /* Should a version number of `;1' be appended? */
 * BuildFilePath.
 ******************************************************************************/
 
-STATICforIDL void BuildFilePath (fileType, pathBase, noAppend, upperCase,
-				 versionNumber, varN, pathX)
-int fileType;           /* Type of file. */
-char *pathBase;         /* Base pathname. */
-Logical noAppend;       /* Should extensions/version numbers be appended? */
-Logical upperCase;      /* Should uppercase extensions be appended? */
-Logical versionNumber;  /* Should a version number of `;1' be appended? */
-Int32 varN;             /* Variable number.  N/a if a `cdf' file. */
-char pathX[DU_MAX_PATH_LEN+1];
+STATICforIDL void BuildFilePath (
+int fileType,           /* Type of file. */
+char *pathBase,         /* Base pathname. */
+Logical noAppend,       /* Should extensions/version numbers be appended? */
+Logical upperCase,      /* Should uppercase extensions be appended? */
+Logical versionNumber,  /* Should a version number of `;1' be appended? */
+Int32 varN,             /* Variable number.  N/a if a `cdf' file. */
+char pathX[DU_MAX_PATH_LEN+1])
 			/* The expanded path w/ extensions/version numbers. */
 {
   ExpandPath (pathBase, pathX);
   if (!noAppend) {
     switch (fileType) {
       case CDFt:
-	strcatX (pathX, (upperCase ? ".CDF" : ".cdf"), DU_MAX_PATH_LEN);
+	strcatX (pathX, (upperCase ? ".CDF" : ".cdf"), 4, strlen(pathX),
+		 DU_MAX_PATH_LEN);
 	break;
       case Vt:
-	strcatX (pathX, (upperCase ? ".V" : ".v"), DU_MAX_PATH_LEN);
+	strcatX (pathX, (upperCase ? ".V" : ".v"), 2, strlen(pathX),
+		 DU_MAX_PATH_LEN);
   	snprintf (EofS(pathX), (size_t) DU_MAX_PATH_LEN+1-strlen(pathX), 
                   "%d", (int) varN);
 	break;
       case Zt:
-	strcatX (pathX, (upperCase ? ".Z" : ".z"), DU_MAX_PATH_LEN);
+	strcatX (pathX, (upperCase ? ".Z" : ".z"), 2, strlen(pathX),
+		 DU_MAX_PATH_LEN);
 	snprintf (EofS(pathX), (size_t) DU_MAX_PATH_LEN+1-strlen(pathX),
                   "%d", (int) varN);
 	break;
     }
-    strcatX (pathX, (versionNumber ? ";1" : ""), DU_MAX_PATH_LEN);
+    strcatX (pathX, (versionNumber ? ";1" : ""), (versionNumber ? 2 : 0),
+	     strlen(pathX), DU_MAX_PATH_LEN);
   }
   return;
 }
@@ -900,9 +905,9 @@ char pathX[DU_MAX_PATH_LEN+1];
 * the string.
 ******************************************************************************/
 
-STATICforIDL void NulPad (string, length)
-char *string;
-int length;
+STATICforIDL void NulPad (
+char *string,
+int length)
 {
   int i;
   int j;
@@ -921,10 +926,10 @@ int length;
 * UpdateMaxRec.
 ******************************************************************************/
 
-STATICforIDL CDFstatus UpdateMaxRec (CDF, Var, recNum)
-struct CDFstruct *CDF;          /* In: Pointer to CDF. */
-struct VarStruct *Var;          /* In: Pointer to variable. */
-Int32 recNum;                    /* In: Possible new maximum record number. */
+STATICforIDL CDFstatus UpdateMaxRec (
+struct CDFstruct *CDF,          /* In: Pointer to CDF. */
+struct VarStruct *Var,          /* In: Pointer to variable. */
+Int32 recNum)                    /* In: Possible new maximum record number. */
 {
   CDFstatus pStatus = CDF_OK;
   if (recNum > Var->maxRec) {
@@ -950,15 +955,14 @@ Int32 recNum;                    /* In: Possible new maximum record number. */
 * dimension variances depending on the current zMode.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CalcDimParms (CDF, offset, zVar, numDimsP, dimSizesP,
-				     dimVarysP)
-struct CDFstruct *CDF;          /* In: Pointer to CDF. */
-Int32 offset;                   /* In: Offset of VDR. */
-Logical zVar;                   /* In: TRUE if a true zVariable.  FALSE if a
+STATICforIDL CDFstatus CalcDimParms (
+struct CDFstruct *CDF,          /* In: Pointer to CDF. */
+Int32 offset,                   /* In: Offset of VDR. */
+Logical zVar,                   /* In: TRUE if a true zVariable.  FALSE if a
 				       true rVariable. */
-Int32 *numDimsP;		/* Out: Number of dimensions. */
-Int32 dimSizesP[];              /* Out: Dimension sizes. */
-Int32 dimVarysP[];		/* Out: Dimension variances. */
+Int32 *numDimsP,		/* Out: Number of dimensions. */
+Int32 dimSizesP[],              /* Out: Dimension sizes. */
+Int32 dimVarysP[])		/* Out: Dimension variances. */
 {
   CDFstatus pStatus = CDF_OK; int dN;
   Int32 tNumDims, tDimSizes[CDF_MAX_DIMS], tDimVarys[CDF_MAX_DIMS];
@@ -1016,9 +1020,9 @@ Int32 dimVarysP[];		/* Out: Dimension variances. */
 * length is reached.
 ******************************************************************************/
 
-VISIBLE_PREFIX void NULterminateMAX (string, maxLen)
-char *string;
-size_t maxLen;
+VISIBLE_PREFIX void NULterminateMAX (
+char *string,
+size_t maxLen)
 {
   int i;
   for (i = 0; i < (int) maxLen; i++)
@@ -1031,10 +1035,10 @@ size_t maxLen;
 * ClearBytes.
 ******************************************************************************/
 
-VISIBLE_PREFIX void ClearBytes (buffer, firstByte, lastByte)
-void *buffer;
-int firstByte;
-int lastByte;
+VISIBLE_PREFIX void ClearBytes (
+void *buffer,
+int firstByte,
+int lastByte)
 {
   memset ((Byte1 *)buffer+firstByte, 0, (size_t) (lastByte - firstByte + 1));
   return;
@@ -1044,10 +1048,10 @@ int lastByte;
 * WasteIR.
 ******************************************************************************/
 
-STATICforIDL CDFstatus WasteIR (CDF, wasteOffset, size)
-struct CDFstruct *CDF;
-Int32 wasteOffset;
-Int32 size;
+STATICforIDL CDFstatus WasteIR (
+struct CDFstruct *CDF,
+Int32 wasteOffset,
+Int32 size)
 {
   CDFstatus pStatus = CDF_OK;
   struct UIRstruct newUIR, firstUIR, tUIR, nextUIR;
@@ -1168,10 +1172,10 @@ Int32 size;
 * AllocateIR.
 ******************************************************************************/
 
-STATICforIDL CDFstatus AllocateIR (CDF, size, offset)
-struct CDFstruct *CDF;          /* In: Pointer to CDF. */
-Int32 size;                     /* In: Size of internal record (bytes). */
-Int32 *offset;                  /* Out: Offset of allocated internal record. */
+STATICforIDL CDFstatus AllocateIR (
+struct CDFstruct *CDF,          /* In: Pointer to CDF. */
+Int32 size,                     /* In: Size of internal record (bytes). */
+Int32 *offset)                  /* Out: Offset of allocated internal record. */
 {
   CDFstatus pStatus = CDF_OK;
   Int32 sOffset, eOffset, tSize, UIRhead, eof, uir_ = UIR_;
@@ -1308,18 +1312,17 @@ Int32 *offset;                  /* Out: Offset of allocated internal record. */
 * ResizeIR.
 ******************************************************************************/
 
-STATICforIDL CDFstatus ResizeIR (CDF, curOffset, newSize, newOffset, move,
-				 success)
-struct CDFstruct *CDF;
-Int32 curOffset;        /* In: Current offset of internal record. */
-Int32 newSize;          /* In: New size of internal record.  This may be
+STATICforIDL CDFstatus ResizeIR (
+struct CDFstruct *CDF,
+Int32 curOffset,        /* In: Current offset of internal record. */
+Int32 newSize,          /* In: New size of internal record.  This may be
 			   smaller or larger than the current size. */
-Int32 *newOffset;       /* Out: New offset of internal record.  This variable
+Int32 *newOffset,       /* Out: New offset of internal record.  This variable
 			   is not modified if an error occurs or the internal
 			   record cannot be extended (when `move' is FALSE). */
-Logical move;           /* In: TRUE if the internal record can be moved if
+Logical move,           /* In: TRUE if the internal record can be moved if
 			   necessary. */
-Logical *success;       /* Out: TRUE if the internal record was successfully
+Logical *success)       /* Out: TRUE if the internal record was successfully
 			   extended (whether or not it had to be moved). */
 {
   CDFstatus pStatus = CDF_OK; Int32 curSize; Int32 eof;
@@ -1521,10 +1524,10 @@ Logical *success;       /* Out: TRUE if the internal record was successfully
 * RemoveUIRs.
 ******************************************************************************/
 
-STATICforIDL CDFstatus RemoveUIRs (CDF, sOffset, eOffset)
-struct CDFstruct *CDF;          /* In: Pointer to CDF. */
-Int32 sOffset;                  /* In: Offset of starting UIR. */
-Int32 eOffset;                  /* In: Offset of ending UIR. */
+STATICforIDL CDFstatus RemoveUIRs (
+struct CDFstruct *CDF,          /* In: Pointer to CDF. */
+Int32 sOffset,                  /* In: Offset of starting UIR. */
+Int32 eOffset)                  /* In: Offset of ending UIR. */
 {
   CDFstatus pStatus = CDF_OK;
   struct UIRstruct sUIR, eUIR;
@@ -1571,11 +1574,11 @@ Int32 eOffset;                  /* In: Offset of ending UIR. */
 * PriorTo.
 ******************************************************************************/
 
-VISIBLE_PREFIX Logical PriorTo (spec, version, release, increment)
-char *spec;
-Int32 version;
-Int32 release;
-Int32 increment;
+VISIBLE_PREFIX Logical PriorTo (
+char *spec,
+Int32 version,
+Int32 release,
+Int32 increment)
 {
   int ver, rel, incr;
   switch (sscanf(spec,"%d.%d.%d",&ver,&rel,&incr)) {
@@ -1599,8 +1602,8 @@ Int32 increment;
 * ShortenCDR.
 ******************************************************************************/
 
-STATICforIDL CDFstatus ShortenCDR (CDF)
-struct CDFstruct *CDF;
+STATICforIDL CDFstatus ShortenCDR (
+struct CDFstruct *CDF)
 {
   CDFstatus pStatus = CDF_OK;
   Int32 offset, oldRecordSize, newRecordSize, nBytes;
@@ -1623,8 +1626,8 @@ struct CDFstruct *CDF;
 *    It is assumed that the last ADR offset has already been fixed.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CorrectScopes (CDF)
-struct CDFstruct *CDF;
+STATICforIDL CDFstatus CorrectScopes (
+struct CDFstruct *CDF)
 {
   Int32 tOffset, attrScope;
   CDFstatus pStatus = CDF_OK;
@@ -1667,8 +1670,8 @@ struct CDFstruct *CDF;
 *    It is assumed that the last rVDR offset has already been fixed.
 ******************************************************************************/
 
-STATICforIDL CDFstatus ShortenVDRs (CDF)
-struct CDFstruct *CDF;
+STATICforIDL CDFstatus ShortenVDRs (
+struct CDFstruct *CDF)
 {
   Int32 vOffset, nextOffset, recordSize, nTailBytes;
   void *tBuffer;
@@ -1735,8 +1738,8 @@ struct CDFstruct *CDF;
 *    It is assumed that the last rVDR offset has already been fixed.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CorrectBlockingFactors (CDF)
-struct CDFstruct *CDF;
+STATICforIDL CDFstatus CorrectBlockingFactors (
+struct CDFstruct *CDF)
 {
   CDFstatus pStatus = CDF_OK; Int32 nVars, vdrOffset; int varN;
   Logical zVar; struct VDRstruct VDR; struct VarStruct **Vars, *Var;
@@ -1772,8 +1775,8 @@ struct CDFstruct *CDF;
 * CorrectEPOCH.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CorrectEPOCH (CDF)
-struct CDFstruct *CDF;
+STATICforIDL CDFstatus CorrectEPOCH (
+struct CDFstruct *CDF)
 {
   CDFstatus tStatus, pStatus = CDF_OK;
   Int32 dataType, vNum, vOffset, aOffset, eOffset;
@@ -1846,13 +1849,14 @@ struct CDFstruct *CDF;
 * CDFdeleteFile.
 ******************************************************************************/
 
-STATICforIDL Logical CDFdeleteFile (path)
-char *path;
+STATICforIDL Logical CDFdeleteFile (
+char *path)
 {
 #if defined(vms)
   char tPath[DU_MAX_PATH_LEN+1];
   strcpyX (tPath, path, DU_MAX_PATH_LEN);
-  strcatX (tPath, ";0", DU_MAX_PATH_LEN);    /* Only most recent is deleted. */
+  strcatX (tPath, ";0", 2, strlen(tPath), DU_MAX_PATH_LEN); /* Only most */
+							/* recent is deleted. */
   return (delete(tPath) == 0);
 #endif
 #if defined(unix) || defined(dos)
@@ -1861,15 +1865,16 @@ char *path;
 #if defined(mac) || defined(posixSHELL) || defined(win32)
   return (remove(path) == 0);
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * KillAbortedCDF.
 ******************************************************************************/
 
-STATICforIDL void KillAbortedCDF (CDF, Cur)
-struct CDFstruct *CDF;
-struct CurStruct *Cur;
+STATICforIDL void KillAbortedCDF (
+struct CDFstruct *CDF,
+struct CurStruct *Cur)
 {
   CDF->magic = KILLEDid_MAGIC_NUMBER;
   cdf_FreeMemory (CDF, NULL);
@@ -1881,11 +1886,11 @@ struct CurStruct *Cur;
 * AbortAccess.
 ******************************************************************************/
 
-STATICforIDL void AbortAccess (CDF, updateCDF, deleteCDF)
-struct CDFstruct *CDF;
-Logical updateCDF;      /* Update "working" dotCDF file (if read/write
+STATICforIDL void AbortAccess (
+struct CDFstruct *CDF,
+Logical updateCDF,      /* Update "working" dotCDF file (if read/write
 			   access has been obtained)? */
-Logical deleteCDF;      /* Delete CDF file(s)? */
+Logical deleteCDF)      /* Delete CDF file(s)? */
 {
   /****************************************************************************
   * If the CDF is to be deleted do that first and then skip the updating and/or
@@ -1929,8 +1934,8 @@ Logical deleteCDF;      /* Delete CDF file(s)? */
 * uncompressed dotCDF file (if one exists).
 ******************************************************************************/
 
-STATICforIDL CDFstatus DeleteCDFfiles (CDF)
-struct CDFstruct *CDF;
+STATICforIDL CDFstatus DeleteCDFfiles (
+struct CDFstruct *CDF)
 {
   char tmpFile[DU_MAX_PATH_LEN+1]; CDFstatus pStatus = CDF_OK;
   /**************************************************************************
@@ -1985,10 +1990,10 @@ struct CDFstruct *CDF;
 * DeleteEntry.
 ******************************************************************************/
 
-STATICforIDL CDFstatus DeleteEntry (CDF, aOffset, eOffset)
-struct CDFstruct *CDF;
-Int32 aOffset;
-Int32 eOffset;
+STATICforIDL CDFstatus DeleteEntry (
+struct CDFstruct *CDF,
+Int32 aOffset,
+Int32 eOffset)
 {
   CDFstatus pStatus = CDF_OK;
   struct ADRstruct ADR;
@@ -2071,8 +2076,8 @@ Int32 eOffset;
 ******************************************************************************/
 
 #if defined(MPW_C)
-STATICforIDL uChar *CtoPstr (string)
-char *string;
+STATICforIDL uChar *CtoPstr (
+char *string)
 {
   size_t length = MINIMUM(strlen(string),255);
   if (length > 0) memmove (&string[1], string, length);
@@ -2082,8 +2087,8 @@ char *string;
 #endif
 
 #if defined(MPW_C)
-STATICforIDL char *PtoCstr (string)
-uChar *string;
+STATICforIDL char *PtoCstr (
+uChar *string)
 {
   size_t length = (size_t) string[0];
   if (length > 0) memmove (string, &string[1], length);
@@ -2099,11 +2104,11 @@ uChar *string;
 * should not be padded of course).
 ******************************************************************************/
 
-STATICforIDL CDFstatus PadUnRecords (CDF, Var, firstRec, lastRec)
-struct CDFstruct *CDF;
-struct VarStruct *Var;
-Int32 firstRec;
-Int32 lastRec;
+STATICforIDL CDFstatus PadUnRecords (
+struct CDFstruct *CDF,
+struct VarStruct *Var,
+Int32 firstRec,
+Int32 lastRec)
 {
   CDFstatus pStatus = CDF_OK; Int32 offset; int how; void *buffer;
   Int32 recNum, nRecords, toRec, lastRecInVVR; Logical found;
@@ -2174,13 +2179,13 @@ Int32 lastRec;
 * assumed that the values have already been encoded for the CDF.
 ******************************************************************************/
 
-STATICforIDL CDFstatus WritePadValues (Var, fp, offset, nRecords, how, buffer)
-struct VarStruct *Var;
-vFILE *fp;
-Int32 offset;
-Int32 nRecords;
-int how;
-void *buffer;
+STATICforIDL CDFstatus WritePadValues (
+struct VarStruct *Var,
+vFILE *fp,
+Int32 offset,
+Int32 nRecords,
+int how,
+void *buffer)
 {
   Int32 nBytes, nValues, recX, valueX;
   /****************************************************************************
@@ -2219,23 +2224,23 @@ void *buffer;
 * These are used to avoid double evaluation in macro expansions (eg. MINIMUM).
 ******************************************************************************/
 
-VISIBLE_PREFIX int MinInt (a, b)
-int a;
-int b;
+VISIBLE_PREFIX int MinInt (
+int a,
+int b)
 {
   return MINIMUM(a,b);
 }
 
-VISIBLE_PREFIX Int32 MinInt32 (a, b)
-Int32 a;
-Int32 b;
+VISIBLE_PREFIX Int32 MinInt32 (
+Int32 a,
+Int32 b)
 {
   return MINIMUM(a,b);
 }
 
-VISIBLE_PREFIX long MinLong (a, b)
-long a;
-long b;
+VISIBLE_PREFIX long MinLong (
+long a,
+long b)
 {
   return MINIMUM(a,b);
 }
@@ -2245,23 +2250,23 @@ long b;
 * These are used to avoid double evaluation in macro expansions (eg. MAXIMUM).
 ******************************************************************************/
 
-VISIBLE_PREFIX int MaxInt (a, b)
-int a;
-int b;
+VISIBLE_PREFIX int MaxInt (
+int a,
+int b)
 {
   return MAXIMUM(a,b);
 }
 
-VISIBLE_PREFIX Int32 MaxInt32 (a, b)
-Int32 a;
-Int32 b;
+VISIBLE_PREFIX Int32 MaxInt32 (
+Int32 a,
+Int32 b)
 {
   return MAXIMUM(a,b);
 }
 
-VISIBLE_PREFIX long MaxLong (a, b)
-long a;
-long b;
+VISIBLE_PREFIX long MaxLong (
+long a,
+long b)
 {
   return MAXIMUM(a,b);
 }
@@ -2272,15 +2277,15 @@ long b;
 * delimiter string.
 ******************************************************************************/
 
-VISIBLE_PREFIX long FindNumberOfItems (string, numElems, delimiter)
-char *string;
-long numElems;
-char *delimiter;
+VISIBLE_PREFIX long FindNumberOfItems (
+char *string,
+long numElems,
+char *delimiter)
 {
   long count;
   char *tmp, *tmp2, *tmp3;
   int dlen = (int) strlen(delimiter);
-  tmp = malloc ((size_t) numElems+1);
+  tmp = cdf_AllocateMemory ((size_t) numElems+1, NULL);
   memcpy (tmp, string, (size_t) numElems);
   *(tmp+numElems) = '\0';
   count = 1;
@@ -2291,7 +2296,7 @@ char *delimiter;
     ++count;
     tmp3 = strstr(tmp2, delimiter);
   }
-  free (tmp);
+  cdf_FreeMemory (tmp, NULL);
   tmp = NULL;
   return count;
 }
@@ -2302,17 +2307,17 @@ char *delimiter;
 * reading the string-based variable attribute entry.
 ******************************************************************************/
 
-VISIBLE_PREFIX void CDF_Free_String (numStrings, strings)
-long numStrings;
-char **strings;
+VISIBLE_PREFIX void CDF_Free_String (
+long numStrings,
+char **strings)
 {
   int ix;
   for (ix = 0; ix < (int) numStrings; ++ix) {
-    free (strings[ix]);
+    cdf_FreeMemory (strings[ix], NULL);
     strings[ix] = NULL;
   }
   if (strings != NULL) {
-    free (strings);
+    cdf_FreeMemory (strings, NULL);
     strings = NULL;
   }
 }
@@ -2321,9 +2326,9 @@ char **strings;
 * AddTOvStats.
 ******************************************************************************/
 
-STATICforIDL void AddTOvStats (vStatsTO, vStats)
-vSTATS *vStatsTO;	/* If NULL, do nothing. */
-vSTATS *vStats;		/* If NULL, initialize (to zero). */
+STATICforIDL void AddTOvStats (
+vSTATS *vStatsTO,	/* If NULL, do nothing. */
+vSTATS *vStats)		/* If NULL, initialize (to zero). */
 {
   if (vStatsTO != NULL) {
     if (vStats == NULL) {
@@ -2357,10 +2362,10 @@ vSTATS *vStats;		/* If NULL, initialize (to zero). */
 * entered with a length shorter than the defined number of elements. The
 * buffer's size is a number of numElms, which could contain multiple strings.
 ******************************************************************************/
-STATICforIDL void FillSpacesToString (buffer, totalBytes, numElems)
-char  *buffer;
-int   totalBytes;
-int   numElems;
+STATICforIDL void FillSpacesToString (
+char  *buffer,
+int   totalBytes,
+int   numElems)
 {
   int i, j, k, l;
   l = totalBytes / numElems;
@@ -2383,10 +2388,10 @@ int   numElems;
 * entered with a length shorter than the defined number of elements. The
 * buffer's size is a number of numElms, which could contain multiple strings.
 ******************************************************************************/
-STATICforIDL void FillNulsToString (buffer, totalBytes, numElems)
-char  *buffer;
-int   totalBytes;
-int   numElems;
+STATICforIDL void FillNulsToString (
+char  *buffer,
+int   totalBytes,
+int   numElems)
 {
   int i, j, k, l;
   l = totalBytes / numElems;
@@ -2407,10 +2412,10 @@ int   numElems;
 ******************************************************************************/
 
 #if defined(DEBUG)
-STATICforIDL void DisplayVs (toWhere, label, vStats)
-char *toWhere;
-char *label;
-vSTATS *vStats;
+STATICforIDL void DisplayVs (
+char *toWhere,
+char *label,
+vSTATS *vStats)
 {
   if (toWhere != NULL) {
     FILE *fp = BOO(strcmp(toWhere,"STDOUT"),FOPEN(toWhere,"a"),stdout);
