@@ -44,11 +44,11 @@ static CDFstatus ValidateCDFTT2000 (CDFid id, int zVars, int rVars);
 * CDFope.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CDFope (Va, Cur)
-struct VAstruct *Va;
-struct CurStruct *Cur;
+STATICforIDL CDFstatus CDFope (
+struct VAstruct *Va,
+struct CurStruct *Cur)
 {
-CDFstatus pStatus = CDF_OK, status;
+CDFstatus pStatus = CDF_OK;
 Logical compressedCDF;
 
 compressedCDF = FALSE;
@@ -225,7 +225,7 @@ switch (Va->item) {
 */
     if (compressedCDF) {
       if (magicNumber1 == V2magicNUMBER_1) {
-	int ccrLen, remaining;
+	int ccrLen;
 	if (!Read32(dotFp,&ccrLen)) {
 	  V_close (dotFp, NULL, NULL);
 	  return CDF_READ_ERROR;
@@ -235,13 +235,13 @@ switch (Va->item) {
 	  V_delete (uDotFp, NULL);
 	  return BAD_CACHE_SIZE;
 	} 
-	if (!sX(DecompressCDF(CDF,dotFp,uDotFp),&pStatus)) {
+	if (!sX(DecompressCDF(dotFp,uDotFp),&pStatus)) {
 	  V_close (dotFp, NULL, NULL);
 	  V_delete (uDotFp, NULL);
 	  return pStatus;
 	}
       } else {
-	OFF_T ccrLen; int remaining;
+	OFF_T ccrLen;
 	if (!Read64_64(dotFp,&ccrLen)) {
 	  V_close64 (dotFp, NULL, NULL);
 	  return CDF_READ_ERROR;
@@ -251,7 +251,7 @@ switch (Va->item) {
           V_delete64 (uDotFp, NULL);
           return BAD_CACHE_SIZE;
         }
-	if (!sX(DecompressCDF64(CDF,dotFp,uDotFp),&pStatus)) {
+	if (!sX(DecompressCDF64(dotFp,uDotFp),&pStatus)) {
 	  V_close64 (dotFp, NULL, NULL);
 	  V_delete64 (uDotFp, NULL);
 	  return pStatus;
@@ -422,10 +422,10 @@ switch (Va->item) {
             long libver, librel, libinc;
             snprintf (vri, (size_t) 6, "%1.1d.%1.1d.%1.1d", (int) version,
                       (int) release, (int) increment);
-            status = CDFlib (GET_, LIB_VERSION_, &libver,
-                                   LIB_RELEASE_, &librel,
-                                   LIB_INCREMENT_, &libinc,
-                             NULL_);
+            CDFlib (GET_, LIB_VERSION_, &libver,
+                          LIB_RELEASE_, &librel,
+                          LIB_INCREMENT_, &libinc,
+                    NULL_);
             if (PriorTo(vri, (Int32)libver, (Int32)librel, (Int32)libinc) &&
                 PriorTo("3.5.0", (Int32)libver, (Int32)librel, (Int32)libinc))
               return UNABLE_TO_PROCESS_CDF;
@@ -633,11 +633,11 @@ static CDFstatus ValidateCDFTT2000 (CDFid id, int zVars, int rVars)
     count = (int) (maxRec + 1);
     if (numDims > 0)
       for (j = 0; j < (int) numDims; ++j) count *= (int) dimSizes[j];
-    buffer = (void *) malloc ((size_t) (count * 8));
+    buffer = (void *) cdf_AllocateMemory ((size_t) (count * 8), NULL);
     if (buffer == NULL) return BAD_MALLOC;
     status =  CDFgetVarAllRecordsByVarID (id, 1, (long) i, buffer);
     if (status < CDF_OK) {
-      free (buffer);
+      cdf_FreeMemory (buffer, NULL);
       buffer = NULL;
       return status;
     } 
@@ -645,7 +645,7 @@ static CDFstatus ValidateCDFTT2000 (CDFid id, int zVars, int rVars)
       if (tt2000 < *(((long long *)buffer)+j))
         tt2000 = *(((long long *)buffer)+j);
     }
-    free (buffer);
+    cdf_FreeMemory (buffer, NULL);
     buffer = NULL;
   }
   status = CDFlib(GET_, rVARs_NUMDIMS_, &numDims,
@@ -668,11 +668,11 @@ static CDFstatus ValidateCDFTT2000 (CDFid id, int zVars, int rVars)
     count = (int) (maxRec + 1);
     if (numDims > 0) 
       for (j = 0; j < (int) numDims; ++j) count *= (int) dimSizes[j];
-    buffer = (void *) malloc ((size_t) (count * 8));
+    buffer = (void *) cdf_AllocateMemory ((size_t) (count * 8), NULL);
     if (buffer == NULL) return BAD_MALLOC;
     status =  CDFgetVarAllRecordsByVarID (id, 0, (long) i, buffer);
     if (status < CDF_OK) {
-      free (buffer);
+      cdf_FreeMemory (buffer, NULL);
       buffer = NULL;
       return status;
     }
@@ -680,7 +680,7 @@ static CDFstatus ValidateCDFTT2000 (CDFid id, int zVars, int rVars)
       if (tt2000 < *(((long long *)buffer)+j))
         tt2000 = *(((long long *)buffer)+j);
     }
-    free (buffer);
+    cdf_FreeMemory (buffer, NULL);
     buffer = NULL;
   }
   if (tt2000 != DEFAULT_TT2000_PADVALUE) {
