@@ -35,9 +35,9 @@
 * CDFput2.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CDFput2 (Va, Cur)
-struct VAstruct *Va;
-struct CurStruct *Cur;
+STATICforIDL CDFstatus CDFput2 (
+struct VAstruct *Va,
+struct CurStruct *Cur)
 {
 CDFstatus tStatus, pStatus = CDF_OK;
 
@@ -897,8 +897,8 @@ switch (Va->item) {
     if (!sX(CheckEntryOp(CDF,entryType),&pStatus)) return pStatus;
     if (!WriteAccess(CDF,FALSE,&pStatus)) return pStatus;
     if (STRINGdataType(dataType)) {
-      int cnt;
 /*
+      int cnt;
       if (UTF8Check((unsigned char *)value, (int) numElems, &cnt) != NULL)
 	pStatus = STRING_NOT_UTF8_ENCODING;
 */
@@ -1133,7 +1133,7 @@ switch (Va->item) {
     }
     dataType = CDF_CHAR;
     numElems = length + (long) strlen(STRINGDELIMITER) * (numStrings-1);
-    tmpStr = (char *) malloc (sizeof(char)*numElems);
+    tmpStr = (char *) cdf_AllocateMemory (sizeof(char)*numElems, NULL);
     cstr = tmpStr;
     for (ix = 0; ix < numStrings; ++ix) {
       memcpy (cstr, values[ix], strlen(values[ix]));
@@ -1320,7 +1320,7 @@ switch (Va->item) {
         }
       }
     }
-    free (tmpStr);
+    cdf_FreeMemory (tmpStr, NULL);
     tmpStr = NULL;
     break;
   }
