@@ -34,8 +34,8 @@
 * newline characters to carriage returns (`\015').
 ******************************************************************************/
 
-STATICforIDL void CDFcopyRight (copyRight)
-char *copyRight;
+STATICforIDL void CDFcopyRight (
+char *copyRight)
 {
   strcpyX (copyRight,
 "\012\
@@ -51,9 +51,9 @@ Greenbelt, Maryland 20771 USA\012", CDF_COPYRIGHT_LEN);
 * CDFstatusText.
 ******************************************************************************/
 
-STATICforIDL CDFstatus CDFstatusText (status, textPtr)
-CDFstatus status;
-char *textPtr;
+STATICforIDL CDFstatus CDFstatusText (
+CDFstatus status,
+char *textPtr)
 {
 #if INCLUDE_STATUS_TEXT
   switch (status) {
