@@ -15,6 +15,7 @@
 ******************************************************************************/
 
 #include "cdflib.h"
+#include "cdftt2000.h"
 
 /******************************************************************************
 * breakdown_TT2000 (FORTRAN equivalent of CDF_TT2000_to_UTC_parts).
@@ -27,18 +28,17 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(breakdown_tt2000__,
                breakdown_tt2000_,
                breakdown_tt2000,
-               BREAKDOWN_TT2000)
-(nanoSecSinceJ2000, ly, lm, ld, lh, ln, ls, ll, lu, lx)
-long long *nanoSecSinceJ2000;
-int *ly;
-int *lm;
-int *ld;
-int *lh;
-int *ln;
-int *ls;
-int *ll;
-int *lu;
-int *lx;
+               BREAKDOWN_TT2000) (
+long long *nanoSecSinceJ2000,
+int *ly,
+int *lm,
+int *ld,
+int *lh,
+int *ln,
+int *ls,
+int *ll,
+int *lu,
+int *lx)
 {
   double ly1, lm1, ld1, lh1, ln1, ls1, ll1, lu1, lx1;
   CDF_TT2000_to_UTC_parts (*nanoSecSinceJ2000, &ly1, &lm1, &ld1,
@@ -65,18 +65,17 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(tt2000_breakdown__,
                tt2000_breakdown_,
                tt2000_breakdown,
-               TT2000_BREAKDOWN)
-(nanoSecSinceJ2000, ly, lm, ld, lh, ln, ls, ll, lu, lx)
-long long *nanoSecSinceJ2000;
-int *ly;
-int *lm;
-int *ld;
-int *lh;
-int *ln;
-int *ls;
-int *ll;
-int *lu;
-int *lx;
+               TT2000_BREAKDOWN) (
+long long *nanoSecSinceJ2000,
+int *ly,
+int *lm,
+int *ld,
+int *lh,
+int *ln,
+int *ls,
+int *ll,
+int *lu,
+int *lx)
 {
   double ly1, lm1, ld1, lh1, ln1, ls1, ll1, lu1, lx1;
   CDF_TT2000_to_UTC_parts (*nanoSecSinceJ2000, &ly1, &lm1, &ld1,
@@ -103,18 +102,17 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(cdf_tt2000_to_utc_parts_f__,
                cdf_tt2000_to_utc_parts_f_,
                cdf_tt2000_to_utc_parts_f,
-               CDF_TT2000_TO_UTC_PARTS_F)
-(nanoSecSinceJ2000, ly, lm, ld, lh, ln, ls, ll, lu, lx)
-long long *nanoSecSinceJ2000;
-int *ly;
-int *lm;
-int *ld;
-int *lh;
-int *ln;
-int *ls;
-int *ll;
-int *lu;
-int *lx;
+               CDF_TT2000_TO_UTC_PARTS_F) (
+long long *nanoSecSinceJ2000,
+int *ly,
+int *lm,
+int *ld,
+int *lh,
+int *ln,
+int *ls,
+int *ll,
+int *lu,
+int *lx)
 {
   double ly1, lm1, ld1, lh1, ln1, ls1, ll1, lu1, lx1;
   CDF_TT2000_to_UTC_parts (*nanoSecSinceJ2000, &ly1, &lm1, &ld1,
@@ -141,18 +139,17 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(compute_tt2000__,
                compute_tt2000_,
                compute_tt2000,
-               COMPUTE_TT2000)
-(ly, lm, ld, lh, ln, ls, ll, lu, la, nanoSecSinceJ2000)
-int *ly;
-int *lm;
-int *ld;
-int *lh;
-int *ln;
-int *ls;
-int *ll;
-int *lu;
-int *la;
-long long *nanoSecSinceJ2000;
+               COMPUTE_TT2000) (
+int *ly,
+int *lm,
+int *ld,
+int *lh,
+int *ln,
+int *ls,
+int *ll,
+int *lu,
+int *la,
+long long *nanoSecSinceJ2000)
 {
   *nanoSecSinceJ2000 = CDF_TT2000_from_UTC_parts ((double)*ly, (double)*lm,
                                                   (double)*ld, (double)*lh,
@@ -173,18 +170,17 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(cdf_tt2000_from_utc_parts_f__,
                cdf_tt2000_from_utc_parts_f_,
                cdf_tt2000_from_utc_parts_f,
-               CDF_TT2000_FROM_UTC_PARTS_F)
-(ly, lm, ld, lh, ln, ls, ll, lu, la, nanoSecSinceJ2000)
-int *ly;
-int *lm;
-int *ld;
-int *lh;
-int *ln;
-int *ls;
-int *ll;
-int *lu;
-int *la;
-long long *nanoSecSinceJ2000;
+               CDF_TT2000_FROM_UTC_PARTS_F) (
+int *ly,
+int *lm,
+int *ld,
+int *lh,
+int *ln,
+int *ls,
+int *ll,
+int *lu,
+int *la,
+long long *nanoSecSinceJ2000)
 {
   *nanoSecSinceJ2000 = CDF_TT2000_from_UTC_parts ((double)*ly, (double)*lm, 
                                                   (double)*ld, (double)*lh,
@@ -204,10 +200,9 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(tt2000_to_epoch__,
                tt2000_to_epoch_,
                tt2000_to_epoch,
-               TT2000_TO_EPOCH)
-(nanoSecSinceJ2000, epoch)
-long long *nanoSecSinceJ2000;
-double *epoch;
+               TT2000_TO_EPOCH) (
+long long *nanoSecSinceJ2000,
+double *epoch)
 {
   *epoch = CDF_TT2000_to_UTC_EPOCH (*nanoSecSinceJ2000);
 }
@@ -223,10 +218,9 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(cdf_tt2000_to_utc_epoch_f__,
                cdf_tt2000_to_utc_epoch_f_,
                cdf_tt2000_to_utc_epoch_f,
-               CDF_TT2000_TO_UTC_EPOCH_F)
-(nanoSecSinceJ2000, epoch)
-long long *nanoSecSinceJ2000;
-double *epoch;
+               CDF_TT2000_TO_UTC_EPOCH_F) (
+long long *nanoSecSinceJ2000,
+double *epoch)
 {
   *epoch = CDF_TT2000_to_UTC_EPOCH (*nanoSecSinceJ2000);
 }
@@ -242,10 +236,9 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(tt2000_from_epoch__,
                tt2000_from_epoch_,
                tt2000_from_epoch,
-               TT2000_FROM_EPOCH)
-(epoch, nanoSecSinceJ2000)
-double *epoch;
-long long *nanoSecSinceJ2000;
+               TT2000_FROM_EPOCH) (
+double *epoch,
+long long *nanoSecSinceJ2000)
 {
   *nanoSecSinceJ2000 = CDF_TT2000_from_UTC_EPOCH (*epoch);
 }
@@ -262,10 +255,9 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(cdf_tt2000_from_utc_epoch_f__,
                cdf_tt2000_from_utc_epoch_f_,
                cdf_tt2000_from_utc_epoch_f,
-               CDF_TT2000_FROM_UTC_EPOCH_F)
-(epoch, nanoSecSinceJ2000)
-double *epoch;
-long long *nanoSecSinceJ2000;
+               CDF_TT2000_FROM_UTC_EPOCH_F) (
+double *epoch,
+long long *nanoSecSinceJ2000)
 {
   *nanoSecSinceJ2000 = CDF_TT2000_from_UTC_EPOCH (*epoch);
 }
@@ -281,10 +273,9 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(tt2000_to_epoch16__,
                tt2000_to_epoch16_,
                tt2000_to_epoch16,
-               TT2000_TO_EPOCH16)
-(nanoSecSinceJ2000, epoch16)
-long long *nanoSecSinceJ2000;
-double *epoch16;
+               TT2000_TO_EPOCH16) (
+long long *nanoSecSinceJ2000,
+double *epoch16)
 {
   CDF_TT2000_to_UTC_EPOCH16 (*nanoSecSinceJ2000, epoch16);
 }
@@ -301,10 +292,9 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(cdf_tt2000_to_utc_epoch16_f__,
                cdf_tt2000_to_utc_epoch16_f_,
                cdf_tt2000_to_utc_epoch16_f,
-               CDF_TT2000_TO_UTC_EPOCH16_F)
-(nanoSecSinceJ2000, epoch16)
-long long *nanoSecSinceJ2000;
-double *epoch16;
+               CDF_TT2000_TO_UTC_EPOCH16_F) (
+long long *nanoSecSinceJ2000,
+double *epoch16)
 {
   CDF_TT2000_to_UTC_EPOCH16 (*nanoSecSinceJ2000, epoch16);
 }
@@ -320,10 +310,9 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(tt2000_from_epoch16__,
                tt2000_from_epoch16_,
                tt2000_from_epoch16,
-               TT2000_FROM_EPOCH16)
-(epoch16, nanoSecSinceJ2000) 
-double *epoch16;
-long long *nanoSecSinceJ2000;
+               TT2000_FROM_EPOCH16) (
+double *epoch16,
+long long *nanoSecSinceJ2000)
 {
   *nanoSecSinceJ2000 = CDF_TT2000_from_UTC_EPOCH16 (epoch16);
 }
@@ -340,10 +329,9 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(cdf_tt2000_from_utc_epoch16_f__,
                cdf_tt2000_from_utc_epoch16_f_,
                cdf_tt2000_from_utc_epoch16_f,
-               CDF_TT2000_FROM_UTC_EPOCH16_F)
-(epoch16, nanoSecSinceJ2000) 
-double *epoch16;
-long long *nanoSecSinceJ2000;
+               CDF_TT2000_FROM_UTC_EPOCH16_F) (
+double *epoch16,
+long long *nanoSecSinceJ2000)
 {
   *nanoSecSinceJ2000 = CDF_TT2000_from_UTC_EPOCH16 (epoch16);
 }
@@ -360,12 +348,11 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(encode_tt2000__,
                encode_tt2000_,
                encode_tt2000,
-               ENCODE_TT2000)
-(nanoSecSinceJ2000, style, string Fif_GHOSTARG(string_len))
-long long *nanoSecSinceJ2000;
-int  *style;
-void *string;
-Fif_GHOSTDEF(string_len)
+               ENCODE_TT2000) (
+long long *nanoSecSinceJ2000,
+int  *style,
+void *string 
+Fif_GHOSTDEF2(string_len))
 {
   char tString[TT2000_0_STRING_LEN+1];
   int  len = -1;
@@ -403,12 +390,11 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(toencode_tt2000__,
                toencode_tt2000_,
                toencode_tt2000,
-               TOENCODE_TT2000)
-(nanoSecSinceJ2000, style, string Fif_GHOSTARG(string_len))
-long long *nanoSecSinceJ2000;
-int  *style;
-void *string;
-Fif_GHOSTDEF(string_len)
+               TOENCODE_TT2000) (
+long long *nanoSecSinceJ2000,
+int  *style,
+void *string
+Fif_GHOSTDEF2(string_len))
 {
   char tString[TT2000_0_STRING_LEN+1];
   int  len = -1;
@@ -446,12 +432,11 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(cdf_tt2000_to_utc_string_f__,
                cdf_tt2000_to_utc_string_f_,
                cdf_tt2000_to_utc_string_f,
-               CDF_TT2000_TO_UTC_STRING_F)
-(nanoSecSinceJ2000, style, string Fif_GHOSTARG(string_len))
-long long *nanoSecSinceJ2000;
-int  *style;
-void *string;
-Fif_GHOSTDEF(string_len)
+               CDF_TT2000_TO_UTC_STRING_F) (
+long long *nanoSecSinceJ2000,
+int  *style,
+void *string 
+Fif_GHOSTDEF2(string_len))
 {
   char tString[TT2000_0_STRING_LEN+1];
   int len = -1;
@@ -489,11 +474,10 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(parse_tt2000__,
                parse_tt2000_,
                parse_tt2000,
-               PARSE_TT2000)
-(string, tt2000 Fif_GHOSTARG(string_len))
-char *string;
-long long *tt2000;
-Fif_GHOSTDEF(string_len)
+               PARSE_TT2000) (
+char *string,
+long long *tt2000
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
 #if defined(Fif_DESCR)
@@ -524,11 +508,10 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(toparse_tt2000__,
                toparse_tt2000_,
                toparse_tt2000,
-               TOPARSE_TT2000)
-(string, tt2000 Fif_GHOSTARG(string_len))
-char *string;
-long long *tt2000;
-Fif_GHOSTDEF(string_len)
+               TOPARSE_TT2000) (
+char *string,
+long long *tt2000
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
 #if defined(Fif_DESCR)
@@ -561,11 +544,10 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(cdf_tt2000_from_utc_string_f__,
                cdf_tt2000_from_utc_string_f_,
                cdf_tt2000_from_utc_string_f,
-               CDF_TT2000_FROM_UTC_STRING_F)
-(string, tt2000 Fif_GHOSTARG(string_len))
-char *string;
-long long *tt2000;
-Fif_GHOSTDEF(string_len)
+               CDF_TT2000_FROM_UTC_STRING_F) (
+char *string,
+long long *tt2000
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
 #if defined(Fif_DESCR)
@@ -598,10 +580,9 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(cdf_getleapsecondstableenvvar__,
                cdf_getleapsecondstableenvvar_,
                cdf_getleapsecondstableenvvar,
-               CDF_GETLEAPSECONDSTABLEENVVAR)
-(string Fif_GHOSTARG(string_len))
-char *string;
-Fif_GHOSTDEF(string_len)
+               CDF_GETLEAPSECONDSTABLEENVVAR) (
+char *string 
+Fif_GHOSTDEF2(string_len))
 {
   char *table = CDFgetLeapSecondsTableEnvVar();
   if (table != NULL) {
@@ -637,10 +618,10 @@ Fif_ENTRYPOINT(cdf_getlastdateinleapsecondstable__,
                cdf_getlastdateinleapsecondstable,
                CDF_GETLASTDATEINLEAPSECONDSTABLE)
 #endif
-(year, month, day)
-Int32 *year;
-Int32 *month;
-Int32 *day;
+(
+Int32 *year,
+Int32 *month,
+Int32 *day)
 {
   long yy, mm, dd;
 #if defined(vms)
@@ -665,8 +646,7 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(cdf_getleapsecondstablestatus__,
                cdf_getleapsecondstablestatus_,
                cdf_getleapsecondstablestatus,
-               CDF_GETLEAPSECONDSTABLESTATUS)
-()
+               CDF_GETLEAPSECONDSTABLESTATUS) (void)
 {
   return (Int32) CDFgetLeapSecondsTableStatus ();
 }
@@ -683,8 +663,7 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(cdf_getrowsinleapsecondstable__,
                cdf_getrowsinleapsecondstable_,
                cdf_getrowsinleapsecondstable,
-               CDF_GETROWSINLEAPSECONDSTABLE)
-()
+               CDF_GETROWSINLEAPSECONDSTABLE) (void)
 {
   return (Int32) CDFgetRowsinLeapSecondsTable ();
 }
@@ -701,9 +680,8 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(cdf_fillleapsecondstable__,
                cdf_fillleapsecondstable_,
                cdf_fillleapsecondstable,
-               CDF_FILLLEAPSECONDSTABLE)
-(tableo)
-double *tableo;
+               CDF_FILLLEAPSECONDSTABLE) (
+double *tableo)
 {
   int ix, iy;
   int rows = CDFgetRowsinLeapSecondsTable ();
@@ -730,11 +708,10 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(tt2000_to_unixtime__,
                tt2000_to_unixtime_,
                tt2000_to_unixtime,
-               TT2000_TO_UNIXTIME)
-(tt2000s, unixTimes, num)
-long long *tt2000s;
-double  *unixTimes;
-int     *num;
+               TT2000_TO_UNIXTIME) (
+long long *tt2000s,
+double  *unixTimes,
+int     *num)
 {
   TT2000toUnixTime (tt2000s, unixTimes, *num);
 }
@@ -750,11 +727,10 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(unixtime_to_tt2000__,
                unixtime_to_tt2000_,
                unixtime_to_tt2000,
-               UNIXTIME_TO_TT2000)
-(unixTimes, tt2000s, num)
-double  *unixTimes;
-long long *tt2000s;
-int  *num;
+               UNIXTIME_TO_TT2000) (
+double  *unixTimes,
+long long *tt2000s,
+int  *num)
 {
   UnixTimetoTT2000 (unixTimes, tt2000s, *num);
 }
