@@ -70,18 +70,24 @@ static int numAttrs;
 * QuitCDF.
 ******************************************************************************/
 
-static CDFstatus QuitCDF (char *why, Int32 offset, int size, int num,
-	                  void *value1, void *value2, Logical debug)
+static CDFstatus QuitCDF (
+char *why, 
+Int32 offset, 
+int size, 
+int num,
+void *value1, 
+void *value2, 
+Logical debug)
 {
   
   if (debug) {
-    char text[151], texta[41];
+    char text[150+1], texta[40+1];
     text[0] = NUL;
     strcpyX (text, why, 150);
     if (offset >= 0) {
       snprintf (texta, (size_t) sizeof(texta),
                 " (@%ld) ", (long) offset);
-      strcatX (text, texta, 150);
+      strcatX (text, texta, strlen(texta), strlen(text), 150);
     }
     if (strlen(why) < 150) {
       if (num == 2) { /* Two argument values to show. */
@@ -92,7 +98,7 @@ static CDFstatus QuitCDF (char *why, Int32 offset, int size, int num,
           snprintf (text2, (size_t) sizeof(text2),
 		    "(%ld vs %ld)", (long) *(int *)value1,
                     (long) *(int *)value2);
-          strcatX (text, text2, 150);
+          strcatX (text, text2, strlen(text2), strlen(text), 150);
         } else { /* Both are strings. */
           char *text2;
           size_t len = strlen ((char *) value1) + strlen ((char *) value2) + 
@@ -102,7 +108,7 @@ static CDFstatus QuitCDF (char *why, Int32 offset, int size, int num,
             text2[0] = NUL;
             snprintf (text2, len, "(%s vs %s)", (char *)value1,
                       (char *)value2);
-            strcatX (text, text2, 150);
+            strcatX (text, text2, strlen(text2), strlen(text), 150);
             cdf_FreeMemory (text2, NULL);
           }
         }
@@ -112,7 +118,7 @@ static CDFstatus QuitCDF (char *why, Int32 offset, int size, int num,
           text2[0] = NUL;
           snprintf (text2, (size_t) sizeof(text2),
 		    "(%ld)", (long) *(int *)value1);
-          strcatX (text, text2, 150);
+          strcatX (text, text2, strlen(text2), strlen(text), 150);
         } else {
           char *text2;
           size_t len = strlen ((char *) value1) + 2 + 1;
@@ -120,7 +126,7 @@ static CDFstatus QuitCDF (char *why, Int32 offset, int size, int num,
           if (text2 != NULL) {
             text2[0] = NUL;
             snprintf (text2, len, "(%s)", (char *)value1);
-            strcatX (text, text2, 150);
+            strcatX (text, text2, strlen(text2), strlen(text), 150);
             cdf_FreeMemory (text2, NULL);
           }
         }
@@ -136,9 +142,12 @@ static CDFstatus QuitCDF (char *why, Int32 offset, int size, int num,
 *   Start to validate each internal record in a CDF file.
 ******************************************************************************/
 
-STATICforIDL CDFstatus ValidateCDF (struct CDFstruct *CDF, vFILE *CDFfp, 
-                                    Int32 offset, Int32 fileSize,
-                                    Logical debug)
+STATICforIDL CDFstatus ValidateCDF (
+struct CDFstruct *CDF, 
+vFILE *CDFfp, 
+Int32 offset, 
+Int32 fileSize,
+Logical debug)
 {
   Int32 recordSize;
   Int32 recordType;
@@ -274,6 +283,8 @@ STATICforIDL CDFstatus ValidateCDF (struct CDFstruct *CDF, vFILE *CDFfp,
         * Sparseness Parameters Record (SPR).
         **********************************************************************/
         case SPR_: {
+          status = ValidateSPR (CDFfp, offset, debug);
+          if (status != CDF_OK) return status;
           offset = offset + recordSize;
           if (!SEEKv(CDFfp,offset,vSEEK_SET)) return CRE;
 	  break;
@@ -282,6 +293,8 @@ STATICforIDL CDFstatus ValidateCDF (struct CDFstruct *CDF, vFILE *CDFfp,
         * Unused internal record
         **********************************************************************/
         case UIR_: {
+          status = ValidateUIR (CDFfp, offset, debug);
+          if (status != CDF_OK) return status;
           offset = offset + recordSize;
           if (!SEEKv(CDFfp,offset,vSEEK_SET)) return CRE;
 	  break;
@@ -332,7 +345,10 @@ STATICforIDL CDFstatus ValidateCDF (struct CDFstruct *CDF, vFILE *CDFfp,
 * ValidateCDR.
 ******************************************************************************/
 
-static CDFstatus ValidateCDR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateCDR (
+vFILE *fp, 
+Int32 offset, 
+Logical debug)
 {
   Int32 actualEncoding;
   CDFstatus status;
@@ -373,7 +389,10 @@ static CDFstatus ValidateCDR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateGDR.
 ******************************************************************************/
 
-static CDFstatus ValidateGDR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateGDR (
+vFILE *fp, 
+Int32 offset, 
+Logical debug)
 {
   int i;
   CDFstatus status;
@@ -421,8 +440,11 @@ static CDFstatus ValidateGDR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateADR.
 ******************************************************************************/
 
-static CDFstatus ValidateADR (struct CDFstruct *CDF, vFILE *fp, Int32 offset, 
-                              Logical debug)
+static CDFstatus ValidateADR (
+struct CDFstruct *CDF, 
+vFILE *fp, 
+Int32 offset, 
+Logical debug)
 {
   struct ADRstruct ADR;
   CDFstatus status;
@@ -493,9 +515,14 @@ static CDFstatus ValidateADR (struct CDFstruct *CDF, vFILE *fp, Int32 offset,
 * ValidateAEDR/AzEDR.
 ******************************************************************************/
 
-static CDFstatus ValidateAEDR (struct CDFstruct *CDF, vFILE *fp, Int32 offset,
-                               Int32 num, Int32 maxEntry, Logical zEntry, 
-                               Logical debug)
+static CDFstatus ValidateAEDR (
+struct CDFstruct *CDF, 
+vFILE *fp, 
+Int32 offset,
+Int32 num, 
+Int32 maxEntry, 
+Logical zEntry, 
+Logical debug)
 {
   struct AEDRstruct AEDR;
   size_t nBytes;
@@ -546,8 +573,12 @@ static CDFstatus ValidateAEDR (struct CDFstruct *CDF, vFILE *fp, Int32 offset,
 * ValidateVDR/zVDR.
 ******************************************************************************/
 
-static CDFstatus ValidateVDR (struct CDFstruct *CDF, vFILE *fp, Int32 offset, 
-		              Logical zVar, Logical debug)
+static CDFstatus ValidateVDR (
+struct CDFstruct *CDF, 
+vFILE *fp, 
+Int32 offset, 
+Logical zVar, 
+Logical debug)
 {
   struct VDRstruct VDR;
   Int32 numVars;
@@ -617,8 +648,11 @@ static CDFstatus ValidateVDR (struct CDFstruct *CDF, vFILE *fp, Int32 offset,
 * ValidateVXR.
 ******************************************************************************/
 
-static CDFstatus ValidateVXR (vFILE *fp, Int32 offset, Int32 lastRec,
-	                      Logical debug)
+static CDFstatus ValidateVXR (
+vFILE *fp, 
+Int32 offset, 
+Int32 lastRec,
+Logical debug)
 {
   struct VXRstruct VXR;
   int i;
@@ -680,7 +714,10 @@ static CDFstatus ValidateVXR (vFILE *fp, Int32 offset, Int32 lastRec,
 * ValidateVVR.
 ******************************************************************************/
 
-static CDFstatus ValidateVVR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateVVR (
+vFILE *fp, 
+Int32 offset, 
+Logical debug)
 {
   struct VVRstruct VVR;
   CDFstatus status;
@@ -704,7 +741,10 @@ static CDFstatus ValidateVVR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateUIR.
 ******************************************************************************/
 
-static CDFstatus ValidateUIR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateUIR (
+vFILE *fp, 
+Int32 offset, 
+Logical debug)
 {
   struct UIRstruct UIR;
   CDFstatus status;
@@ -718,17 +758,17 @@ static CDFstatus ValidateUIR (vFILE *fp, Int32 offset, Logical debug)
   if (UIR.RecordType != UIR_)
     return QuitCDF ("CDF(UIR): record type is invalid ", offset,
                     4, 1, &(UIR.RecordType), 0, debug);
-  if (UIR.RecordSize < UIR_BASE_SIZE) 
-    return QuitCDF ("CDF(UIR): record size is invalid for UIR",
-                        offset,
+  if (UIR.RecordSize < UUIR_BASE_SIZE) 
+    return QuitCDF ("CDF(UIR): record size is invalid for UIR", offset,
                     4, 1, &(UIR.RecordSize), 0, debug);
-  if (UIR.NextUIR < 0) 
-    return QuitCDF ("CDF(UIR): offset to next UIR is invalid for UIR",
-                        offset,
-                    4, 1, &(UIR.NextUIR), 0, debug);
-  if (UIR.PrevUIR < 0) 
-    return QuitCDF ("CDF(UIR): offset to previous UIR is invalid for UIR",
-                    offset, 4, 1, &(UIR.PrevUIR), 0, debug);
+  if (UIR.RecordSize > UIR_BASE_SIZE) {
+    if (UIR.NextUIR < 0) 
+      return QuitCDF ("CDF(UIR): offset to next UIR is invalid for UIR",
+                      offset, 4, 1, &(UIR.NextUIR), 0, debug);
+    if (UIR.PrevUIR < 0) 
+      return QuitCDF ("CDF(UIR): offset to previous UIR is invalid for UIR",
+                      offset, 4, 1, &(UIR.PrevUIR), 0, debug);
+  }
   return CDF_OK;
 }
 
@@ -736,7 +776,10 @@ static CDFstatus ValidateUIR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateCCR.
 ******************************************************************************/
 
-static CDFstatus ValidateCCR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateCCR (
+vFILE *fp, 
+Int32 offset, 
+Logical debug)
 {
   struct CCRstruct CCR;
   CDFstatus status;
@@ -766,7 +809,10 @@ static CDFstatus ValidateCCR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateCPR.
 ******************************************************************************/
 
-static CDFstatus ValidateCPR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateCPR (
+vFILE *fp, 
+Int32 offset, 
+Logical debug)
 {
   struct CPRstruct CPR;
   CDFstatus status;
@@ -799,7 +845,10 @@ static CDFstatus ValidateCPR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateSPR.
 ******************************************************************************/
 
-static CDFstatus ValidateSPR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateSPR (
+vFILE *fp, 
+Int32 offset, 
+Logical debug)
 {
   struct SPRstruct SPR;
   CDFstatus status;
@@ -826,7 +875,10 @@ static CDFstatus ValidateSPR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateCVVR.
 ******************************************************************************/
 
-static CDFstatus ValidateCVVR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateCVVR (
+vFILE *fp, 
+Int32 offset, 
+Logical debug)
 {
   struct CVVRstruct CVVR;
   CDFstatus status;
@@ -850,8 +902,10 @@ static CDFstatus ValidateCVVR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateAttributeLinks.
 ******************************************************************************/
 
-static CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp, 
-                                         Logical debug)
+static CDFstatus ValidateAttributeLinks (
+struct CDFstruct *CDF, 
+vFILE *fp, 
+Logical debug)
 {
   CDFstatus status;
   Int32 offset, nextADR, AgrEDRhead, AzEDRhead;
@@ -910,10 +964,15 @@ static CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp,
 * ValidateAttributeEntryLink.
 ******************************************************************************/
 
-static CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp, 
-                                             Int32 num, Logical zEntry,
-                                             Int32 EDRhead, Int32 numEntries,
-                                             Int32 maxEntry, Logical debug)
+static CDFstatus ValidateAttributeEntryLink (
+struct CDFstruct *CDF, 
+vFILE *fp, 
+Int32 num, 
+Logical zEntry,
+Int32 EDRhead, 
+Int32 numEntries,
+Int32 maxEntry, 
+Logical debug)
 {
   CDFstatus status;
   Int32 offset, nextAEDR;
@@ -969,8 +1028,11 @@ static CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp,
 * ValidateVariableLinks.
 ******************************************************************************/
 
-static CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp, 
-                                        Logical zVar, Logical debug)
+static CDFstatus ValidateVariableLinks (
+struct CDFstruct *CDF, 
+vFILE *fp, 
+Logical zVar, 
+Logical debug)
 {
   CDFstatus status;
   Int32 offset, headVXR, tailVXR, nextVDR, cprOffset;
@@ -1043,9 +1105,12 @@ static CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp,
 * ValidateVariableValueLinks.
 ******************************************************************************/
 
-static CDFstatus ValidateVariableValueLinks (struct CDFstruct *CDF, vFILE *fp, 
-                                             Int32 lastRec, Int32 headVXR,
-                                             Logical debug)
+static CDFstatus ValidateVariableValueLinks (
+struct CDFstruct *CDF, 
+vFILE *fp, 
+Int32 lastRec, 
+Int32 headVXR,
+Logical debug)
 {
   CDFstatus status;
 
