@@ -73,7 +73,7 @@ static CDFstatus QuitCDF (char *why, OFF_T offset, int isize, int num,
 {
   
   if (debug) {
-    char text[151], texta[41];
+    char text[150+1], texta[40+1];
     text[0] = NUL;
     strcpyX (text, why, 150);
     if (offset >= 0) {
@@ -84,7 +84,7 @@ static CDFstatus QuitCDF (char *why, OFF_T offset, int isize, int num,
       snprintf (texta, (size_t) sizeof(texta),
 	        " (@%I64d) ", (long long) offset);
 #endif
-      strcatX (text, texta, 150);
+      strcatX (text, texta, strlen(texta), strlen(text), 150);
     }
     if (strlen(why) < 150) {
       if (num == 2) { /* Two argument values to show. */
@@ -95,7 +95,7 @@ static CDFstatus QuitCDF (char *why, OFF_T offset, int isize, int num,
           snprintf (text2, (size_t) sizeof(text2),
 		    "(%ld vs %ld)", (long) *(int *)value1,
                     (long) *(int *)value2);
-          strcatX (text, text2, 150);
+          strcatX (text, text2, strlen(text2), strlen(text), 150);
         } else if (isize == 8) { /* Each one is a 8-byte long long type. */
                                  /* Each long long is up to 19 digits + sign.*/
           char text2[2 * 20 + 6 + 1];
@@ -109,7 +109,7 @@ static CDFstatus QuitCDF (char *why, OFF_T offset, int isize, int num,
 		    "(%I64d vs %I64d)", *(long long *)value1,
                                         *(long long *)value2);
 #endif
-          strcatX (text, text2, 150);
+          strcatX (text, text2, strlen(text2), strlen(text), 150);
         } else { /* Each one is a string. */
           char *text2;
           size_t len = strlen ((char *) value1) + strlen ((char *) value2) + 6
@@ -119,7 +119,7 @@ static CDFstatus QuitCDF (char *why, OFF_T offset, int isize, int num,
             text2[0] = (char) NUL;
             snprintf (text2, len, "(%s vs %s)", (char *)value1,
                       (char *)value2);
-            strcatX (text, text2, 150);
+            strcatX (text, text2, strlen(text2), strlen(text), 150);
             cdf_FreeMemory (text2, NULL);
           }
         }
@@ -129,7 +129,7 @@ static CDFstatus QuitCDF (char *why, OFF_T offset, int isize, int num,
           text2[0] = (char) NUL;
           snprintf (text2, (size_t) sizeof(text2),
 		    "(%ld)", (long) *(int *)value1);
-          strcatX (text, text2, 150);
+          strcatX (text, text2, strlen(text2), strlen(text), 150);
         } else if (isize == 8) {
           char text2[20 + 2 + 1];
           text2[0] = (char) NUL;
@@ -140,7 +140,7 @@ static CDFstatus QuitCDF (char *why, OFF_T offset, int isize, int num,
           snprintf (text2, (size_t) sizeof(text2),
 		    "(%I64d)", *(long long *)value1);
 #endif
-          strcatX (text, text2, 150);
+          strcatX (text, text2, strlen(text2), strlen(text), 150);
         } else {
           char *text2;
           size_t len = strlen ((char *) value1)  + 2 + 1;
@@ -148,7 +148,7 @@ static CDFstatus QuitCDF (char *why, OFF_T offset, int isize, int num,
           if (text2 != NULL) {
             text2[0] = (char) NUL;
             snprintf (text2, len, "(%s)", (char *)value1);
-            strcatX (text, text2, 150);
+            strcatX (text, text2, strlen(text2), strlen(text), 150);
             cdf_FreeMemory (text2, NULL);
           }
         }
@@ -300,6 +300,8 @@ STATICforIDL CDFstatus ValidateCDF64 (struct CDFstruct *CDF, vFILE *CDFfp,
         * Sparseness Parameters Record (SPR).
         **********************************************************************/
         case SPR_: {
+          status = ValidateSPR (CDFfp,offset,debug);
+          if (status != CDF_OK) return status;
           offset = offset + recordSize;
           if (!SEEKv64(CDFfp,offset,vSEEK_SET)) return CRE;
 	  break;
@@ -308,6 +310,8 @@ STATICforIDL CDFstatus ValidateCDF64 (struct CDFstruct *CDF, vFILE *CDFfp,
         * Unused internal record
         **********************************************************************/
         case UIR_: {
+          status = ValidateUIR (CDFfp,offset,debug);
+          if (status != CDF_OK) return status;
           offset = offset + recordSize;
           if (!SEEKv64(CDFfp,offset,vSEEK_SET)) return CRE;
 	  break;
@@ -777,15 +781,17 @@ static CDFstatus ValidateUIR (vFILE *fp, OFF_T offset, Logical debug)
   if (UIR.RecordType != UIR_) 
     return QuitCDF ("CDF(UIR): record type is invalid ", offset,
                     4, 1, &(UIR.RecordType), 0, debug);
-  if (UIR.RecordSize < UIR_BASE_SIZE64) 
+  if (UIR.RecordSize < UUIR_BASE_SIZE64)
     return QuitCDF ("CDF(UIR): record size is invalid ", offset,
                     8, 1, &(UIR.RecordSize), 0, debug);
-  if (UIR.NextUIR < 0) 
-    return QuitCDF ("CDF(UIR): offset to next UIR is invalid ", offset,
-                    8, 1, &(UIR.NextUIR), 0, debug);
-  if (UIR.PrevUIR < 0) 
-    return QuitCDF ("CDF(UIR): offset to previous UIR is invalid ", offset,
-                    8, 1, &(UIR.PrevUIR), 0, debug);
+  if (UIR.RecordSize > UIR_BASE_SIZE64) {
+    if (UIR.NextUIR < 0) 
+      return QuitCDF ("CDF(UIR): offset to next UIR is invalid ", offset,
+                      8, 1, &(UIR.NextUIR), 0, debug);
+    if (UIR.PrevUIR < 0) 
+      return QuitCDF ("CDF(UIR): offset to previous UIR is invalid ", offset,
+                      8, 1, &(UIR.PrevUIR), 0, debug);
+  }
   return CDF_OK;
 }
 
