@@ -38,9 +38,9 @@
 * Write32.
 ******************************************************************************/
 
-STATICforIDL Logical Write32 (fp, value)
-vFILE *fp;
-Int32 *value;
+STATICforIDL Logical Write32 (
+vFILE *fp,
+Int32 *value)
 {
 #if defined(NETWORKbyteORDERcpu)
   if (!WRITEv(value,(size_t)4,(size_t)1,fp)) return FALSE;
@@ -56,10 +56,10 @@ Int32 *value;
 * Write32s.
 ******************************************************************************/
 
-STATICforIDL Logical Write32s (fp, buffer, count)
-vFILE *fp;
-Int32 *buffer;
-int count;
+STATICforIDL Logical Write32s (
+vFILE *fp,
+Int32 *buffer,
+int count)
 {
 #define MAX_tBUFFER_SIZE 10             /* This must be set to the maximum
 					   value that `count' may ever be.
@@ -87,10 +87,10 @@ int count;
 *   The size is always in the first 4-byte field.
 ******************************************************************************/
 
-STATICforIDL CDFstatus WriteIrSize (fp, offset, irSize)
-vFILE *fp;
-Int32 offset;
-Int32 *irSize;
+STATICforIDL CDFstatus WriteIrSize (
+vFILE *fp,
+Int32 offset,
+Int32 *irSize)
 {
   if (!SEEKv(fp,(long)offset,vSEEK_SET)) return CWE;
   if (!Write32(fp,irSize)) return CWE;
@@ -102,10 +102,10 @@ Int32 *irSize;
 *   The type is always in the second 4-byte field.
 ******************************************************************************/
 
-STATICforIDL CDFstatus WriteIrType (fp, offset, irType)
-vFILE *fp;
-Int32 offset;
-Int32 *irType;
+STATICforIDL CDFstatus WriteIrType (
+vFILE *fp,
+Int32 offset,
+Int32 *irType)
 {
   long irTypeOffset = offset + 4;
   if (!SEEKv(fp,irTypeOffset,vSEEK_SET)) return CWE;
