@@ -40,9 +40,9 @@
 * Write32_64.
 ******************************************************************************/
 
-STATICforIDL Logical Write32_64 (fp, value)
-vFILE *fp;
-Int32 *value;
+STATICforIDL Logical Write32_64 (
+vFILE *fp,
+Int32 *value)
 {
 #if defined(NETWORKbyteORDERcpu)
   if (!WRITEv64(value,(size_t)4,(size_t)1,fp)) return FALSE;
@@ -58,10 +58,10 @@ Int32 *value;
 * Write32s_64.
 ******************************************************************************/
 
-STATICforIDL Logical Write32s_64 (fp, buffer, count)
-vFILE *fp;
-Int32 *buffer;
-int count;
+STATICforIDL Logical Write32s_64 (
+vFILE *fp,
+Int32 *buffer,
+int count)
 {
 #define MAX_tBUFFER_SIZE 10             /* This must be set to the maximum
                                            value that `count' may ever be.
@@ -88,9 +88,9 @@ int count;
 * Write64_64.
 ******************************************************************************/
 
-STATICforIDL Logical Write64_64 (fp, value)
-vFILE *fp;
-OFF_T *value;
+STATICforIDL Logical Write64_64 (
+vFILE *fp,
+OFF_T *value)
 {
 #if defined(NETWORKbyteORDERcpu)
   if (!WRITEv64(value,(size_t)8,(size_t)1,fp)) return FALSE;
@@ -106,10 +106,10 @@ OFF_T *value;
 * Write64s_64.
 ******************************************************************************/
 
-STATICforIDL Logical Write64s_64 (fp, buffer, count)
-vFILE *fp;
-OFF_T *buffer;
-int count;
+STATICforIDL Logical Write64s_64 (
+vFILE *fp,
+OFF_T *buffer,
+int count)
 {
 #define MAX_tBUFFER_SIZE 10             /* This must be set to the maximum
 					   value that `count' may ever be.
@@ -137,10 +137,10 @@ int count;
 *   The size is always in the first 8-byte field.
 ******************************************************************************/
 
-STATICforIDL CDFstatus WriteIrSize64 (fp, offset, irSize)
-vFILE *fp;
-OFF_T offset;
-OFF_T *irSize;
+STATICforIDL CDFstatus WriteIrSize64 (
+vFILE *fp,
+OFF_T offset,
+OFF_T *irSize)
 {
   if (!SEEKv64(fp,offset,vSEEK_SET)) return CWE;
   if (!Write64_64(fp,irSize)) return CWE;
@@ -152,12 +152,12 @@ OFF_T *irSize;
 *   The type is always in the second field (4-byte).
 ******************************************************************************/
 
-STATICforIDL CDFstatus WriteIrType64 (fp, offset, irType)
-vFILE *fp;
-OFF_T offset;
-Int32 *irType;
+STATICforIDL CDFstatus WriteIrType64 (
+vFILE *fp,
+OFF_T offset,
+Int32 *irType)
 {
-  OFF_T irTypeOffset = offset + sizeof(OFF_T);
+  OFF_T irTypeOffset = offset + sizeof(size_t);
   if (!SEEKv64(fp,irTypeOffset,vSEEK_SET)) return CWE;
   if (!Write32_64(fp,irType)) return CWE;
   return CDF_OK;
@@ -728,7 +728,7 @@ va_dcl
 	 if (!Write32s_64(fp,VDR->DimVarys,(int)nDims)) return CWE;
 	 if (PADvalueBITset(VDR->Flags) && padValue != NULL) {
 	   if (STRINGdataType(VDR->DataType)) {
-	     char *newPad, *tmp; int len;
+	     char *newPad; int len;
 	     newPad = (char *) cdf_AllocateMemory (sizeof(char) *
 	    					   VDR->NumElems, NULL);
 	     memset ((void *)newPad, '\0', (size_t)VDR->NumElems);
@@ -1160,7 +1160,7 @@ va_dcl
            case CCR_RFUa: tOffset += (OFF_T) CCR_RFUa_OFFSET64; break;
            default: return CDF_INTERNAL_ERROR;
          }
-         if (!SEEKv64(fp,offset,vSEEK_SET)) return CWE;
+         if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CWE;
          if (!Write32_64(fp,buffer)) return CWE;
          break;
        }
