@@ -31,11 +31,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(parse_epoch__,parse_epoch_,parse_epoch,PARSE_EPOCH)
-(string, epoch Fif_GHOSTARG(string_len))
-void   *string;
-double *epoch;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(parse_epoch__,
+	       parse_epoch_,
+	       parse_epoch,
+	       PARSE_EPOCH) (
+void   *string,
+double *epoch
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
 #if defined(Fif_DESCR)
@@ -59,11 +61,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(toparse_epoch__,toparse_epoch_,toparse_epoch,TOPARSE_EPOCH)
-(string, epoch Fif_GHOSTARG(string_len))
-void   *string;
-double *epoch;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(toparse_epoch__,
+	       toparse_epoch_,
+	       toparse_epoch,
+	       TOPARSE_EPOCH) (
+void   *string,
+double *epoch
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
 #if defined(Fif_DESCR)
@@ -87,11 +91,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(parse_epoch1__,parse_epoch1_,parse_epoch1,PARSE_EPOCH1)
-(string, epoch Fif_GHOSTARG(string_len))
-void   *string;
-double *epoch;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(parse_epoch1__,
+	       parse_epoch1_,
+	       parse_epoch1,
+	       PARSE_EPOCH1) (
+void   *string,
+double *epoch
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
 #if defined(Fif_DESCR)
@@ -115,11 +121,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(parse_epoch2__,parse_epoch2_,parse_epoch2,PARSE_EPOCH2)
-(string, epoch Fif_GHOSTARG(string_len))
-void   *string;
-double *epoch;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(parse_epoch2__,
+	       parse_epoch2_,
+	       parse_epoch2,
+	       PARSE_EPOCH2) (
+void   *string,
+double *epoch
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
 #if defined(Fif_DESCR)
@@ -143,11 +151,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(parse_epoch3__,parse_epoch3_,parse_epoch3,PARSE_EPOCH3)
-(string, epoch Fif_GHOSTARG(string_len))
-void   *string;
-double *epoch;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(parse_epoch3__,
+	       parse_epoch3_,
+	       parse_epoch3,
+	       PARSE_EPOCH3) (
+void   *string,
+double *epoch
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
 #if defined(Fif_DESCR)
@@ -171,11 +181,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(parse_epoch4__,parse_epoch4_,parse_epoch4,PARSE_EPOCH4)
-(string, epoch Fif_GHOSTARG(string_len))
-void   *string;
-double *epoch;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(parse_epoch4__,
+	       parse_epoch4_,
+	       parse_epoch4,
+	       PARSE_EPOCH4) (
+void   *string,
+double *epoch
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
 #if defined(Fif_DESCR)
@@ -199,11 +211,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(encode_epoch__,encode_epoch_,encode_epoch,ENCODE_EPOCH)
-(epoch, string Fif_GHOSTARG(string_len))
-double *epoch;
-void   *string;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(encode_epoch__,
+	       encode_epoch_,
+	       encode_epoch,
+	       ENCODE_EPOCH) (
+double *epoch,
+void   *string
+Fif_GHOSTDEF2(string_len))
 {
   char tString[EPOCH_STRING_LEN+1];
   encodeEPOCH (*epoch, tString);
@@ -223,12 +237,14 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(toencode_epoch__,toencode_epoch_,toencode_epoch,TOENCODE_EPOCH)
-(epoch, style, string Fif_GHOSTARG(string_len))
-double *epoch;
-int    *style;
-void   *string;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(toencode_epoch__,
+	       toencode_epoch_,
+	       toencode_epoch,
+	       TOENCODE_EPOCH) (
+double *epoch,
+int    *style,
+void   *string
+Fif_GHOSTDEF2(string_len))
 {
   char tString[EPOCH_STRING_LEN+1];
   int  style2 = *style;
@@ -258,11 +274,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(encode_epoch1__,encode_epoch1_,encode_epoch1,ENCODE_EPOCH1)
-(epoch, string Fif_GHOSTARG(string_len))
-double *epoch;
-void   *string;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(encode_epoch1__,
+	       encode_epoch1_,
+	       encode_epoch1,
+	       ENCODE_EPOCH1) (
+double *epoch,
+void   *string
+Fif_GHOSTDEF2(string_len))
 {
   char tString[EPOCH1_STRING_LEN+1];
   encodeEPOCH1 (*epoch, tString);
@@ -282,11 +300,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(encode_epoch2__,encode_epoch2_,encode_epoch2,ENCODE_EPOCH2)
-(epoch, string Fif_GHOSTARG(string_len))
-double *epoch;
-void   *string;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(encode_epoch2__,
+	       encode_epoch2_,
+	       encode_epoch2,
+	       ENCODE_EPOCH2) (
+double *epoch,
+void   *string
+Fif_GHOSTDEF2(string_len))
 {
   char tString[EPOCH2_STRING_LEN+1];
   encodeEPOCH2 (*epoch, tString);
@@ -306,11 +326,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(encode_epoch3__,encode_epoch3_,encode_epoch3,ENCODE_EPOCH3)
-(epoch, string Fif_GHOSTARG(string_len))
-double *epoch;
-void   *string;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(encode_epoch3__,
+	       encode_epoch3_,
+	       encode_epoch3,
+	       ENCODE_EPOCH3) (
+double *epoch,
+void   *string
+Fif_GHOSTDEF2(string_len))
 {
   char tString[EPOCH3_STRING_LEN+1];
   encodeEPOCH3 (*epoch, tString);
@@ -330,11 +352,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(encode_epoch4__,encode_epoch4_,encode_epoch4,ENCODE_EPOCH4)
-(epoch, string Fif_GHOSTARG(string_len))
-double *epoch;
-void   *string;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(encode_epoch4__,
+	       encode_epoch4_,
+	       encode_epoch4,
+	       ENCODE_EPOCH4) (
+double *epoch,
+void   *string 
+Fif_GHOSTDEF2(string_len))
 {
   char tString[EPOCH4_STRING_LEN+1];
   encodeEPOCH4 (*epoch, tString);
@@ -354,13 +378,15 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(encode_epochx__,encode_epochx_,encode_epochx,ENCODE_EPOCHX)
-(epoch, format, string Fif_GHOSTARG(format_len) Fif_GHOSTARG(string_len))
-double *epoch;
-void   *format;
-void   *string;
-Fif_GHOSTDEF(format_len)
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(encode_epochx__,
+	       encode_epochx_,
+	       encode_epochx,
+	       ENCODE_EPOCHX) (
+double *epoch,
+void   *format,
+void   *string 
+Fif_GHOSTDEF2(format_len)
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
   char tString[EPOCHx_STRING_MAX+1];
@@ -393,16 +419,15 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(epoch_breakdown__,
 	       epoch_breakdown_,
 	       epoch_breakdown,
-	       EPOCH_BREAKDOWN)
-(epoch, year, month, day, hour, minute, second, msec)
-double *epoch;
-Int32  *year;
-Int32  *month;
-Int32  *day;
-Int32  *hour;
-Int32  *minute;
-Int32  *second;
-Int32  *msec;
+	       EPOCH_BREAKDOWN) (
+double *epoch,
+Int32  *year,
+Int32  *month,
+Int32  *day,
+Int32  *hour,
+Int32  *minute,
+Int32  *second,
+Int32  *msec)
 {
   double tEpoch = *epoch;
   long tYear, tMonth, tDay, tHour, tMinute, tSecond, tMsec;
@@ -426,16 +451,18 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(compute_epoch__,compute_epoch_,compute_epoch,COMPUTE_EPOCH)
-(year, month, day, hour, minute, second, msec, epoch)
-Int32  *year;
-Int32  *month;
-Int32  *day;
-Int32  *hour;
-Int32  *minute;
-Int32  *second;
-Int32  *msec;
-double *epoch;
+Fif_ENTRYPOINT(compute_epoch__,
+	       compute_epoch_,
+	       compute_epoch,
+	       COMPUTE_EPOCH) (
+Int32  *year,
+Int32  *month,
+Int32  *day,
+Int32  *hour,
+Int32  *minute,
+Int32  *second,
+Int32  *msec,
+double *epoch)
 {
   *epoch = computeEPOCH ((long) *year, (long) *month, (long) *day,
 			 (long) *hour, (long) *minute, (long) *second,
@@ -451,26 +478,23 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(parse_epoch16__,parse_epoch16_,parse_epoch16,
-               PARSE_EPOCH16)
-(string, epoch Fif_GHOSTARG(string_len))
-void   *string;
-double *epoch;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(parse_epoch16__,
+	       parse_epoch16_,
+	       parse_epoch16,
+               PARSE_EPOCH16) (
+void   *string,
+double *epoch
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
-  double mmm;
 #if defined(Fif_DESCR)
-  mmm = parseEPOCH16(DESCRtoREFnul(string,EPOCH16_STRING_LEN,&ssh), 
-		         epoch);
+  parseEPOCH16(DESCRtoREFnul(string,EPOCH16_STRING_LEN,&ssh), epoch);
 #endif
 #if defined(Fif_GHOSTLEN)
-  mmm = parseEPOCH16(NULterminate(string,Fif_GHOSTUSE(string_len),&ssh), 
-		         epoch);
+  parseEPOCH16(NULterminate(string,Fif_GHOSTUSE(string_len),&ssh), epoch);
 #endif
 #if defined(Fif_NOLEN)
-  mmm = parseEPOCH16(FindEndNUL(string,EPOCH16_STRING_LEN,&ssh), 
-		         epoch);
+  parseEPOCH16(FindEndNUL(string,EPOCH16_STRING_LEN,&ssh), epoch);
 #endif
   FreeStrings (ssh);
   return;
@@ -484,24 +508,23 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(toparse_epoch16__,toparse_epoch16_,toparse_epoch16,
-               TOPARSE_EPOCH16)
-(string, epoch Fif_GHOSTARG(string_len))
-void   *string;
-double *epoch;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(toparse_epoch16__,
+	       toparse_epoch16_,
+	       toparse_epoch16,
+               TOPARSE_EPOCH16) (
+void   *string,
+double *epoch
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
-  double mmm;
 #if defined(Fif_DESCR)
-  mmm = toParseEPOCH16(DESCRtoREFnul(string,EPOCH16_STRING_LEN,&ssh), epoch);
+  toParseEPOCH16(DESCRtoREFnul(string,EPOCH16_STRING_LEN,&ssh), epoch);
 #endif
 #if defined(Fif_GHOSTLEN)
-  mmm = toParseEPOCH16(NULterminate(string,Fif_GHOSTUSE(string_len),&ssh), 
-		       epoch);
+  toParseEPOCH16(NULterminate(string,Fif_GHOSTUSE(string_len),&ssh), epoch);
 #endif
 #if defined(Fif_NOLEN)
-  mmm = toParseEPOCH16(FindEndNUL(string,EPOCH16_STRING_LEN,&ssh), epoch);
+  toParseEPOCH16(FindEndNUL(string,EPOCH16_STRING_LEN,&ssh), epoch);
 #endif
   FreeStrings (ssh);
   return;
@@ -515,24 +538,23 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(parse_epoch16_1__,parse_epoch16_1_,parse_epoch16_1,
-	       PARSE_EPOCH16_1)
-(string, epoch Fif_GHOSTARG(string_len))
-void   *string;
-double *epoch;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(parse_epoch16_1__,
+	       parse_epoch16_1_,
+	       parse_epoch16_1,
+	       PARSE_EPOCH16_1) (
+void   *string,
+double *epoch
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
-  double mmm;
 #if defined(Fif_DESCR)
-  mmm = parseEPOCH16_1(DESCRtoREFnul(string,EPOCH16_1_STRING_LEN,&ssh), epoch);
+  parseEPOCH16_1(DESCRtoREFnul(string,EPOCH16_1_STRING_LEN,&ssh), epoch);
 #endif
 #if defined(Fif_GHOSTLEN)
-  mmm = parseEPOCH16_1(NULterminate(string,Fif_GHOSTUSE(string_len),&ssh), 
-		       epoch);
+  parseEPOCH16_1(NULterminate(string,Fif_GHOSTUSE(string_len),&ssh), epoch);
 #endif
 #if defined(Fif_NOLEN)
-  mmm = parseEPOCH16_1(FindEndNUL(string,EPOCH16_1_STRING_LEN,&ssh), epoch);
+  parseEPOCH16_1(FindEndNUL(string,EPOCH16_1_STRING_LEN,&ssh), epoch);
 #endif
   FreeStrings (ssh);
   return;
@@ -546,24 +568,23 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(parse_epoch16_2__,parse_epoch16_2_,parse_epoch16_2,
-	       PARSE_EPOCH16_2)
-(string, epoch Fif_GHOSTARG(string_len))
-void   *string;
-double *epoch;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(parse_epoch16_2__,
+	       parse_epoch16_2_,
+	       parse_epoch16_2,
+	       PARSE_EPOCH16_2) (
+void   *string,
+double *epoch
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
-  double mmm;
 #if defined(Fif_DESCR)
-  mmm = parseEPOCH16_2(DESCRtoREFnul(string,EPOCH16_2_STRING_LEN,&ssh), epoch);
+  parseEPOCH16_2(DESCRtoREFnul(string,EPOCH16_2_STRING_LEN,&ssh), epoch);
 #endif
 #if defined(Fif_GHOSTLEN)
-  mmm = parseEPOCH16_2(NULterminate(string,Fif_GHOSTUSE(string_len),&ssh), 
-		       epoch);
+  parseEPOCH16_2(NULterminate(string,Fif_GHOSTUSE(string_len),&ssh), epoch);
 #endif
 #if defined(Fif_NOLEN)
-  mmm = parseEPOCH16_2(FindEndNUL(string,EPOCH16_2_STRING_LEN,&ssh), epoch);
+  parseEPOCH16_2(FindEndNUL(string,EPOCH16_2_STRING_LEN,&ssh), epoch);
 #endif
   FreeStrings (ssh);
   return;
@@ -577,24 +598,23 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(parse_epoch16_3__,parse_epoch16_3_,parse_epoch16_3,
-	       PARSE_EPOCH16_3)
-(string, epoch Fif_GHOSTARG(string_len))
-void   *string;
-double *epoch;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(parse_epoch16_3__,
+	       parse_epoch16_3_,
+	       parse_epoch16_3,
+	       PARSE_EPOCH16_3) (
+void   *string,
+double *epoch
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
-  double mmm;
 #if defined(Fif_DESCR)
-  mmm = parseEPOCH16_3(DESCRtoREFnul(string,EPOCH16_3_STRING_LEN,&ssh), epoch);
+  parseEPOCH16_3(DESCRtoREFnul(string,EPOCH16_3_STRING_LEN,&ssh), epoch);
 #endif
 #if defined(Fif_GHOSTLEN)
-  mmm = parseEPOCH16_3(NULterminate(string,Fif_GHOSTUSE(string_len),&ssh), 
-		       epoch);
+  parseEPOCH16_3(NULterminate(string,Fif_GHOSTUSE(string_len),&ssh), epoch);
 #endif
 #if defined(Fif_NOLEN)
-  mmm = parseEPOCH16_3(FindEndNUL(string,EPOCH16_3_STRING_LEN,&ssh), epoch);
+  parseEPOCH16_3(FindEndNUL(string,EPOCH16_3_STRING_LEN,&ssh), epoch);
 #endif
   FreeStrings (ssh);
   return;
@@ -608,24 +628,23 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(parse_epoch16_4__,parse_epoch16_4_,parse_epoch16_4,
-	       PARSE_EPOCH16_4)
-(string, epoch Fif_GHOSTARG(string_len))
-void   *string;
-double *epoch;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(parse_epoch16_4__,
+	       parse_epoch16_4_,
+	       parse_epoch16_4,
+	       PARSE_EPOCH16_4) (
+void   *string,
+double *epoch
+Fif_GHOSTDEF2(string_len))
 {
   struct STRINGstruct *ssh = NULL;
-  double mmm;
 #if defined(Fif_DESCR)
-  mmm = parseEPOCH16_4(DESCRtoREFnul(string,EPOCH16_4_STRING_LEN,&ssh), epoch);
+  parseEPOCH16_4(DESCRtoREFnul(string,EPOCH16_4_STRING_LEN,&ssh), epoch);
 #endif
 #if defined(Fif_GHOSTLEN)
-  mmm = parseEPOCH16_4(NULterminate(string,Fif_GHOSTUSE(string_len),&ssh), 
-		       epoch);
+  parseEPOCH16_4(NULterminate(string,Fif_GHOSTUSE(string_len),&ssh), epoch);
 #endif
 #if defined(Fif_NOLEN)
-  mmm = parseEPOCH16_4(FindEndNUL(string,EPOCH16_4_STRING_LEN,&ssh), epoch);
+  parseEPOCH16_4(FindEndNUL(string,EPOCH16_4_STRING_LEN,&ssh), epoch);
 #endif
   FreeStrings (ssh);
   return;
@@ -639,12 +658,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(encode_epoch16__,encode_epoch16_,encode_epoch16,
-	       ENCODE_EPOCH16)
-(epoch, string Fif_GHOSTARG(string_len))
-double *epoch;
-void   *string;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(encode_epoch16__,
+	       encode_epoch16_,
+	       encode_epoch16,
+	       ENCODE_EPOCH16) (
+double *epoch,
+void   *string 
+Fif_GHOSTDEF2(string_len))
 {
   char tString[EPOCH16_STRING_LEN+1];
   encodeEPOCH16 (epoch, tString);
@@ -664,13 +684,14 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(toencode_epoch16__,toencode_epoch16_,toencode_epoch16,
-	       toENCODE_EPOCH16)
-(epoch, style, string Fif_GHOSTARG(string_len))
-double *epoch;
-int    *style;
-void   *string;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(toencode_epoch16__,
+	       toencode_epoch16_,
+	       toencode_epoch16,
+	       toENCODE_EPOCH16) (
+double *epoch,
+int    *style,
+void   *string 
+Fif_GHOSTDEF2(string_len))
 {
   char tString[EPOCH16_STRING_LEN+1];
   int  style2 = *style;
@@ -700,12 +721,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(encode_epoch16_1__,encode_epoch16_1_,encode_epoch16_1,
-	       ENCODE_EPOCH16_1)
-(epoch, string Fif_GHOSTARG(string_len))
-double *epoch;
-void   *string;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(encode_epoch16_1__,
+	       encode_epoch16_1_,
+	       encode_epoch16_1,
+	       ENCODE_EPOCH16_1) (
+double *epoch,
+void   *string 
+Fif_GHOSTDEF2(string_len))
 {
   char tString[EPOCH16_1_STRING_LEN+1];
   encodeEPOCH16_1 (epoch, tString);
@@ -725,12 +747,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(encode_epoch16_2__,encode_epoch16_2_,encode_epoch16_2,
-	       ENCODE_EPOCH16_2)
-(epoch, string Fif_GHOSTARG(string_len))
-double *epoch;
-void   *string;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(encode_epoch16_2__,
+	       encode_epoch16_2_,
+	       encode_epoch16_2,
+	       ENCODE_EPOCH16_2) (
+double *epoch,
+void   *string 
+Fif_GHOSTDEF2(string_len))
 {
   char tString[EPOCH16_2_STRING_LEN+1];
   encodeEPOCH16_2 (epoch, tString);
@@ -750,12 +773,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(encode_epoch16_3__,encode_epoch16_3_,encode_epoch16_3,
-	       ENCODE_EPOCH16_3)
-(epoch, string Fif_GHOSTARG(string_len))
-double *epoch;
-void   *string;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(encode_epoch16_3__,
+	       encode_epoch16_3_,
+	       encode_epoch16_3,
+	       ENCODE_EPOCH16_3) (
+double *epoch,
+void   *string 
+Fif_GHOSTDEF2(string_len))
 {
   char tString[EPOCH16_3_STRING_LEN+1];
   encodeEPOCH16_3 (epoch, tString);
@@ -775,12 +799,13 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(encode_epoch16_4__,encode_epoch16_4_,encode_epoch16_4,
-	       ENCODE_EPOCH16_4)
-(epoch, string Fif_GHOSTARG(string_len))
-double *epoch;
-void   *string;
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(encode_epoch16_4__,
+	       encode_epoch16_4_,
+	       encode_epoch16_4,
+	       ENCODE_EPOCH16_4) (
+double *epoch,
+void   *string 
+Fif_GHOSTDEF2(string_len))
 {
   char tString[EPOCH16_4_STRING_LEN+1];
   encodeEPOCH16_4 (epoch, tString);
@@ -800,14 +825,15 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(encode_epoch16_x__,encode_epoch16_x_,encode_epoch16_x,
-	       ENCODE_EPOCH16_X)
-(epoch, format, string Fif_GHOSTARG(format_len) Fif_GHOSTARG(string_len))
-double *epoch;
-void   *format;
-void   *string;
-Fif_GHOSTDEF(format_len)
-Fif_GHOSTDEF(string_len)
+Fif_ENTRYPOINT(encode_epoch16_x__,
+	       encode_epoch16_x_,
+	       encode_epoch16_x,
+	       ENCODE_EPOCH16_X) (
+double *epoch,
+void   *format,
+void   *string 
+Fif_GHOSTDEF2(format_len)
+Fif_GHOSTDEF2(string_len)) 
 {
   struct STRINGstruct *ssh = NULL;
   char tString[EPOCHx_STRING_MAX+1];
@@ -842,19 +868,18 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(epoch16_breakdown__,
 	       epoch16_breakdown_,
 	       epoch16_breakdown,
-	       EPOCH16_BREAKDOWN)
-(epoch, year, month, day, hour, minute, second, msec, usec, nsec, psec)
-double *epoch;
-Int32  *year;
-Int32  *month;
-Int32  *day;
-Int32  *hour;
-Int32  *minute;
-Int32  *second;
-Int32  *msec;
-Int32  *usec;
-Int32  *nsec;
-Int32  *psec;
+	       EPOCH16_BREAKDOWN) (
+double *epoch,
+Int32  *year,
+Int32  *month,
+Int32  *day,
+Int32  *hour,
+Int32  *minute,
+Int32  *second,
+Int32  *msec,
+Int32  *usec,
+Int32  *nsec,
+Int32  *psec)
 {
   double tEpoch[2];
   long tYear, tMonth, tDay, tHour, tMinute, tSecond, tMsec, tUsec, tNsec,
@@ -884,26 +909,26 @@ VISIBLE_PREFIX
 Fif_PREFIXa
 void
 Fif_PREFIXb
-Fif_ENTRYPOINT(compute_epoch16__,compute_epoch16_,compute_epoch16,
-	       COMPUTE_EPOCH16)
-(year, month, day, hour, minute, second, msec, usec, nsec, psec, epoch)
-Int32  *year;
-Int32  *month;
-Int32  *day;
-Int32  *hour;
-Int32  *minute;
-Int32  *second;
-Int32  *msec;
-Int32  *usec;
-Int32  *nsec; 
-Int32  *psec;
-double *epoch;
+Fif_ENTRYPOINT(compute_epoch16__,
+	       compute_epoch16_,
+	       compute_epoch16,
+	       COMPUTE_EPOCH16) (
+Int32  *year,
+Int32  *month,
+Int32  *day,
+Int32  *hour,
+Int32  *minute,
+Int32  *second,
+Int32  *msec,
+Int32  *usec,
+Int32  *nsec, 
+Int32  *psec,
+double *epoch)
 {
-  double mmm;
-  mmm = computeEPOCH16 ((long) *year, (long) *month, (long) *day,
-			    (long) *hour, (long) *minute, (long) *second,
-			    (long) *msec, (long) *usec, (long) *nsec, 
-			    (long) *psec, epoch);
+  computeEPOCH16 ((long) *year, (long) *month, (long) *day,
+		  (long) *hour, (long) *minute, (long) *second,
+		  (long) *msec, (long) *usec, (long) *nsec, 
+		  (long) *psec, epoch);
   return;
 }
 
@@ -918,11 +943,10 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(epoch_to_unixtime__,
                epoch_to_unixtime_,
                epoch_to_unixtime,
-               EPOCH_TO_UNIXTIME)
-(epochs, unixTimes, num)
-double *epochs;
-double *unixTimes;
-int  *num;
+               EPOCH_TO_UNIXTIME) (
+double *epochs,
+double *unixTimes,
+int  *num)
 {
   EPOCHtoUnixTime (epochs, unixTimes, *num);
 }
@@ -938,11 +962,10 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(unixtime_to_epoch__,
                unixtime_to_epoch_,
                unixtime_to_epoch,
-               UNIXTIME_TO_EPOCH)
-(unixTimes, epochs, num)
-double *unixTimes;
-double *epochs;
-int  *num;
+               UNIXTIME_TO_EPOCH) (
+double *unixTimes,
+double *epochs,
+int  *num)
 {
   UnixTimetoEPOCH (unixTimes, epochs, *num);
 }
@@ -958,11 +981,10 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(epoch16_to_unixtime__,
                epoch16_to_unixtime_,
                epoch16_to_unixtime,
-               EPOCH16_TO_UNIXTIME)
-(epochs, unixTimes, num)
-double *epochs;
-double *unixTimes;
-int  *num;
+               EPOCH16_TO_UNIXTIME) (
+double *epochs,
+double *unixTimes,
+int  *num)
 {
   EPOCH16toUnixTime (epochs, unixTimes, *num);
 }
@@ -978,11 +1000,10 @@ Fif_PREFIXb
 Fif_ENTRYPOINT(unixtime_to_epoch16__,
                unixtime_to_epoch16_,
                unixtime_to_epoch16,
-               UNIXTIME_TO_EPOCH16)
-(unixTimes, epochs, num)
-double *unixTimes;
-double *epochs;
-int  *num;
+               UNIXTIME_TO_EPOCH16) (
+double *unixTimes,
+double *epochs,
+int  *num)
 {
   UnixTimetoEPOCH16 (unixTimes, epochs, *num);
 }
