@@ -61,6 +61,8 @@
 #  include "errno.h"
 #endif
 
+static int ccc1 = 0, ccc11 = 0, ccc12 = 0, ccc2 = 0, ccc3 = 0;
+static int sc = 0, nsc = 0;
 /******************************************************************************
 * Local macros/typedef's.
 ******************************************************************************/
@@ -101,7 +103,7 @@ static Logical vRead PROTOARGs((
 static Logical vWrite PROTOARGs((
   long offset, void *buffer, size_t nBytes, vFILE *vFp
 ));
-static vCACHE *AllocateBuffer PROTOARGs((vFILE *vFp));
+static vCACHE *AllocateBuffer PROTOARGs((vFILE *vFp, Logical *new));
 static vCACHE *PageIn PROTOARGs((vFILE *vFp, long blockN));
 static Logical WriteBlockFromCache PROTOARGs((
   vFILE *vFp, vCACHE *cache, size_t Nbytes
@@ -117,9 +119,9 @@ static Logical ExtendFile PROTOARGs((vFILE *vFp, long toBlockN));
 * CDFOpenFile.
 ******************************************************************************/
 
-static FILE *CDFOpenFile (file_spec, a_mode)
-char *file_spec;
-char *a_mode;
+static FILE *CDFOpenFile (
+char *file_spec,
+char *a_mode)
 {
 #if defined(vms)
   char mrs[10+1];       /* Maximum record size. */
@@ -137,32 +139,43 @@ char *a_mode;
 * FindCache.
 ******************************************************************************/
 
-static vCACHE *FindCache (vFp, blockN)
-vFILE *vFp;
-long blockN;
+static vCACHE *FindCache (
+vFILE *vFp,
+long blockN)
 {
-  vCACHE *cache = vFp->cacheHead;
-  while (cache != NULL) {
-    if (cache->blockN == blockN) {
-      if (cache != vFp->cacheHead) {
-	if (cache == vFp->cacheTail) {
-	  cache->prev->next = NULL;
-	  vFp->cacheTail = cache->prev;
+++ccc1;
+
+  if (vFp->scratch && vFp->fp == NULL && vFp->cacheNumInd != NULL) {
+++ccc11;
+    if (vFp->cacheNumInd[(int)blockN] == 1) {
+      return vFp->cacheLocPtr[(int)blockN];
+    } else
+      return NULL;
+  } else {
+    vCACHE *cache = vFp->cacheHead;
+    while (cache != NULL) {
+++ccc12;
+      if (cache->blockN == blockN) {
+	if (cache != vFp->cacheHead) {
+	  if (cache == vFp->cacheTail) {
+	    cache->prev->next = NULL;
+	    vFp->cacheTail = cache->prev;
+	  }
+	  else {
+	    cache->next->prev = cache->prev;
+	    cache->prev->next = cache->next;
+	  }
+	  vFp->cacheHead->prev = cache;
+	  cache->next = vFp->cacheHead;
+	  vFp->cacheHead = cache;
+	  cache->prev = NULL;
 	}
-	else {
-	  cache->next->prev = cache->prev;
-	  cache->prev->next = cache->next;
-	}
-	vFp->cacheHead->prev = cache;
-	cache->next = vFp->cacheHead;
-	vFp->cacheHead = cache;
-	cache->prev = NULL;
+	return cache;
       }
-      return cache;
+      cache = cache->next;
     }
-    cache = cache->next;
+    return NULL;
   }
-  return NULL;
 }
 
 /******************************************************************************
@@ -171,9 +184,9 @@ long blockN;
 * buffer.
 ******************************************************************************/
 
-VISIBLE_PREFIX Logical FlushCache (vFp, firstCache)
-vFILE *vFp;             /* Pointer to vFILE structure. */
-vCACHE *firstCache;     /* Pointer to the first cache structure to flush. */
+VISIBLE_PREFIX Logical FlushCache (
+vFILE *vFp,             /* Pointer to vFILE structure. */
+vCACHE *firstCache)     /* Pointer to the first cache structure to flush. */
 {
   vCACHE *cache; long nBytes;
   for (cache = firstCache; cache != NULL; cache = cache->next) {
@@ -195,8 +208,8 @@ vCACHE *firstCache;     /* Pointer to the first cache structure to flush. */
 * FreeCache.
 ******************************************************************************/
 
-static Logical FreeCache (firstCache)
-vCACHE *firstCache;     /* Pointer to the first cache structure to free. */
+static Logical FreeCache (
+vCACHE *firstCache)     /* Pointer to the first cache structure to free. */
 {
   vCACHE *cache = firstCache;
   while (cache != NULL) {
@@ -209,6 +222,7 @@ vCACHE *firstCache;     /* Pointer to the first cache structure to free. */
       cdf_FreeMemory (cache->ptr, NULL);
     cdf_FreeMemory (cache, NULL);
     cache = nextCache;
+ccc3++;
   }
   return TRUE;
 }
@@ -220,8 +234,9 @@ vCACHE *firstCache;     /* Pointer to the first cache structure to free. */
 * an error occurred).
 ******************************************************************************/
 
-static vCACHE *AllocateBuffer (vFp)
-vFILE *vFp;
+static vCACHE *AllocateBuffer (
+vFILE *vFp,
+Logical *new)
 {
   vCACHE *cache; long nBytes;
 #if !defined(vms)
@@ -232,9 +247,13 @@ vFILE *vFp;
   * fail, process as if the maximum number of cache buffers has already been
   * reached.
   ****************************************************************************/
+  *new = FALSE;
   if (vFp->nBuffers < vFp->maxBuffers) {
     cache = (vCACHE *) cdf_AllocateMemory ((size_t)sizeof(vCACHE), NULL);
     if (cache != NULL) {
+  *new = TRUE;
+if (vFp->scratch) ++sc;
+else ++nsc;
 #if defined(MICROSOFTC_700) && INCLUDEvMEMORY
       if (useVmem)
 	cache->ptr = (void *) AllocateVMemory (nCACHE_BUFFER_BYTEs);
@@ -256,6 +275,7 @@ vFILE *vFp;
 	}
 	(vFp->nBuffers)++;
 	memset(cache->ptr, 0, nCACHE_BUFFER_BYTEs);
+ccc2++;
 	return cache;
       }
       else {
@@ -286,6 +306,7 @@ vFILE *vFp;
 	 vFp->cacheHead = cache;
 	 cache->prev = NULL;
        }
+ccc2++;
        return cache;
      }
   }
@@ -313,6 +334,7 @@ vFILE *vFp;
   }
   (vFp->nPageOuts)++;
   memset(cache->ptr, 0, nCACHE_BUFFER_BYTEs);
+ccc2++;
   return cache;
 }
 
@@ -322,9 +344,9 @@ vFILE *vFp;
 ******************************************************************************/
 
 #if EXTEND_FILE
-static Logical ExtendFile (vFp, toBlockN)
-vFILE *vFp;
-long toBlockN;
+static Logical ExtendFile (
+vFILE *vFp,
+long toBlockN)
 {
   vCACHE *cache; long blockN;
   /****************************************************************************
@@ -388,13 +410,18 @@ long toBlockN;
 * NULL if an error occurred).
 ******************************************************************************/
 
-static vCACHE *PageIn (vFp, blockN)
-vFILE *vFp;
-long blockN;
+static vCACHE *PageIn (
+vFILE *vFp,
+long blockN)
 {
   long offset, nBytes; vCACHE *cache; void *buffer;
-  cache = AllocateBuffer (vFp);
+  Logical new;
+  cache = AllocateBuffer (vFp, &new);
   if (cache == NULL) return NULL;
+  if (vFp->scratch && vFp->fp == NULL && new) {
+    vFp->cacheNumInd[blockN] = 1;
+    vFp->cacheLocPtr[blockN] = cache;
+  }
   offset = blockN * nCACHE_BUFFER_BYTEs;
   nBytes = vFp->phyLength - offset;
   nBytes = MINIMUM (nBytes, nCACHE_BUFFER_BYTEs);
@@ -416,10 +443,10 @@ long blockN;
 * successful, FALSE if an error occurred.
 ******************************************************************************/
 
-static Logical WriteBlockFromCache (vFp, cache, nBytes)
-vFILE *vFp;
-vCACHE *cache;
-size_t nBytes;
+static Logical WriteBlockFromCache (
+vFILE *vFp,
+vCACHE *cache,
+size_t nBytes)
 {
   long offset; void *buffer;
   offset = nCACHE_BUFFER_BYTEs * cache->blockN;
@@ -441,11 +468,11 @@ size_t nBytes;
 * successful, FALSE if an error occurred.
 ******************************************************************************/
 
-static Logical WriteBlockFromBuffer (vFp, blockN, buffer, nBytes)
-vFILE *vFp;
-long blockN;
-void *buffer;
-size_t nBytes;
+static Logical WriteBlockFromBuffer (
+vFILE *vFp,
+long blockN,
+void *buffer,
+size_t nBytes)
 {
   long offset = nCACHE_BUFFER_BYTEs * blockN;
 #if EXTEND_FILE
@@ -462,11 +489,11 @@ size_t nBytes;
 * vRead.
 ******************************************************************************/
 
-static Logical vRead (offset, buffer, nBytes, vFp)
-long offset;
-void *buffer;
-size_t nBytes;
-vFILE *vFp;
+static Logical vRead (
+long offset,
+void *buffer,
+size_t nBytes,
+vFILE *vFp)
 {
   int tryN;
   /****************************************************************************
@@ -491,11 +518,11 @@ vFILE *vFp;
 * vWrite.
 ******************************************************************************/
 
-static Logical vWrite(offset,buffer,nBytes,vFp)
-long offset;
-void *buffer;
-size_t nBytes;
-vFILE *vFp;
+static Logical vWrite(
+long offset,
+void *buffer,
+size_t nBytes,
+vFILE *vFp)
 {
   int tryN;
 #if defined(__MWERKS__)
@@ -530,6 +557,9 @@ vFILE *vFp;
   * actually the scratch directory to be used.
   ****************************************************************************/
   if (vFp->fp == NULL) {
+#if __XSI_VISIBLE >= 4
+int ix;
+#endif
     long i; char *tmpPath; size_t pathLength;
     pathLength = strlen(vFp->path) + 1 + 8 + 1 + EXT_LEN;
     if (pathLength < DU_MAX_DIR_LEN) pathLength = DU_MAX_DIR_LEN;
@@ -538,8 +568,9 @@ vFILE *vFp;
     if (vFp->path != NULL && strlen(vFp->path) != 0) { 
       strcpyX (tmpPath, vFp->path, 0);
       AppendToDir (tmpPath, "");
-#     if defined(unix) || defined(vms)
-        strcatX (tmpPath, TmpFileTemplate, 0);
+#     if defined(unix) || defined(vms) || defined(__CYGWIN__)
+        strcatX (tmpPath, TmpFileTemplate, strlen(TmpFileTemplate),
+		 strlen(tmpPath), 0);
         fileid = mkstemp(tmpPath);
         if (fileid != -1) fp = fdopen(fileid, "w+");
         else {
@@ -547,7 +578,8 @@ vFILE *vFp;
             strcpyX (tmpPath, vFp->path, 0);
             AppendToDir (tmpPath, "");
             snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
-                      "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+                      "TMP%08ld.%s", (long)(rand()%100000000),
+                      vFp->scratchExt);
             if (!IsReg(tmpPath)) {
               fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
               if (fp != NULL) break;
@@ -556,7 +588,8 @@ vFILE *vFp;
         }
 #     else
 #       if defined(win32)
-          strcatX (tmpPath, TmpFileTemplate, 0);
+          strcatX (tmpPath, TmpFileTemplate, strlen(TmpFileTemplate),
+		   strlen(tmpPath), 0);
           err = _mktemp_s(tmpPath, (int)strlen(tmpPath)+1);
           if (err == 0) {
             fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
@@ -564,8 +597,10 @@ vFILE *vFp;
             if (err == EEXIST) {
               int i1, i2;
               for (i = 1; i <= MAX_TMP; i++) {
-                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
-                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
+                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) +
+                     (int) 'A';
+                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) +
+                     (int) 'A';
                 strcpyX (tmpPath, vFp->path, 0);
                 AppendToDir (tmpPath, "");
                 snprintf (EofS(tmpPath), (size_t) pathLength + 1 -
@@ -583,7 +618,8 @@ vFILE *vFp;
             strcpyX (tmpPath, vFp->path, (size_t)pathLength);
             AppendToDir (tmpPath, "");
             snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
-                      "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+                      "TMP%08ld.%s", (long)(rand()%100000000),
+                      vFp->scratchExt);
             if (!IsReg(tmpPath)) fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
             if (fp != NULL) break;
           }
@@ -607,15 +643,18 @@ vFILE *vFp;
             strcpyX (tmpPath, "SYS$SCRATCH:", (size_t)pathLength);
             strcpyX (tmpFolder, tmpPath, (size_t)pathLength);
 #         endif
-          strcatX (tmpPath, TmpFileTemplate, 0);
+          strcatX (tmpPath, TmpFileTemplate, strlen(TmpFileTemplate),
+		   strlen(tmpPath), 0);
         }
         fileid = mkstemp(tmpPath);
-        if (fileid != -1) fp = fdopen(fileid, "w+");
-        else {
+        if (fileid != -1) {
+	  fp = fdopen(fileid, "w+");
+        } else {
           for (i = 1; i <= MAX_TMP; i++) {
             strcpyX (tmpPath, tmpFolder, (size_t)pathLength);
             snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
-                      "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+                      "TMP%08ld.%s", (long)(rand()%100000000),
+                      vFp->scratchExt);
             if (!IsReg(tmpPath)) {
               fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
               if (fp != NULL) break;
@@ -625,7 +664,8 @@ vFILE *vFp;
         if (tmpFolder != NULL) cdf_FreeMemory (tmpFolder, NULL);
 #     else
 #       if defined(win32)
-          strcatX (tmpPath, TmpFileTemplate, 0);
+          strcatX (tmpPath, TmpFileTemplate, strlen(TmpFileTemplate),
+		   strlen(tmpPath), 0);
           err = _mktemp_s(tmpPath, (int)strlen(tmpPath)+1 );
           if (err == 0) {
             fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
@@ -634,8 +674,10 @@ vFILE *vFp;
               int i1, i2;
               for (i = 1; i <= MAX_TMP; i++) {
                 strcpyX (tmpPath, "", (size_t)pathLength);
-                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
-                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
+                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) +
+                     (int) 'A';
+                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) +
+                     (int) 'A';
                 snprintf (EofS(tmpPath), (size_t) pathLength + 1 -
                                          strlen(tmpPath),
                           "TMP%c%c%5.5d.%s", i1, i2, rand(), vFp->scratchExt);
@@ -651,7 +693,9 @@ vFILE *vFp;
 #       else
           snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
                     "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
-          if (!IsReg(tmpPath)) fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+          if (!IsReg(tmpPath)) {
+	    fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+	  }
 #       endif
 #     endif
     }
@@ -688,9 +732,9 @@ vFILE *vFp;
 * Open the file and setup vFILE structure.
 ******************************************************************************/
 
-VISIBLE_PREFIX vFILE *V_open (file_spec, a_mode)
-char *file_spec;        /* File specification. */
-char *a_mode;           /* Access mode. */
+VISIBLE_PREFIX vFILE *V_open (
+char *file_spec,        /* File specification. */
+char *a_mode)           /* Access mode. */
 {
   FILE *fp;             /* Temporary file pointer. */
   vFILE *vFp;           /* Pointer to vFILE structure. */
@@ -724,7 +768,8 @@ char *a_mode;           /* Access mode. */
     }
     EOFoffsetInBlock = eof % nCACHE_BUFFER_BYTEs;
     if (EOFoffsetInBlock != 0) {
-      long offsetToLastBlock; char buffer[nCACHE_BUFFER_BYTEs]; size_t numitems; int i;
+      long offsetToLastBlock; char buffer[nCACHE_BUFFER_BYTEs];
+      size_t numitems; int i;
       offsetToLastBlock = nCACHE_BUFFER_BYTEs * (eof / nCACHE_BUFFER_BYTEs);
       if (fseek(fp,offsetToLastBlock,vSEEK_SET) == EOF) {
 	fclose (fp);
@@ -763,7 +808,8 @@ char *a_mode;           /* Access mode. */
   }
   vFp->magic_number = VSTREAM_MAGIC_NUMBER;
   vFp->fp = fp;
-  vFp->path = (char *) cdf_AllocateMemory ((size_t)strlen(file_spec) + 1, NULL);
+  vFp->path = (char *) cdf_AllocateMemory ((size_t)strlen(file_spec) + 1,
+                                           NULL);
   if (vFp->path == NULL) {
     cdf_FreeMemory (vFp, NULL);
     fclose (fp);
@@ -787,6 +833,8 @@ char *a_mode;           /* Access mode. */
   vFp->GDR64 = NULL;
   vFp->ADRList = NULL;
   vFp->ADRList64 = NULL;
+vFp->cacheNumInd = NULL;
+vFp->cacheLocPtr = NULL;
   /****************************************************************************
   * Determine length of file and set current offset.
   ****************************************************************************/
@@ -833,10 +881,10 @@ char *a_mode;           /* Access mode. */
 * block needs to be paged out.
 ******************************************************************************/
 
-VISIBLE_PREFIX vFILE *V_scratch (directory, extension)
-char *directory;	/* Directory in which to create the scratch file (if
+VISIBLE_PREFIX vFILE *V_scratch (
+char *directory,	/* Directory in which to create the scratch file (if
 			   necessary).  If NULL, use the current directory. */
-char *extension;	/* Extension to use for the scratch file.  If NULL,
+char *extension)	/* Extension to use for the scratch file.  If NULL,
 			   `.ich' is used. */
 {
   vFILE *vFp;           /* Pointer to vFILE structure. */
@@ -879,12 +927,61 @@ char *extension;	/* Extension to use for the scratch file.  If NULL,
   vFp->GDR64 = NULL;
   vFp->ADRList = NULL;
   vFp->ADRList64 = NULL;
+  vFp->cacheNumInd = (long *) cdf_AllocateMemory ((size_t)sizeof(long) *
+						  NUMcacheCOMPRESS, NULL);
+  vFp->cacheLocPtr = (vCACHE **) cdf_AllocateMemory ((size_t)sizeof(vCACHE *) *
+						     NUMcacheCOMPRESS, NULL);
+  memset (vFp->cacheNumInd, 0, NUMcacheCOMPRESS * sizeof(long));
+  memset (vFp->cacheLocPtr, 0, NUMcacheCOMPRESS * sizeof(vCACHE *));
   /****************************************************************************
   * Return pointer to vFILE structure.
   ****************************************************************************/
   return vFp;
 }
 
+/******************************************************************************
+* V_stagereset.
+* Reset the staging area and its scratch file pointer.
+******************************************************************************/
+
+VISIBLE_PREFIX void V_stagereset (
+struct CDFstruct *CDF)
+{
+  vFILE *vFp = CDF->stage.fp;
+  CDF->stage.mark64 = (OFF_T) ZERO_OFFSET64;
+  CDF->stage.mark = ZERO_OFFSET;
+  vFp->fp = NULL;
+  vFp->fh = 0;
+  vFp->scratch = TRUE;
+  vFp->error = FALSE;
+  vFp->eof = FALSE;
+  vFp->cacheHead = NULL;
+  vFp->cacheTail = NULL;
+  vFp->nBuffers = 0;
+  vFp->nBlockReads = 0;
+  vFp->nBlockWrites = 0;
+  vFp->nV_reads = 0;
+  vFp->nV_writes = 0;
+  vFp->nPageIns = 0;
+  vFp->nPageOuts = 0;
+  vFp->length = 0;
+  vFp->length64 = (OFF_T) 0;
+  vFp->phyLength = 0;
+  vFp->phyLength64 = (OFF_T) 0;
+  vFp->offset = 0;
+  vFp->offset64 = (OFF_T) 0;
+  vFp->GDR = NULL;
+  vFp->GDR64 = NULL;
+  vFp->ADRList = NULL;
+  vFp->ADRList64 = NULL;
+  vFp->cacheNumInd = (long *) cdf_AllocateMemory ((size_t)sizeof(long) *
+						  NUMcacheCOMPRESS, NULL);
+  vFp->cacheLocPtr = (vCACHE **) cdf_AllocateMemory ((size_t)sizeof(vCACHE *) *
+						     NUMcacheCOMPRESS, NULL);
+  memset (vFp->cacheNumInd, 0, NUMcacheCOMPRESS * sizeof(long));
+  memset (vFp->cacheLocPtr, 0, NUMcacheCOMPRESS * sizeof(vCACHE *));
+}
+
 /******************************************************************************
 * V_setcache.
 * Set number of cache buffers.  This can be done at any time after the file
@@ -892,9 +989,9 @@ char *extension;	/* Extension to use for the scratch file.  If NULL,
 * the old cache size (do nothing).
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_setcache (vFp, maxBuffers)
-vFILE *vFp;             /* Pointer to vFILE structure. */
-int maxBuffers;         /* New maximum number of cache buffers. */
+VISIBLE_PREFIX int V_setcache (
+vFILE *vFp,             /* Pointer to vFILE structure. */
+int maxBuffers)         /* New maximum number of cache buffers. */
 {
   if (vFp == NULL) return EOF;
   if (vFp->magic_number != VSTREAM_MAGIC_NUMBER) return EOF;
@@ -932,15 +1029,26 @@ int maxBuffers;         /* New maximum number of cache buffers. */
   return 0;
 }
 
+/******************************************************************************
+* V_freecaches.
+* Free the caches from head to tail.
+******************************************************************************/
+
+VISIBLE_PREFIX void V_freecaches (
+vFILE *vFp)
+{
+  FreeCache(vFp->cacheHead);
+}
+
 /******************************************************************************
 * V_seek.
 * Seek to a position in the file.
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_seek (vFp, offset, direction)
-vFILE *vFp;             /* Pointer to vFILE structure. */
-long offset;            /* New current file offset. */
-int direction;          /* Reference for offset. */
+VISIBLE_PREFIX int V_seek (
+vFILE *vFp,             /* Pointer to vFILE structure. */
+long offset,            /* New current file offset. */
+int direction)          /* Reference for offset. */
 {
   if (vFp == NULL) return EOF;
   if (vFp->magic_number != VSTREAM_MAGIC_NUMBER) return EOF;
@@ -970,8 +1078,8 @@ int direction;          /* Reference for offset. */
 * the last byte that exists.
 ******************************************************************************/
 
-VISIBLE_PREFIX long V_tell (vFp)
-vFILE *vFp;             /* Pointer to vFILE structure. */
+VISIBLE_PREFIX long V_tell (
+vFILE *vFp)             /* Pointer to vFILE structure. */
 {
   if (vFp == NULL) return EOF;
   if (vFp->magic_number != VSTREAM_MAGIC_NUMBER) return EOF;
@@ -985,8 +1093,8 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
 * before the EOF indicator will be set (just like `feof').
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_eof (vFp)
-vFILE *vFp;	/* Pointer to vFILE structure. */
+VISIBLE_PREFIX int V_eof (
+vFILE *vFp)	/* Pointer to vFILE structure. */
 {
   if (vFp == NULL) return EOF;
   if (vFp->magic_number != VSTREAM_MAGIC_NUMBER) return EOF;
@@ -999,8 +1107,8 @@ vFILE *vFp;	/* Pointer to vFILE structure. */
 * Returns non-zero if error indicator is set.
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_error (vFp)
-vFILE *vFp;	/* Pointer to vFILE structure. */
+VISIBLE_PREFIX int V_error (
+vFILE *vFp)	/* Pointer to vFILE structure. */
 {
   if (vFp == NULL) return EOF;
   if (vFp->magic_number != VSTREAM_MAGIC_NUMBER) return EOF;
@@ -1012,11 +1120,11 @@ vFILE *vFp;	/* Pointer to vFILE structure. */
 * V_read.
 ******************************************************************************/
 
-VISIBLE_PREFIX size_t V_read (buffer, item_size, n_items, vFp)
-void *buffer;           /* Pointer to buffer. */
-size_t item_size;       /* Size (in bytes) of each item to read. */
-size_t n_items;         /* Number of items to read. */
-vFILE *vFp;             /* Pointer to vFILE structure. */
+VISIBLE_PREFIX size_t V_read (
+void *buffer,           /* Pointer to buffer. */
+size_t item_size,       /* Size (in bytes) of each item to read. */
+size_t n_items,         /* Number of items to read. */
+vFILE *vFp)             /* Pointer to vFILE structure. */
 {
   size_t nBytesX;       /* Total number of bytes in buffer. */
   size_t nBytes;        /* Total number of bytes to read. */
@@ -1135,11 +1243,11 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
 * V_write.
 ******************************************************************************/
 
-VISIBLE_PREFIX size_t V_write (buffer, item_size, n_items, vFp)
-void *buffer;           /* Pointer to buffer. */
-size_t item_size;       /* Size (in bytes) of each item to write. */
-size_t n_items;         /* Number of items to write. */
-vFILE *vFp;             /* Pointer to vFILE structure. */
+VISIBLE_PREFIX size_t V_write (
+void *buffer,           /* Pointer to buffer. */
+size_t item_size,       /* Size (in bytes) of each item to write. */
+size_t n_items,         /* Number of items to write. */
+vFILE *vFp)             /* Pointer to vFILE structure. */
 {
   size_t nBytesX;       /* Total number of bytes in buffer. */
   size_t nBytes;        /* Total number of bytes in write. */
@@ -1152,6 +1260,7 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
   vCACHE *cache;        /* Pointer to cache structure. */
   Byte1 *cBuffer;       /* Pointer to cache buffer. */
   size_t nBytesInBlock;	/* Number of bytes to the end of the block. */
+  Logical new;
   /****************************************************************************
   * Validate write.
   ****************************************************************************/
@@ -1188,11 +1297,15 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
 	}
       }
       else {
-	cache = AllocateBuffer (vFp);
+	cache = AllocateBuffer (vFp, &new);
 	if (cache == NULL) {
 	  vFp->error = TRUE;
 	  return 0;
 	}
+	if (vFp->scratch && vFp->fp == NULL && new) {
+	  vFp->cacheNumInd[firstBlockN] = 1;
+	  vFp->cacheLocPtr[firstBlockN] = cache;
+	}
 	cache->blockN = firstBlockN;
 #if CLEAR_BYTES
 	cBuffer = CACHEbufferWRITEto (cache);
@@ -1256,11 +1369,15 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
 	   }
 	 }
 	 else {
-	   cache = AllocateBuffer (vFp);
+	   cache = AllocateBuffer (vFp, &new);
 	   if (cache == NULL) {
 	     vFp->error = TRUE;
 	     return 0;
 	   }
+	   if (vFp->scratch && vFp->fp == NULL && new) {
+	     vFp->cacheNumInd[blockN] = 1;
+	     vFp->cacheLocPtr[blockN] = cache;
+	   }
 	   cache->blockN = blockN;
 #if CLEAR_BYTES
 	   cBuffer = CACHEbufferWRITEto (cache);
@@ -1304,8 +1421,8 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
 * V_getc.
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_getc (fp)
-vFILE *fp;
+VISIBLE_PREFIX int V_getc (
+vFILE *fp)
 {
   uByte tmp;
   if (V_read(&tmp,1,1,fp) != 1) return EOF;
@@ -1316,9 +1433,9 @@ vFILE *fp;
 * V_putc.
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_putc (value, fp)
-int value;
-vFILE *fp;
+VISIBLE_PREFIX int V_putc (
+int value,
+vFILE *fp)
 {
   uByte tmp = (uByte) value;
   if (V_write(&tmp,1,1,fp) != 1) return EOF;
@@ -1331,8 +1448,8 @@ vFILE *fp;
 * prevent blocks of unwanted data from being paged out to disk.
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_clear (vFp)
-vFILE *vFp;             /* Pointer to vFILE structure. */
+VISIBLE_PREFIX int V_clear (
+vFILE *vFp)             /* Pointer to vFILE structure. */
 {
   vCACHE *cache;
   if (vFp == NULL) return EOF;
@@ -1349,8 +1466,8 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
 * Flush the file to disk.
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_flush (vFp)
-vFILE *vFp;             /* Pointer to vFILE structure. */
+VISIBLE_PREFIX int V_flush (
+vFILE *vFp)             /* Pointer to vFILE structure. */
 {
   /****************************************************************************
   * Validate.
@@ -1387,10 +1504,10 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
 * Returns EOF if an error occurred.
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_close (vFp, CDF, vStats)
-vFILE *vFp;             /* Pointer to vFILE structure. */
-struct CDFstruct *CDF;  /* Indicator whether to perform check sum operation. */
-vSTATS *vStats;         /* Pointer to statistics structure. */
+VISIBLE_PREFIX int V_close (
+vFILE *vFp,             /* Pointer to vFILE structure. */
+struct CDFstruct *CDF,  /* Indicator whether to perform check sum operation. */
+vSTATS *vStats)         /* Pointer to statistics structure. */
 {
   Logical error = FALSE;        /* Has an error occurred? */
   /****************************************************************************
@@ -1431,6 +1548,8 @@ vSTATS *vStats;         /* Pointer to statistics structure. */
   * Deallocate cache and vFILE structure.
   ****************************************************************************/
   FreeCache (vFp->cacheHead);
+  if (vFp->cacheNumInd != NULL) cdf_FreeMemory (vFp->cacheNumInd, NULL);
+  if (vFp->cacheLocPtr != NULL) cdf_FreeMemory (vFp->cacheLocPtr, NULL);
   cdf_FreeMemory (vFp->path, NULL);
   cdf_FreeMemory (vFp, NULL);
   /****************************************************************************
@@ -1444,9 +1563,9 @@ vSTATS *vStats;         /* Pointer to statistics structure. */
 * Returns EOF if an error occurred.
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_delete (vFp, vStats)
-vFILE *vFp;             /* Pointer to vFILE structure. */
-vSTATS *vStats;         /* Pointer to statistics structure. */
+VISIBLE_PREFIX int V_delete (
+vFILE *vFp,             /* Pointer to vFILE structure. */
+vSTATS *vStats)         /* Pointer to statistics structure. */
 {
   Logical error = FALSE;        /* Has an error occurred? */
   /****************************************************************************
@@ -1483,6 +1602,8 @@ vSTATS *vStats;         /* Pointer to statistics structure. */
   * Deallocate cache and vFILE structure.
   ****************************************************************************/
   FreeCache (vFp->cacheHead);
+if (vFp->cacheNumInd != NULL) cdf_FreeMemory (vFp->cacheNumInd, NULL);
+if (vFp->cacheLocPtr != NULL) cdf_FreeMemory (vFp->cacheLocPtr, NULL);
   cdf_FreeMemory (vFp->path, NULL);
   cdf_FreeMemory (vFp, NULL);
   /****************************************************************************
