@@ -127,12 +127,12 @@ static Logical ExtendFile PROTOARGs((vFILE *vFp, long toBlockN));
 * CDFOpenFile.
 ******************************************************************************/
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
-static int CDFOpenFile (file_spec, a_mode)
+static int CDFOpenFile (
 #else
-static FILE *CDFOpenFile (file_spec, a_mode)
+static FILE *CDFOpenFile (
 #endif
-char *file_spec;
-char *a_mode;                   
+char *file_spec,
+char *a_mode)                   
 {                               
 #if defined(vms)                
   char mrs[10+1];       /* Maximum record size. */
@@ -142,7 +142,7 @@ char *a_mode;
 	    VMS_DEFAULT_nALLOCATION_BLOCKS);
   return fopen(file_spec,a_mode,"rfm=fix",mrs,deq);
 #else
-#if defined(win32) && (_FILE_OFFSET_BITS == 64)
+# if defined(win32) && (_FILE_OFFSET_BITS == 64)
   int oflag;
   if (!strcmp(a_mode, READ_ONLY_a_mode))
       oflag = READ_ONLY_a_mode_windows_LFS;
@@ -151,9 +151,9 @@ char *a_mode;
   else if (!strcmp(a_mode, WRITE_PLUS_a_mode))
       oflag = WRITE_PLUS_a_mode_windows_LFS;
   return FOPEN64 (file_spec,oflag,PMODE);
-#else
+# else
   return FOPEN64 (file_spec,a_mode);
-#endif
+# endif
 #endif
 }   
 
@@ -162,9 +162,9 @@ char *a_mode;
 *          
 ******************************************************************************/
 
-static vCACHE *FindCache (vFp, blockN)
-vFILE *vFp;
-long blockN;
+static vCACHE *FindCache (
+vFILE *vFp,
+long blockN)
 {
   if (vFp->scratch && vFp->fp == NULL && vFp->cacheNumInd != NULL) {
     if (vFp->cacheNumInd[(int)blockN] == 1) {
@@ -199,10 +199,11 @@ long blockN;
 
 /******************************************************************************
 * CountCaches.
+* Count the number caches in the linked list. 
 ******************************************************************************/
 
-static int CountCaches (vFp)
-vFILE *vFp;
+static int CountCaches (
+vFILE *vFp)
 {
   int ix = 0;
   vCACHE *cache = vFp->cacheHead;
@@ -219,20 +220,19 @@ vFILE *vFp;
 * buffer.
 ******************************************************************************/
 
-VISIBLE_PREFIX Logical FlushCache64 (vFp, firstCache)
-vFILE *vFp;             /* Pointer to vFILE structure. */
-vCACHE *firstCache;     /* Pointer to the first cache structure to flush. */
+VISIBLE_PREFIX Logical FlushCache64 (
+vFILE *vFp,             /* Pointer to vFILE structure. */
+vCACHE *firstCache)     /* Pointer to the first cache structure to flush. */
 {
-  vCACHE *cache; long nBytes; OFF_T tmpBytes;
-  OFF_T tmp; 
-int ix;
-ix = 0;
+  vCACHE *cache; long nBytes; size_t tmpBytes;
+  size_t tmp; 
+
   for (cache = firstCache; cache != NULL; cache = cache->next) {
      if (cache->modified) {
 #if defined(vms)
        nBytes = nCACHE_BUFFER_BYTEs;
 #else
-       tmp = ((OFF_T) cache->blockN) * nCACHE_BUFFER_BYTEs;
+       tmp = ((size_t) cache->blockN) * nCACHE_BUFFER_BYTEs;
        tmpBytes = vFp->length64 - tmp;
        if (tmpBytes > nCACHE_BUFFER_BYTEs) 
 	 nBytes = nCACHE_BUFFER_BYTEs;
@@ -250,8 +250,8 @@ ix = 0;
 * FreeCache.
 ******************************************************************************/
 
-static Logical FreeCache (firstCache)
-vCACHE *firstCache;     /* Pointer to the first cache structure to free. */
+static Logical FreeCache (
+vCACHE *firstCache)     /* Pointer to the first cache structure to free. */
 {
   vCACHE *cache = firstCache;
   while (cache != NULL) {
@@ -276,13 +276,13 @@ if (cache->ptr != NULL)
 * an error occurred). New cache is placed at the head of the link-list.
 ******************************************************************************/
 
-static vCACHE *AllocateBuffer (vFp, new)
-vFILE *vFp;
-Logical *new;
+static vCACHE *AllocateBuffer (
+vFILE *vFp,
+Logical *new)
 {
-  vCACHE *cache; long nBytes; OFF_T tmpBytes;
+  vCACHE *cache; long nBytes; size_t tmpBytes;
 #if !defined(vms)
-  OFF_T offset;
+  size_t offset;
 #endif
   /****************************************************************************
   * Check if a new cache structure can be allocated.  If the allocation(s)
@@ -357,7 +357,7 @@ Logical *new;
 #if defined(vms)
 	  nBytes = nCACHE_BUFFER_BYTEs;
 #else
-  offset = ((OFF_T) cache->blockN) * nCACHE_BUFFER_BYTEs;
+  offset = ((size_t) cache->blockN) * nCACHE_BUFFER_BYTEs;
   tmpBytes = vFp->length64 - offset;
   if (tmpBytes > nCACHE_BUFFER_BYTEs)
     nBytes = nCACHE_BUFFER_BYTEs;
@@ -384,9 +384,9 @@ Logical *new;
 ******************************************************************************/
 
 #if EXTEND_FILE
-static Logical ExtendFile (vFp, toBlockN)
-vFILE *vFp;
-long toBlockN;
+static Logical ExtendFile (
+vFILE *vFp,
+long toBlockN)
 {
   vCACHE *cache; long blockN;
   /****************************************************************************
@@ -395,28 +395,28 @@ long toBlockN;
   ****************************************************************************/
   if (vFp->phyLength64 > 0) {
     long lastPhyBlockN = LASTphyBLOCKn (vFp);
-    long nBytes = (long) (vFp->phyLength64 - (OFF_T) lastPhyBlockN *
+    long nBytes = (long) (vFp->phyLength64 - (size_t) lastPhyBlockN *
 					      nCACHE_BUFFER_BYTEs);
     if (nBytes < nCACHE_BUFFER_BYTEs) {
       cache = FindCache (vFp, lastPhyBlockN);
       if (cache != NULL) {
 	void *buffer = CACHEbufferREADfrom (cache);
 	if (buffer == NULL) return FALSE;
-	if (!vWrite((OFF_T) lastPhyBlockN * nCACHE_BUFFER_BYTEs,
+	if (!vWrite((size_t) lastPhyBlockN * nCACHE_BUFFER_BYTEs,
 		    buffer,nCACHE_BUFFER_BYTEs,vFp)) return FALSE;
 	cache->modified = FALSE;
       }
       else {
 	Byte1 buffer[nCACHE_BUFFER_BYTEs];
-	if (!vRead(((OFF_T)lastPhyBlockN) * nCACHE_BUFFER_BYTEs,
+	if (!vRead(((size_t)lastPhyBlockN) * nCACHE_BUFFER_BYTEs,
 		   buffer,(size_t)nBytes,vFp)) return FALSE;
 #if CLEAR_BYTES
 	ClearBytes (buffer, (int) nBytes, nCACHE_BUFFER_BYTEs - 1);
 #endif
-	if (!vWrite((OFF_T) lastPhyBlockN * nCACHE_BUFFER_BYTEs,
+	if (!vWrite((size_t) lastPhyBlockN * nCACHE_BUFFER_BYTEs,
 		    buffer,nCACHE_BUFFER_BYTEs,vFp)) return FALSE;
       }
-      vFp->phyLength64 = ((OFF_T) nCACHE_BUFFER_BYTEs) * (lastPhyBlockN + 1);
+      vFp->phyLength64 = ((size_t) nCACHE_BUFFER_BYTEs) * (lastPhyBlockN + 1);
     }
   }
   /****************************************************************************
@@ -427,7 +427,7 @@ long toBlockN;
      if (cache != NULL) {
        void *buffer = CACHEbufferREADfrom (cache);
        if (buffer == NULL) return FALSE;
-       if (!vWrite((OFF_T) blockN * nCACHE_BUFFER_BYTEs,
+       if (!vWrite((size_t) blockN * nCACHE_BUFFER_BYTEs,
 		   buffer,nCACHE_BUFFER_BYTEs,vFp)) return FALSE;
        cache->modified = FALSE;
      }
@@ -436,10 +436,10 @@ long toBlockN;
 #if CLEAR_BYTES
        ClearBytes (buffer, 0, nCACHE_BUFFER_BYTEs - 1);
 #endif
-       if (!vWrite((OFF_T) blockN * nCACHE_BUFFER_BYTEs,
+       if (!vWrite((size_t) blockN * nCACHE_BUFFER_BYTEs,
 		   buffer,nCACHE_BUFFER_BYTEs,vFp)) return FALSE;
      }
-     vFp->phyLength64 = ((OFF_T) blockN + 1) * nCACHE_BUFFER_BYTEs;
+     vFp->phyLength64 = ((size_t) blockN + 1) * nCACHE_BUFFER_BYTEs;
   }
   return TRUE;
 }
@@ -451,12 +451,12 @@ long toBlockN;
 * NULL if an error occurred).
 ******************************************************************************/
 
-static vCACHE *PageIn (vFp, blockN)
-vFILE *vFp;
-long blockN;
+static vCACHE *PageIn (
+vFILE *vFp,
+long blockN)
 {
   long nBytes; vCACHE *cache; void *buffer;
-  OFF_T offset, tmpBytes;
+  size_t offset, tmpBytes;
   Logical new;
   cache = AllocateBuffer (vFp, &new);
   if (cache == NULL) return NULL;
@@ -464,7 +464,7 @@ long blockN;
     vFp->cacheNumInd[blockN] = 1;
     vFp->cacheLocPtr[blockN] = cache;
   }
-  offset = ((OFF_T) blockN) * nCACHE_BUFFER_BYTEs;
+  offset = ((size_t) blockN) * nCACHE_BUFFER_BYTEs;
   tmpBytes = vFp->phyLength64 - offset;
   if (tmpBytes > nCACHE_BUFFER_BYTEs)
     nBytes = nCACHE_BUFFER_BYTEs;
@@ -488,13 +488,13 @@ long blockN;
 * successful, FALSE if an error occurred.
 ******************************************************************************/
 
-static Logical WriteBlockFromCache (vFp, cache, nBytes)
-vFILE *vFp;
-vCACHE *cache;
-size_t nBytes;
+static Logical WriteBlockFromCache (
+vFILE *vFp,
+vCACHE *cache,
+size_t nBytes)
 {
-  OFF_T offset; void *buffer;
-  offset = ((OFF_T) cache->blockN) * nCACHE_BUFFER_BYTEs;
+  size_t offset; void *buffer;
+  offset = ((size_t) cache->blockN) * nCACHE_BUFFER_BYTEs;
 #if EXTEND_FILE
   if (offset > vFp->phyLength64) {
     if (!ExtendFile(vFp,cache->blockN-1)) return FALSE;
@@ -503,7 +503,7 @@ size_t nBytes;
   buffer = CACHEbufferREADfrom (cache);
   if (buffer == NULL) return FALSE;
   if (!vWrite(offset,buffer,nBytes,vFp)) return FALSE;
-  vFp->phyLength64 = MaxLongLong (vFp->phyLength64, offset + (OFF_T) nBytes);
+  vFp->phyLength64 = MaxLongLong (vFp->phyLength64, offset + (size_t) nBytes);
   return TRUE;
 }
 
@@ -513,20 +513,20 @@ size_t nBytes;
 * successful, FALSE if an error occurred.
 ******************************************************************************/
 
-static Logical WriteBlockFromBuffer (vFp, blockN, buffer, nBytes)
-vFILE *vFp;
-long blockN;
-void *buffer;
-size_t nBytes;
+static Logical WriteBlockFromBuffer (
+vFILE *vFp,
+long blockN,
+void *buffer,
+size_t nBytes)
 {
-  OFF_T offset = ((OFF_T) blockN) * nCACHE_BUFFER_BYTEs;
+  size_t offset = ((size_t) blockN) * nCACHE_BUFFER_BYTEs;
 #if EXTEND_FILE
   if (offset > vFp->phyLength64) {
     if (!ExtendFile(vFp,blockN-1)) return FALSE;
   }
 #endif
   if (!vWrite(offset,buffer,nBytes,vFp)) return FALSE;
-  vFp->phyLength64 = MaxLongLong (vFp->phyLength64, offset + (OFF_T) nBytes);
+  vFp->phyLength64 = MaxLongLong (vFp->phyLength64, offset + (size_t) nBytes);
   return TRUE;
 }
 
@@ -534,11 +534,11 @@ size_t nBytes;
 * vRead.
 ******************************************************************************/
 
-static Logical vRead (offset, buffer, nBytes, vFp)
-OFF_T offset;
-void *buffer;
-size_t nBytes;
-vFILE *vFp;
+static Logical vRead (
+OFF_T offset,
+void *buffer,
+size_t nBytes,
+vFILE *vFp)
 {
   int tryN;
   /****************************************************************************
@@ -558,11 +558,11 @@ vFILE *vFp;
   ****************************************************************************/
   for (tryN = 1; tryN <= vMAX_TRYs; tryN++) {
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
-     if (FSEEK64(vFp->fh,(OFF_T) offset,vSEEK_SET) == EOF) return FALSE;
+     if (FSEEK64(vFp->fh,(size_t) offset,vSEEK_SET) == EOF) return FALSE;
      if (FREAD64(vFp->fh,buffer,(unsigned int) nBytes) == (int) nBytes)
         return TRUE;
 #else
-     if (FSEEK64(vFp->fp,(OFF_T) offset,vSEEK_SET) == EOF) return FALSE;
+     if (FSEEK64(vFp->fp,(size_t) offset,vSEEK_SET) == EOF) return FALSE;
      if (FREAD64(buffer,nBytes,1,vFp->fp) == 1) {
        return TRUE;
      }
@@ -575,11 +575,11 @@ vFILE *vFp;
 * vWrite.
 ******************************************************************************/
 
-static Logical vWrite (offset,buffer,nBytes,vFp)
-OFF_T offset;
-void *buffer;
-size_t nBytes;
-vFILE *vFp;
+static Logical vWrite (
+OFF_T offset,
+void *buffer,
+size_t nBytes,
+vFILE *vFp)
 {
   int tryN;
 #if defined(__MWERKS__)
@@ -623,7 +623,8 @@ vFILE *vFp;
       strcpyX (tmpPath, vFp->path, 0);
       AppendToDir (tmpPath, "");
 #     if defined(unix) || defined(vms) || defined(__CYGWIN__)
-        strcatX (tmpPath, TmpFileTemplate, 0);
+        strcatX (tmpPath, TmpFileTemplate, strlen(TmpFileTemplate),
+		 strlen(tmpPath), 0);
         fileid = mkstemp(tmpPath);
         if (fileid != -1) {
           fp = fdopen(fileid, "w+");
@@ -643,7 +644,8 @@ vFILE *vFp;
 #     else
 #       if defined(win32)
           fh = -1;
-          strcatX (tmpPath, TmpFileTemplate, 0);
+          strcatX (tmpPath, TmpFileTemplate, strlen(TmpFileTemplate),
+		   strlen(tmpPath), 0);
           err = _mktemp_s(tmpPath, (int)strlen(tmpPath)+1);
           if (err == 0) {
             fh = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
@@ -698,7 +700,8 @@ vFILE *vFp;
             strcpyX (tmpPath, "SYS$SCRATCH:", (size_t)pathLength);
             strcpyX (tmpFolder, tmpPath, (size_t)pathLength);
 #         endif
-          strcatX (tmpPath, TmpFileTemplate, 0);
+          strcatX (tmpPath, TmpFileTemplate, strlen(TmpFileTemplate),
+		   strlen(tmpPath), 0);
         }
         fileid = mkstemp(tmpPath);
         if (fileid != -1) {
@@ -719,7 +722,8 @@ vFILE *vFp;
 #     else
 #       if defined(win32)
           fh = -1;
-          strcatX (tmpPath, TmpFileTemplate, 0);
+          strcatX (tmpPath, TmpFileTemplate, strlen(TmpFileTemplate),
+		   strlen(tmpPath), 0);
           err = _mktemp_s(tmpPath, (int)strlen(tmpPath)+1 );
           if (err == 0) {
             fh = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
@@ -785,11 +789,11 @@ vFILE *vFp;
   ****************************************************************************/
   for (tryN = 1; tryN <= vMAX_TRYs; tryN++) {
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
-     if (FSEEK64(vFp->fh,(OFF_T) offset,vSEEK_SET) == EOF) return FALSE;
+     if (FSEEK64(vFp->fh,(size_t) offset,vSEEK_SET) == EOF) return FALSE;
      if (FWRITE64(vFp->fh,buffer,(unsigned int)nBytes) == (int)nBytes)
         return TRUE;
 #else
-     if (FSEEK64(vFp->fp,(OFF_T) offset,vSEEK_SET) == EOF) return FALSE;
+     if (FSEEK64(vFp->fp,(size_t) offset,vSEEK_SET) == EOF) return FALSE;
      if (FWRITE64(buffer,nBytes,1,vFp->fp) == 1) return TRUE;
 #endif
   }
@@ -801,10 +805,10 @@ vFILE *vFp;
 * Seek to a position in the file.
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_seek64 (vFp, offset, direction)
-vFILE *vFp;             /* Pointer to vFILE structure. */
-OFF_T offset;           /* New current file offset. */
-int direction;          /* Reference for offset. */
+VISIBLE_PREFIX int V_seek64 (
+vFILE *vFp,             /* Pointer to vFILE structure. */
+OFF_T offset,           /* New current file offset. */
+int direction)          /* Reference for offset. */
 {
   if (vFp == NULL) return EOF;
   if (vFp->magic_number != VSTREAM_MAGIC_NUMBER) return EOF;
@@ -812,12 +816,12 @@ int direction;          /* Reference for offset. */
   vFp->eof = FALSE;		/* Cleared before proceeding. */
   switch (direction) {
     case vSEEK_SET:
-      if (offset < (OFF_T) 0) return EOF;
+      if (offset < (size_t) 0) return EOF;
       vFp->offset64 = offset;
       break;
     case vSEEK_CUR:
-      if (vFp->offset64 + offset < (OFF_T) 0) return EOF;
-      vFp->offset64 += (OFF_T) offset;
+      if (vFp->offset64 + offset < (size_t) 0) return EOF;
+      vFp->offset64 += (size_t) offset;
       break;
     case vSEEK_END:
       vFp->offset64 = vFp->length64;
@@ -834,8 +838,8 @@ int direction;          /* Reference for offset. */
 * the last byte that exists.
 ******************************************************************************/
 
-VISIBLE_PREFIX OFF_T V_tell64 (vFp)
-vFILE *vFp;             /* Pointer to vFILE structure. */
+VISIBLE_PREFIX OFF_T V_tell64 (
+vFILE *vFp)             /* Pointer to vFILE structure. */
 {
   if (vFp == NULL) return EOF;
   if (vFp->magic_number != VSTREAM_MAGIC_NUMBER) return EOF;
@@ -847,15 +851,15 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
 * V_read64. Read data from cache(s), starting from offset64, into buffer
 ******************************************************************************/
 
-VISIBLE_PREFIX size_t V_read64 (buffer, item_size, n_items, vFp)
-void *buffer;           /* Pointer to buffer. */
-size_t item_size;       /* Size (in bytes) of each item to read. */
-size_t n_items;         /* Number of items to read. */
-vFILE *vFp;             /* Pointer to vFILE structure. */
+VISIBLE_PREFIX size_t V_read64 (
+void *buffer,           /* Pointer to buffer. */
+size_t item_size,       /* Size (in bytes) of each item to read. */
+size_t n_items,         /* Number of items to read. */
+vFILE *vFp)             /* Pointer to vFILE structure. */
 {
   size_t nBytesX;       /* Total number of bytes in buffer. */
   size_t nBytes;	/* Total number of bytes to read. */
-  OFF_T  remainingItems;/* Number of items remaining after the offset. */
+  size_t  remainingItems;/* Number of items remaining after the offset. */
   size_t nItems;	/* Number of items to actually be read. */
   long firstBlockN;    	/* First block involved in read. */
   long lastBlockN;     	/* Last block involved in read. */
@@ -877,8 +881,8 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
   if (vFp->magic_number != VSTREAM_MAGIC_NUMBER) return 0;
   if (vFp->error) return 0;
   if ((int) item_size <= 0 || (int) n_items <= 0) return 0;
-  remainingItems = (OFF_T) ((vFp->length64 - vFp->offset64) / 
-			    (OFF_T) item_size);
+  remainingItems = (size_t) ((vFp->length64 - vFp->offset64) / 
+			    (size_t) item_size);
   if (remainingItems < 1) {
     vFp->eof = TRUE;
     vFp->offset64 = vFp->length64;
@@ -905,7 +909,7 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
   *               3. move the cache to head
   *            locate the buffer point for moving the data to 
   ****************************************************************************/
-  firstBlockN = (long) (vFp->offset64 / (OFF_T) nCACHE_BUFFER_BYTEs);
+  firstBlockN = (long) (vFp->offset64 / (size_t) nCACHE_BUFFER_BYTEs);
   bufferOffset = (int) ((OFF_T) vFp->offset64 % nCACHE_BUFFER_BYTEs);
   remainingBytes = nCACHE_BUFFER_BYTEs - bufferOffset;
   xBytes = MINIMUM (nBytes, (size_t) remainingBytes);
@@ -931,11 +935,11 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
   /****************************************************************************
   * Read from remaining blocks...
   ****************************************************************************/
-  lastBlockN = (long) ((vFp->offset64 + (OFF_T) nBytes - 1) / 
-			(OFF_T) nCACHE_BUFFER_BYTEs); 
+  lastBlockN = (long) ((vFp->offset64 + (size_t) nBytes - 1) / 
+			(size_t) nCACHE_BUFFER_BYTEs); 
   for (blockN = atBlockN; blockN <= lastBlockN; blockN++) {
-     xBytes = (size_t) (((OFF_T)vFp->offset64) + (OFF_T) nBytes - 
-		        ((OFF_T) blockN) * nCACHE_BUFFER_BYTEs);
+     xBytes = (size_t) (((OFF_T)vFp->offset64) + (size_t) nBytes - 
+		        ((size_t) blockN) * nCACHE_BUFFER_BYTEs);
      xBytes = MINIMUM (xBytes, nCACHE_BUFFER_BYTEs);
      if (xBytes > nBytesX) return 0;
      cache = FindCache (vFp, blockN);
@@ -962,7 +966,7 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
 	 memmove (buffer, cBuffer, (size_t) xBytes);
        }
        else {
-	 fileOffset = ((OFF_T) blockN) * nCACHE_BUFFER_BYTEs;
+	 fileOffset = ((size_t) blockN) * nCACHE_BUFFER_BYTEs;
 	 if (!vRead(fileOffset,buffer,nCACHE_BUFFER_BYTEs,vFp)) {
 	   vFp->error = TRUE;
 	   return 0;
@@ -975,7 +979,7 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
   /****************************************************************************
   * Increment current file offset or set to EOF if the EOF indicator was set.
   ****************************************************************************/
-  vFp->offset64 = BOO(vFp->eof,vFp->length64,vFp->offset64 + (OFF_T)nBytes);
+  vFp->offset64 = BOO(vFp->eof,vFp->length64,vFp->offset64 + (size_t)nBytes);
   return nItems;
 }
 
@@ -983,11 +987,11 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
 * V_write64. -- write data to cache, which will be marked as modified
 ******************************************************************************/
 
-VISIBLE_PREFIX size_t V_write64 (buffer, item_size, n_items, vFp)
-void *buffer;           /* Pointer to buffer. */
-size_t item_size;       /* Size (in bytes) of each item to write. */
-size_t n_items;         /* Number of items to write. */
-vFILE *vFp;             /* Pointer to vFILE structure. */
+VISIBLE_PREFIX size_t V_write64 (
+void *buffer,           /* Pointer to buffer. */
+size_t item_size,       /* Size (in bytes) of each item to write. */
+size_t n_items,         /* Number of items to write. */
+vFILE *vFp)             /* Pointer to vFILE structure. */
 {
   size_t nBytesX;       /* Total number of bytes in buffer. */
   size_t nBytes;        /* Total number of bytes in write. */
@@ -1030,8 +1034,8 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
   *    locate the buffer point in cache for moving the data from buffer to
   *
   ****************************************************************************/
-  firstBlockN = (long) (vFp->offset64 / (OFF_T) nCACHE_BUFFER_BYTEs); 
-  bufferOffset = (int) ((OFF_T) vFp->offset64 % nCACHE_BUFFER_BYTEs);
+  firstBlockN = (long) (vFp->offset64 / (size_t) nCACHE_BUFFER_BYTEs); 
+  bufferOffset = (int) ((size_t) vFp->offset64 % nCACHE_BUFFER_BYTEs);
   nBytesInBlock = nCACHE_BUFFER_BYTEs - bufferOffset;
   xBytes = MINIMUM (nBytes, nBytesInBlock);
   if (xBytes > nBytesX) return 0;
@@ -1076,7 +1080,7 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
     memmove (cBuffer + bufferOffset, buffer, (size_t) xBytes);
     cache->modified = TRUE;
     vFp->length64 = MaxLongLong (vFp->length64, vFp->offset64 + 
-				  (OFF_T) xBytes);
+				  (size_t) xBytes);
     buffer = (Byte1 *) buffer + xBytes;
     atBlockN = firstBlockN + 1;
   }
@@ -1085,11 +1089,11 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
   /****************************************************************************
   * Write to remaining blocks...
   ****************************************************************************/
-  lastBlockN = (long) ((vFp->offset64 + (OFF_T) nBytes - 1) / 
-			(OFF_T) nCACHE_BUFFER_BYTEs); 
+  lastBlockN = (long) ((vFp->offset64 + (size_t) nBytes - 1) / 
+			(size_t) nCACHE_BUFFER_BYTEs); 
   for (blockN = atBlockN; blockN <= lastBlockN; blockN++) {
-     xBytes = (size_t) (((OFF_T)vFp->offset64) + (OFF_T) nBytes - 
-		        ((OFF_T) blockN) * nCACHE_BUFFER_BYTEs);
+     xBytes = (size_t) (((size_t)vFp->offset64) + (size_t) nBytes - 
+		        ((size_t) blockN) * nCACHE_BUFFER_BYTEs);
      xBytes = MINIMUM (xBytes, nCACHE_BUFFER_BYTEs);
      if (xBytes > nBytesX) return 0;
      /*************************************************************************
@@ -1158,14 +1162,14 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
 	 }
        }
      }
-     vFp->length64 = MaxLongLong (vFp->length64, ((OFF_T) blockN) *
-			          nCACHE_BUFFER_BYTEs + (OFF_T) xBytes);
+     vFp->length64 = MaxLongLong (vFp->length64, ((size_t) blockN) *
+			          nCACHE_BUFFER_BYTEs + (size_t) xBytes);
      buffer = (Byte1 *) buffer + xBytes;
   }
   /****************************************************************************
   * Increment current file offset.
   ****************************************************************************/
-  vFp->offset64 += (OFF_T) nBytes;
+  vFp->offset64 += (size_t) nBytes;
   return n_items;
 }
 
@@ -1174,9 +1178,9 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
 * Open the file and setup vFILE structure.
 ******************************************************************************/
 
-VISIBLE_PREFIX vFILE *V_open64 (file_spec, a_mode)
-char *file_spec;        /* File specification. */
-char *a_mode;           /* Access mode. */
+VISIBLE_PREFIX vFILE *V_open64 (
+char *file_spec,        /* File specification. */
+char *a_mode)           /* Access mode. */
 {
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
   int fp;
@@ -1187,7 +1191,6 @@ char *a_mode;           /* Access mode. */
 #if defined(vms)
   struct STAT st;       /* Status block from `stat'. */
 #endif
-int jj;
   /****************************************************************************
   * Open the file.
   ****************************************************************************/
@@ -1207,7 +1210,7 @@ int jj;
   * created.
   ****************************************************************************/
   if (strstr(a_mode,"r+") || strchr(a_mode,'a')) {
-    OFF_T eof, EOFoffsetInBlock;
+    size_t eof, EOFoffsetInBlock;
     if (FSEEK64(fp,0,vSEEK_END) == EOF) {
       FCLOSE64 (fp);
       return NULL;
@@ -1219,8 +1222,8 @@ int jj;
     }
     EOFoffsetInBlock = eof % nCACHE_BUFFER_BYTEs;
     if (EOFoffsetInBlock != 0) {
-      OFF_T offsetToLastBlock; char buffer[nCACHE_BUFFER_BYTEs]; int i;
-      offsetToLastBlock = (OFF_T) nCACHE_BUFFER_BYTEs * 
+      size_t offsetToLastBlock; char buffer[nCACHE_BUFFER_BYTEs]; int i;
+      offsetToLastBlock = (size_t) nCACHE_BUFFER_BYTEs * 
                           (eof / nCACHE_BUFFER_BYTEs);
       if (FSEEK64(fp,offsetToLastBlock,vSEEK_SET) == EOF) {
 	FCLOSE64 (fp);
@@ -1366,9 +1369,9 @@ int jj;
 * the old cache size (do nothing).
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_setcache64 (vFp, maxBuffers)
-vFILE *vFp;             /* Pointer to vFILE structure. */
-int maxBuffers;         /* New maximum number of cache buffers. */
+VISIBLE_PREFIX int V_setcache64 (
+vFILE *vFp,             /* Pointer to vFILE structure. */
+int maxBuffers)         /* New maximum number of cache buffers. */
 {
   if (vFp == NULL) return EOF;
   if (vFp->magic_number != VSTREAM_MAGIC_NUMBER) return EOF;
@@ -1410,8 +1413,8 @@ int maxBuffers;         /* New maximum number of cache buffers. */
 * Free the caches from head to tail.
 ******************************************************************************/
 
-VISIBLE_PREFIX void V_freecaches64 (vFp)
-vFILE *vFp;
+VISIBLE_PREFIX void V_freecaches64 (
+vFILE *vFp)
 {
    FreeCache(vFp->cacheHead);
 }
@@ -1421,8 +1424,8 @@ vFILE *vFp;
 * Flush the file to disk.
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_flush64 (vFp)
-vFILE *vFp;             /* Pointer to vFILE structure. */
+VISIBLE_PREFIX int V_flush64 (
+vFILE *vFp)             /* Pointer to vFILE structure. */
 {
   /****************************************************************************
   * Validate.
@@ -1434,7 +1437,7 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
   * Flush cache buffers.  If this is a scratch file, this will cause the file
   * to be created if it hasn't been already (unless nothing has been written).
   ****************************************************************************/
-  if (vFp->fp != NULL) { /* xxxxxxxxxxxxxxxxxxxxxxxxxx */
+  if (vFp->fp != NULL) {
     if (!FlushCache64(vFp,vFp->cacheHead)) {
       vFp->error = TRUE;
       return EOF;
@@ -1458,7 +1461,7 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
       }
     }
 #endif
-  } /* xxxxxxxxxxxxxxxxxxxxxxxxxx */
+  }
   /****************************************************************************
   * Return success.
   ****************************************************************************/
@@ -1470,10 +1473,10 @@ vFILE *vFp;             /* Pointer to vFILE structure. */
 * Returns EOF if an error occurred.
 ******************************************************************************/
   
-VISIBLE_PREFIX int V_close64 (vFp, CDF, vStats)
-vFILE *vFp;             /* Pointer to vFILE structure. */
-struct CDFstruct *CDF;  /* Check sum operation indicator if non-NULL. */
-vSTATS *vStats;         /* Pointer to statistics structure. */
+VISIBLE_PREFIX int V_close64 (
+vFILE *vFp,             /* Pointer to vFILE structure. */
+struct CDFstruct *CDF,  /* Check sum operation indicator if non-NULL. */
+vSTATS *vStats)         /* Pointer to statistics structure. */
 { 
   Logical error = FALSE;        /* Has an error occurred? */
   /****************************************************************************
@@ -1538,8 +1541,8 @@ vSTATS *vStats;         /* Pointer to statistics structure. */
 * V_getc64.
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_getc64 (fp)
-vFILE *fp;
+VISIBLE_PREFIX int V_getc64 (
+vFILE *fp)
 { 
   uByte tmp;
   if (V_read64(&tmp,1,1,fp) != 1) return EOF;
@@ -1550,9 +1553,9 @@ vFILE *fp;
 * V_putc64.
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_putc64 (value, fp)
-int value;
-vFILE *fp;
+VISIBLE_PREFIX int V_putc64 (
+int value,
+vFILE *fp)
 { 
   uByte tmp = (uByte) value;
   if (V_write64(&tmp,1,1,fp) != 1) return EOF;
@@ -1564,9 +1567,9 @@ vFILE *fp;
 * Returns EOF if an error occurred.
 ******************************************************************************/
 
-VISIBLE_PREFIX int V_delete64 (vFp, vStats)
-vFILE *vFp;             /* Pointer to vFILE structure. */
-vSTATS *vStats;         /* Pointer to statistics structure. */
+VISIBLE_PREFIX int V_delete64 (
+vFILE *vFp,             /* Pointer to vFILE structure. */
+vSTATS *vStats)         /* Pointer to statistics structure. */
 {
   Logical error = FALSE;        /* Has an error occurred? */
   /****************************************************************************
@@ -1631,7 +1634,7 @@ vSTATS *vStats;         /* Pointer to statistics structure. */
 * Returns the PID of the session. If -1 then it is not set.
 ******************************************************************************/
 
-VISIBLE_PREFIX int GetMyPID ()
+VISIBLE_PREFIX int GetMyPID (void)
 {
   return pid;
 }
@@ -1641,7 +1644,8 @@ VISIBLE_PREFIX int GetMyPID ()
 * Sets the PID of the session.
 ******************************************************************************/
 
-VISIBLE_PREFIX void SetMyPID (int npid)
+VISIBLE_PREFIX void SetMyPID (
+int npid)
 {
   pid = npid;
 }
