@@ -85,9 +85,9 @@ MAIN {
 * CreateSkeletonTable.
 ******************************************************************************/
 
-Logical CreateSkeletonTable (argC, argV)
-int argC;
-char *argV[];
+Logical CreateSkeletonTable (
+int argC,
+char *argV[])
 {
   CDFstatus status;
   char CDFpath[DU_MAX_PATH_LEN+1], CDFpathX[DU_MAX_PATH_LEN+1];
@@ -299,10 +299,6 @@ char *argV[];
       qopError = qopError | !TFqualifier(qop,&negToPosFp0,NEG2POSqual,
 				         NONEG2POSqual,DEFAULT_NEGtoPOSfp0,
 				         "neg2posfp0");
-/*
-      qopError = qopError | !TFqualifier(qop,&useFormat,FORMATqual,NOFORMATqual,
-				         DEFAULTformatCDF2SKT,"format");
-*/
       /************************************************************************
       * Check for conflicting/missing qualifiers.
       ************************************************************************/
@@ -376,7 +372,7 @@ char *argV[];
     SKTfp = stdout;
   else {
     if (!EndsWithIgCase(SKTpath, ".skt"))
-      strcatX (SKTpath, ".skt", DU_MAX_PATH_LEN);
+      strcatX (SKTpath, ".skt", 4, strlen(SKTpath), DU_MAX_PATH_LEN);
     ExpandPath (SKTpath, SKTpathX);
 
     /**************************************************************************
@@ -491,10 +487,10 @@ char *argV[];
 * WriteHeader.
 ******************************************************************************/
 
-Logical WriteHeader (CDFname, varValues, variables)
-char *CDFname;
-int varValues;
-char *variables;
+Logical WriteHeader (
+char *CDFname,
+int varValues,
+char *variables)
 {
   CDFstatus status;
   long encoding, majority, format;
@@ -596,8 +592,8 @@ char *variables;
   snprintf (text, (size_t) sizeof(text), "%ld/%ld", numVars, numZvars);
   Ncharacters (SKTfp, MaxInt((int)(6 - strlen(text)),0), (int) ' ');
   snprintf (tempS, (size_t) sizeof(tempS),
-	    "%s     %7ld       %7ld     %5ld/z    %3ld",
-	    text, numGattrs, numVattrs, maxRec + 1, numDims);
+	    "%.*s     %*ld       %*ld     %*ld/z    %*ld", (int)strlen(text),
+	    text, 7, numGattrs, 7, numVattrs, 5, maxRec + 1, 3, numDims);
   WriteOut (SKTfp, tempS);
 
   if (numDims > 0) {
@@ -645,7 +641,7 @@ char *variables;
 * WriteGlobalAttr.
 ******************************************************************************/
 
-Logical WriteGlobalAttr ()
+Logical WriteGlobalAttr (void)
 {
   CDFstatus status;
   char delim;			     /* Delimeter for attribute name. */
@@ -655,6 +651,7 @@ Logical WriteGlobalAttr ()
   void *value;
   char attrName[CDF_ATTR_NAME_LEN256+1],
        tempS[MAX_LINE_LEN+1];
+  char tempS2[4+CDF_ATTR_NAME_LEN256+1];
   int GattrCount = 0;		     /* Number of global scope attributes. */
   int entryCount;
 
@@ -710,9 +707,10 @@ Logical WriteGlobalAttr ()
 
          delim = PickDelimiter (attrName, strlen(attrName));
          WriteOut (SKTfp, "\n\n");
-         snprintf (tempS, (size_t) sizeof(tempS),
-	           "  %c%s%c", delim, attrName, delim);
-         ccc = WriteOut (SKTfp, tempS);
+	 snprintf (tempS2, (size_t) sizeof(tempS2),
+	           "  %c%.*s%c", delim, (int)strlen(attrName), attrName,
+		   delim);
+	 ccc = WriteOut (SKTfp, tempS2);
          /*********************************************************************
          * Write each entry.
          *********************************************************************/
@@ -779,8 +777,7 @@ Logical WriteGlobalAttr ()
          if (!ISTPname(attrName)) {
            WriteOut (SKTfp, "\n");
            WriteOutFP (SKTfp,
-                       "!  Warning: \"%s\": Not ISTP compliant... not recommended",
-                       attrName);
+                       "!  Warning: \"%s\": Not ISTP compliant...", attrName);
          }
        }
        CHECKforABORTso
@@ -798,11 +795,12 @@ Logical WriteGlobalAttr ()
 * WriteVarAttr.
 ******************************************************************************/
 
-Logical WriteVarAttr ()
+Logical WriteVarAttr (void)
 {
   CDFstatus status;
   char delim,			     /* Delimeter for attribute name. */
        tempS[MAX_LINE_LEN+1];
+  char tempS2[5+CDF_ATTR_NAME_LEN256+1];
   long attrN, numAttrs, scope;
   char attrName[CDF_ATTR_NAME_LEN256+1];
   int VattrCount = 0;		     /* Number of variable scope attributes.*/
@@ -828,14 +826,14 @@ Logical WriteVarAttr ()
          ********************************************************************/
          VattrCount++;
          delim = PickDelimiter (attrName, strlen(attrName));
-         snprintf (tempS, (size_t) sizeof(tempS),
-	  	   "\n  %c%s%c", delim, attrName, delim);
-         WriteOut (SKTfp, tempS);
+         snprintf (tempS2, (size_t) sizeof(tempS2),
+	  	   "\n  %c%.*s%c", delim, (int)strlen(attrName), attrName,
+		   delim);
+         WriteOut (SKTfp, tempS2);
          if (!ISTPname(attrName)) {
            WriteOut (SKTfp, "\n");
            WriteOutFP (SKTfp,
-                       "!  Warning: \"%s\": Not ISTP compliant... not recommended",
-                       attrName);
+                       "!  Warning: \"%s\": Not ISTP compliant...", attrName);
          }
        }
        CHECKforABORTso
@@ -853,9 +851,9 @@ Logical WriteVarAttr ()
 * WriteVars.
 ******************************************************************************/
 
-Logical WriteVars (varValues, variables)
-int varValues;
-char *variables;
+Logical WriteVars (
+int varValues,
+char *variables)
 {
   CDFstatus status;
   long numVars;
@@ -894,11 +892,11 @@ char *variables;
 * WriteVar.
 ******************************************************************************/
 
-Logical WriteVar (varN, varValues, variables, zVar)
-long varN;
-int varValues;
-char *variables;
-Logical zVar;
+Logical WriteVar (
+long varN,
+int varValues,
+char *variables,
+Logical zVar)
 {
   CDFstatus status;
   long numDims, dimSizes[CDF_MAX_DIMS];
@@ -920,6 +918,7 @@ Logical zVar;
   char varys[MAX_VARYS_LEN+1];
   char sizes[MAX_SIZES_LEN+1];
   char tempS[MAX_LINE_LEN+1];
+  char tempS2[6+CDF_ATTR_NAME_LEN256+1];
   long cType, cParms[CDF_MAX_DIMS], cPct, sparse, bf;
   void *pad = NULL;
   int  padValue;
@@ -988,8 +987,10 @@ Logical zVar;
   if (numDims > 0) {
     strcpyX (varys, "", MAX_VARYS_LEN);
     for (dimN = 0; dimN < numDims; dimN++) {
-       strcatX (varys, TFvarianceToken(dimVarys[dimN]), MAX_VARYS_LEN);
-       strcatX (varys, " ", MAX_VARYS_LEN);
+       strcatX (varys, TFvarianceToken(dimVarys[dimN]),
+		strlen(TFvarianceToken(dimVarys[dimN])),
+		strlen(varys), MAX_VARYS_LEN);
+       strcatX (varys, " ", 1, strlen(varys), MAX_VARYS_LEN);
     }
     varys[strlen(varys)-1] = NUL;		/* Wipe out trailing blank. */
   }
@@ -1069,7 +1070,8 @@ Logical zVar;
   WriteOut (SKTfp, "\n");
   varNameLen = (int) strlen(varName);
   if (varNameLen < 75) {
-    snprintf (tempS, (size_t) sizeof(tempS), "  %c%s%c", delim, varName, delim);
+    snprintf (tempS, (size_t) sizeof(tempS), "  %c%.*s%c", delim, 74, varName,
+              delim);
     ccc = WriteOut (SKTfp, tempS);
   } else {
     int len, ix;
@@ -1137,8 +1139,7 @@ Logical zVar;
 
   if (!ISTPname(varName)) {
     WriteOutFP (SKTfp, 
-		"!  Warning: \"%s\": Not ISTP compliant... not recommended",
-                varName);
+		"!  Warning: \"%s\": Not ISTP compliant...", varName);
   }
 
     WriteOutFP (SKTfp, "\n  ! VAR_COMPRESSION: %s",
@@ -1186,15 +1187,11 @@ Logical zVar;
         if (precision == 0) {
           if (*format == 'E' || *format == 'e' ||
               *format == 'G' || *format == 'g') {
-/*              metaformat = 0; */
-/*              varformat = 0; */
           }
         } else {
           if (((*format == 'F' || *format == 'f') && precision < 5) ||
               ((*format == 'E' || *format == 'e') && precision < 5) ||
               ((*format == 'G' || *format == 'g') && precision < 5)) {
-/*              metaformat = 0; */
-/*              varformat = 0; */
           }
         }
       }
@@ -1204,12 +1201,12 @@ Logical zVar;
     }
   }
   if (STRINGdataType(varDataType)) {
-    int ix, iy;
+    int iy;
     if (padValue == 0) { /* Only output a single blank */
       *(((char *) pad)+0) = (char) DEFAULT_CHAR_PADVALUE;
       *(((char *) pad)+1) = (char) '\0';
     } else {
-      int ix, len;
+      int ix;
       iy = -1;
       for (ix = (varNumElements-1); ix >= 0; --ix) {
         if (*(((char *) pad)+ix) != ' ') {
@@ -1330,9 +1327,10 @@ Logical zVar;
 
        delim = PickDelimiter (attrName, strlen(attrName));
        WriteOut (SKTfp, "\n");
-       snprintf (tempS, (size_t) sizeof(tempS),
-		 "    %c%s%c", delim, attrName, delim);
-       ccc = WriteOut (SKTfp, tempS);
+       snprintf (tempS2, (size_t) sizeof(tempS2),
+		 "    %c%.*s%c", delim, (int)strlen(attrName), attrName,
+		 delim);
+       ccc = WriteOut (SKTfp, tempS2);
 
        if (entryDataType != CDF_TIME_TT2000) ddd = 0;
        else ddd = 4;
@@ -1468,7 +1466,7 @@ Logical zVar;
 * WriteEnd.
 ******************************************************************************/
 
-Logical WriteEnd ()
+Logical WriteEnd (void)
 {
   WriteOut (SKTfp, "\n\n");
   WriteOut (SKTfp, "\n#end");
@@ -1480,19 +1478,18 @@ Logical WriteEnd ()
 *     It is assumed that there is at least one record in the CDF.
 ******************************************************************************/
 
-Logical WriteVariableData (fp, zVar, varN, dataType, numElements, numDims,
-			   dimSizes, recVary, dimVarys, maxRec, format)
-FILE *fp;
-Logical zVar;
-long varN;
-long dataType;
-long numElements;
-long numDims;
-long dimSizes[];
-long recVary;
-long dimVarys[];
-long maxRec;
-char *format;
+Logical WriteVariableData (
+FILE *fp,
+Logical zVar,
+long varN,
+long dataType,
+long numElements,
+long numDims,
+long dimSizes[],
+long recVary,
+long dimVarys[],
+long maxRec,
+char *format)
 {
   CDFstatus status;
   long indices[CDF_MAX_DIMS];
@@ -1559,10 +1556,11 @@ char *format;
           for (dimN = 0; dimN < numDims; dimN++) {
              snprintf (EofS(tempS), (size_t) sizeof(tempS)-strlen(tempS),
 		       "%ld", indices[dimN] + 1);
-	     if (dimN != numDims-1) strcatX (tempS, ",", MAX_LINE_LEN);
+	     if (dimN != numDims-1)
+	       strcatX (tempS, ",",  1, strlen(tempS), MAX_LINE_LEN);
           }
         }
-        strcatX (tempS, "] = ",MAX_LINE_LEN);
+        strcatX (tempS, "] = ", 4, strlen(tempS), MAX_LINE_LEN);
 	ccc += WriteOut (SKTfp, tempS);
         if (STRINGdataType(dataType)) {
           long maxLen = (long) strlen (value);
@@ -1639,29 +1637,10 @@ char *format;
 * <delim><chars><delim>,<delim><chars><delim>,...,<delim><chars><delim>
 ******************************************************************************/
 
-Logical VariableSelected (varName, variables)
-char *varName;
-char *variables;
+Logical VariableSelected (
+char *varName,
+char *variables)
 {
-/*
-  char *d1, *d2, varNameT[CDF_VAR_NAME_LEN256+1];
-  size_t len;
-  d1 = variables;
-  for (;;) {
-    while (*d1 != NUL && Spacing(*d1)) d1++;
-    if (*d1 == NUL) return FALSE;
-    d2 = d1 + 1;
-    while (*d2 != NUL && *d2 != *d1) d2++;
-    if (*d2 == NUL) return FALSE;
-    len = (size_t) (d2 - d1 - 1);
-    strcpyX (varNameT, d1 + 1, MINIMUM(len,CDF_VAR_NAME_LEN256));
-    if (!strcmpITB(varName,varNameT)) return TRUE;
-    d1 = d2 + 1;
-    while (*d1 != NUL && *d1 != ',') d1++;
-    if (*d1 == NUL) return FALSE;
-    d1++;
-  }
-*/
   if (variables == NULL) return FALSE;
   if (strstr((const char *)variables, (const char *)varName) != NULL)
     return TRUE;
@@ -1674,8 +1653,8 @@ char *variables;
 *    Strings are blank-padded on the end to all be the same length.
 ******************************************************************************/
 
-char *DataTypePaddedString (dataType)
-long dataType;
+char *DataTypePaddedString (
+long dataType)
 {
   switch (dataType) {
     case CDF_BYTE:   return "CDF_BYTE  ";
@@ -1703,8 +1682,8 @@ long dataType;
 * StatusHandlerC2S.
 ******************************************************************************/
 
-Logical StatusHandlerC2S (status)
-CDFstatus status;
+Logical StatusHandlerC2S (
+CDFstatus status)
 {
   char text[CDF_STATUSTEXT_LEN + 1];
 
@@ -1756,9 +1735,9 @@ CDFstatus status;
 * WriteTT2000VarData.
 ******************************************************************************/
 
-Logical WriteTT2000VarData (varValues, variables)
-int varValues;
-char *variables;
+Logical WriteTT2000VarData (
+int varValues,
+char *variables)
 {
   CDFstatus status;
   long numVars, numZvars;
@@ -1837,9 +1816,9 @@ char *variables;
 ******************************************************************************/
 
 #if defined(mac)
-Logical SkeletonTableQOPs (argC, argV)
-int *argC;
-char **argV[];
+Logical SkeletonTableQOPs (
+int *argC,
+char **argV[])
 {
   DialogPtr dialogP;
   DialogRecord dRecord;
