@@ -64,9 +64,9 @@ MAIN {
 * DumpCDF.
 ******************************************************************************/
 
-Logical DumpCDF (argC, argV)
-int  argC;
-char *argV[];
+Logical DumpCDF (
+int  argC,
+char *argV[])
 {
 
 CDFstatus status;
@@ -120,7 +120,6 @@ static int optRequired[] = {
 int numValidDumps = 6;
 static char *validDumps[] = {
   "all", "data", "nodata", "metadata", "global", "variable" };
-char *locale;
 
 /******************************************************************************
 * Parse qualifiers/options/parameters (QOP).
@@ -290,13 +289,13 @@ switch (argC) {
         char mytmp[CDF_PATHNAME_LEN+1];
         strcpyX (mytmp, CDFpath, CDF_PATHNAME_LEN);
         loc = StrlaststrIgCase(mytmp, ".cdf");
-        if (loc == -1) strcatX (EofS(mytmp), ".txt", 0);
+        if (loc == -1) strcatX (EofS(mytmp), ".txt", 4, strlen(mytmp), 0);
         else strcpyX (mytmp+loc, ".txt", 0);
         strcpyX (outputFile, mytmp, 0);
       } else {
         ParsePath (outputFile, oDir, oName);
         if (strchr(oName,'.') == NULL) 
-          strcatX (outputFile, ".txt", DU_MAX_PATH_LEN);
+          strcatX (outputFile, ".txt", 4, strlen(outputFile), DU_MAX_PATH_LEN);
       }
     }
     if (!strcmp(outputFile, CDFpath)) {
@@ -478,7 +477,7 @@ switch (argC) {
                 fprintf (fp, "\"%s\"\n", (char *)value);
               } else {
                 int ix, style;
-                char tmp[256];
+                char tmp[255+1];
                 if (TT2000dataType(dataTypeX)) {
                   if (!ziso8601) style = TT2000_3_STYLE;
                   else style = TT2000_4_STYLE;
@@ -491,9 +490,9 @@ switch (argC) {
                                (char *)value+ix*CDFelemSize(dataTypeX),
                                tmp, style, (size_t) sizeof(tmp));
                   if (ix == 0) strcpyX (tText, tmp, 0);
-                  else strcatX (tText, tmp, 255);
+                  else strcatX (tText, tmp, strlen(tmp), strlen(tText), 255);
                   if (numElemsX > 1 && ix < (numElemsX-1))
-                    strcatX (tText, ", ", 255);
+                    strcatX (tText, ", ", 2, strlen(tText), 255);
                 }
                 fprintf (fp, "%s\n", tText);
               }
@@ -1081,7 +1080,8 @@ switch (argC) {
                             (size_t)nLogValuesPerRec*nValueBytes[0]); 
                   }
                 }
-                memcpy (working, (char *) value+offset, nBytes);
+                memcpy (working, (char *) value+offset,
+                        (STRINGdataType(dataType)?nBytes-1:nBytes));
                 if (STRINGdataType(dataType)) {
                   ((char *)working)[numElems] = '\0';
                   fprintf (fp, "\"%s\"", (char *)working);
@@ -1219,7 +1219,8 @@ switch (argC) {
                             (size_t)nLogValuesPerRec*nValueBytes[0]);
                   }
                 } 
-                memcpy (working, (char *)value+offset, nBytes);
+                memcpy (working, (char *)value+offset, 
+                        (STRINGdataType(dataType)?nBytes-1:nBytes));
                 if (STRINGdataType(dataType)) {
                     ((char *)working)[numElems] = '\0';
                   fprintf (fp, "\"%s\"", (char *)working);
@@ -1334,11 +1335,11 @@ switch (argC) {
 * QuitCDF.
 ******************************************************************************/
 
-Logical QuitCDF (file, where, status, msg)
-char *file;
-char *where;
-CDFstatus status;
-char *msg;
+Logical QuitCDF (
+char *file,
+char *where,
+CDFstatus status,
+char *msg)
 {
   char text[CDF_STATUSTEXT_LEN+1];
   fprintf (fp, "Program failed for file: %s at %s...\n", file, where);
@@ -1361,9 +1362,9 @@ char *msg;
 * IsVirtualVar.
 ******************************************************************************/
 
-Logical IsVirtualVar (varNum, Z)
-long varNum;
-Logical Z;
+Logical IsVirtualVar (
+long varNum,
+Logical Z)
 {
   CDFstatus status;
   long numElems;
@@ -1381,10 +1382,10 @@ Logical Z;
 * HandleVariable.
 ******************************************************************************/
 
-void *HandleVariable (varNum, Z, maxRec)
-long varNum;
-Logical Z;
-long *maxRec;
+void *HandleVariable (
+long varNum,
+Logical Z,
+long *maxRec)
 {
   CDFstatus status;
   long numElems;
@@ -1402,10 +1403,10 @@ long *maxRec;
 * HandleReal.
 ******************************************************************************/
 
-void *HandleReal (varNum, Z, maxRec)
-long varNum;
-Logical Z;
-long *maxRec;
+void *HandleReal (
+long varNum,
+Logical Z,
+long *maxRec)
 {
   CDFstatus status;
   long numElems, dataType, varMaxRec;
@@ -1465,9 +1466,9 @@ long *maxRec;
 * GetVirtualVarMaxRecord.
 ******************************************************************************/
 
-long GetVirtualVarMaxRecord (varNum, Z)
-long varNum;
-Logical Z;
+long GetVirtualVarMaxRecord (
+long varNum,
+Logical Z)
 {
   CDFstatus status;
   long numElems1, numElems2, varN1, varN2, varMaxRec1, varMaxRec2;
@@ -1521,10 +1522,10 @@ Logical Z;
 * HandleVirtual.
 ******************************************************************************/
 
-void *HandleVirtual (varNum, Z, maxRec)
-long varNum;
-Logical Z;
-long *maxRec;
+void *HandleVirtual (
+long varNum,
+Logical Z,
+long *maxRec)
 {
   CDFstatus status;
   long numElems1, numElems2;
@@ -1768,7 +1769,10 @@ long *maxRec;
 * EpochScale. It returns the scale of units between the base and offset times.
 ******************************************************************************/
 
-double EpochScale(long dataType1, char *units) {
+double EpochScale (
+long dataType1, 
+char *units) 
+{
   /* msec - milliseconds */
   if (dataType1==CDF_EPOCH && strcmpIgCase(units, "sec")) return 1.E3;
   if (dataType1==CDF_EPOCH && strcmpIgCase(units, "msec")) return 1.0;
