@@ -88,9 +88,9 @@ MAIN {
 * EditCDFs.
 ******************************************************************************/
 
-Logical EditCDFs (argC, argV)
-int argC;
-char *argV[];
+Logical EditCDFs (
+int argC,
+char *argV[])
 {
    QOP *qop;
    static char *validQuals[] = {
@@ -297,15 +297,14 @@ char *argV[];
 * SpecificationPrompt.
 ******************************************************************************/
 
-Logical SpecificationPrompt (CDFspec, useFormat, negToPosFp0, zMode,
-			     workingCache, stageCache, compressCache)
-char CDFspec[DU_MAX_PATH_LEN+1];
-Logical useFormat;
-Logical negToPosFp0;
-long zMode;
-long workingCache;
-long stageCache;
-long compressCache;
+Logical SpecificationPrompt (
+char CDFspec[DU_MAX_PATH_LEN+1],
+Logical useFormat,
+Logical negToPosFp0,
+long zMode,
+long workingCache,
+long stageCache,
+long compressCache)
 {
   for (;;) {
     if (NULstring(CDFspec)) strcpyX (CDFspec,CURRENTDIRECTORY,DU_MAX_PATH_LEN);
@@ -336,15 +335,14 @@ long compressCache;
 * EditCDFsMenu.
 ******************************************************************************/
 
-Logical EditCDFsMenu (CDFspec, negToPosFp0, useFormat, zMode, workingCache,
-		      stageCache, compressCache)
-char *CDFspec;
-Logical negToPosFp0;
-Logical useFormat;
-long zMode;
-long workingCache;
-long stageCache;
-long compressCache;
+Logical EditCDFsMenu (
+char *CDFspec,
+Logical negToPosFp0,
+Logical useFormat,
+long zMode,
+long workingCache,
+long stageCache,
+long compressCache)
 {
   CDFstatus status; int nCDFs;
   char **dirS, **CDFs;
@@ -538,7 +536,7 @@ long compressCache;
 	 break;
        }
        /***********************************************************************
-       * Delete currently selected CDF.  When the CDFs menu is updated, the
+       * Delete currently selected CDF. When the CDFs menu is updated, the
        * new current item is set to the old current item (or the last item
        * in case more than one CDF was deleted [possibly by another user]).
        * The new current item should be the CDF (in the list) that followed
@@ -550,10 +548,20 @@ long compressCache;
 	   ProblemWindow (noneMsg, FALSE);
 	 }
 	 else {
-	   char delim, question[DU_MAX_NAME_LEN+15+1];
+	   char delim, question[76+1];
 	   delim = PickDelimiter (CDFs[IW.itemN],strlen(CDFs[IW.itemN]));
 	   snprintf (question, (size_t) sizeof(question),
-		     "Delete CDF %c%s%c ?", delim, CDFs[IW.itemN], delim);
+		     "Delete CDF %c%c ?", delim, delim);
+	   used = (int) strlen (question);
+	   numShown = numCharsShown (sizeof(question)-1, used, CDFs[IW.itemN]);
+	   if (numShown > 0)
+	     snprintf (question, (size_t) sizeof(question),
+		       "Delete CDF %c%.*s%c ?", delim,
+		       (int)strlen(CDFs[IW.itemN]), CDFs[IW.itemN], delim);
+	   else
+	     snprintf (question, (size_t) sizeof(question),
+		       "Delete CDF %c%.*s%s%c ?", delim,
+		       -numShown, CDFs[IW.itemN], dots3, delim);
 	   if (ConfirmWindow(3,78,question,NULL,FALSE,DELETECDFhelpID)) {
 	     CDFstatus status; int lastItemN;
 	     Logical isLFS;
@@ -599,12 +607,12 @@ long compressCache;
 * BuildCDFsMenu.
 ******************************************************************************/
 
-void BuildCDFsMenu (CDFspec, nCDFs, dirS, CDFs, IW)
-char *CDFspec;
-int *nCDFs;
-char ***dirS;
-char ***CDFs;
-struct ItemWindowStruct *IW;
+void BuildCDFsMenu (
+char *CDFspec,
+int *nCDFs,
+char ***dirS,
+char ***CDFs,
+struct ItemWindowStruct *IW)
 {
   int CDFn;
   snprintf (IW->label, (size_t) 16+DU_MAX_PATH_LEN+2+1,
@@ -616,7 +624,13 @@ struct ItemWindowStruct *IW;
     AllocIW (IW, *nCDFs, *nCDFs, CDFs_NAME_LEN, FatalError);
     for (CDFn = 0; CDFn < *nCDFs; CDFn++) {
        size_t nameLen = strlen((*CDFs)[CDFn]);
-       strcpyX (IW->iLines[CDFn], (*CDFs)[CDFn], CDFs_NAME_LEN);
+       if (nameLen <= CDFs_NAME_LEN)
+	 strcpyX (IW->iLines[CDFn], (*CDFs)[CDFn], CDFs_NAME_LEN);
+       else {
+	 strcpyX (IW->iLines[CDFn], (*CDFs)[CDFn], CDFs_NAME_LEN-3);
+	 strcatX (IW->iLines[CDFn], dots3, strlen(dots3),
+		  strlen(IW->iLines[CDFn]), CDFs_NAME_LEN);
+       }
        IW->iLineNs[CDFn] = CDFn;
        IW->iCols[CDFn] = 0;
        IW->iLens[CDFn] = (int) MINIMUM(CDFs_NAME_LEN,nameLen);
@@ -634,10 +648,10 @@ struct ItemWindowStruct *IW;
 * FreeCDFsMenu.
 ******************************************************************************/
 
-void FreeCDFsMenu (dirS, CDFs, IW)
-char **dirS;
-char **CDFs;
-struct ItemWindowStruct *IW;
+void FreeCDFsMenu (
+char **dirS,
+char **CDFs,
+struct ItemWindowStruct *IW)
 {
   if (dirS != NULL) cdf_FreeMemory (dirS, FatalError);
   if (CDFs != NULL) cdf_FreeMemory (CDFs, FatalError);
@@ -649,15 +663,14 @@ struct ItemWindowStruct *IW;
 * TryToEditCDF.
 ******************************************************************************/
 
-Logical TryToEditCDF (CDFspec, negToPosFp0, useFormat, zMode, workingCache,
-		      stageCache, compressCache)
-char *CDFspec;
-Logical negToPosFp0;
-Logical useFormat;
-long zMode;
-long workingCache;
-long stageCache;
-long compressCache;
+Logical TryToEditCDF (
+char *CDFspec,
+Logical negToPosFp0,
+Logical useFormat,
+long zMode,
+long workingCache,
+long stageCache,
+long compressCache)
 {
   CDFstatus status;
   char CDFdir[DU_MAX_DIR_LEN+1], CDFname[DU_MAX_NAME_LEN+1];
@@ -680,17 +693,36 @@ long compressCache;
   switch (status) {
     case NO_SUCH_CDF:
       if (!browseOnly) {
-	char delim, question[DU_MAX_PATH_LEN+29+1];
+	char delim, question[76+1];
 	int helpID;
 	delim = PickDelimiter(CDFfullName, strlen(CDFfullName));
 	if (CDFgetFileBackwardEnvVar() == 1) {
 	  snprintf (question, (size_t) sizeof(question),
-	            "CDF %c%s%c does not exist.  Create?", delim,
-	            CDFfullName, delim);
+	            "CDF %c%c does not exist.  Create?", delim, delim);
+	  used = (int) strlen (question);
+	  numShown = numCharsShown (sizeof(question)-1, used, CDFfullName);
+	  if (numShown > 0)
+	    snprintf (question, (size_t) sizeof(question),
+		      "CDF %c%.*s%c does not exist.  Create?", delim,
+		      (int)strlen(CDFfullName), CDFfullName, delim);
+	  else
+	    snprintf (question, (size_t) sizeof(question),
+		      "CDF %c%.*s%s%c does not exist.  Create?", delim,
+		      -numShown, CDFfullName, dots3, delim);
 	} else {
 	  snprintf (question, (size_t) sizeof(question),
-	            "CDF %c%s%c does not exist.  Create(V3 or V2.7)?", delim,
-		    CDFfullName, delim);
+	            "CDF %c%c does not exist.  Create(V3 or V2.7)?", delim,
+		    delim);
+	  used = (int) strlen (question);
+	  numShown = numCharsShown (sizeof(question)-1, used, CDFfullName);
+	  if (numShown > 0)
+	    snprintf (question, (size_t) sizeof(question),
+		      "CDF %c%.*s%c does not exist.  Create(V3 or V2.7)?",
+		      delim, (int)strlen(CDFfullName), CDFfullName, delim);
+	  else
+	    snprintf (question, (size_t) sizeof(question),
+		      "CDF %c%.*s%s%c does not exist.  Create(V3 or V2.7)?",
+		      delim, -numShown, CDFfullName, dots3, delim);
 	  helpID = CREATECDFV23helpID;
 	}
 	if (ConfirmWindow2(3,78,question,NULL,TRUE,helpID)) {
@@ -717,21 +749,20 @@ long compressCache;
 * CreateCDF.
 ******************************************************************************/
 
-Logical CreateCDF (CDFdir, CDFname, zMode, useFormat, negToPosFp0,
-		   workingCache, stageCache, compressCache, IWcdfs)
-char *CDFdir;           /* Directory in which to create CDF. */
-char *CDFname;          /* If null-string (""), then prompt for name.  Returns
+Logical CreateCDF (
+char *CDFdir,           /* Directory in which to create CDF. */
+char *CDFname,          /* If null-string (""), then prompt for name.  Returns
 			   name entered here. */
-long zMode;             /* The zMode to select after CDF is created. */
-Logical useFormat;      /* TRUE if FORMAT attribute should be used. */
-Logical negToPosFp0;    /* TRUE if conversion of -0.0 to +0.0 should be
+long zMode,             /* The zMode to select after CDF is created. */
+Logical useFormat,      /* TRUE if FORMAT attribute should be used. */
+Logical negToPosFp0,    /* TRUE if conversion of -0.0 to +0.0 should be
 			   selected after CDF is created. */
-long workingCache;      /* Number of cache buffers for the "working" dotCDF
+long workingCache,      /* Number of cache buffers for the "working" dotCDF
 			   file. */
-long stageCache;	/* Number of cache buffers for the staging file. */
-long compressCache;	/* Number of cache buffers for the compression scratch
+long stageCache,	/* Number of cache buffers for the staging file. */
+long compressCache,	/* Number of cache buffers for the compression scratch
 			   file. */
-struct ItemWindowStruct *IWcdfs;
+struct ItemWindowStruct *IWcdfs)
 			/* Pointer to "CDFs Menu" widget.  If NULL, then this
 			   routine was not called from the "CDFs Menu". */
 {
@@ -836,15 +867,14 @@ struct ItemWindowStruct *IWcdfs;
 * EditCDF.
 ******************************************************************************/
 
-Logical EditCDF (CDFname, useFormat, workingCache, stageCache, compressCache,
-		 zMode, negToPosFp0)
-char *CDFname;
-Logical useFormat;
-long workingCache;
-long stageCache;
-long compressCache;
-long zMode;
-Logical negToPosFp0;
+Logical EditCDF (
+char *CDFname,
+Logical useFormat,
+long workingCache,
+long stageCache,
+long compressCache,
+long zMode,
+Logical negToPosFp0)
 {
   Logical status, closed = FALSE;
   /****************************************************************************
@@ -864,19 +894,17 @@ Logical negToPosFp0;
 * EditCDFx.
 ******************************************************************************/
 
-Logical EditCDFx (CDFname, useFormat, workingCache, stageCache, compressCache,
-		  zMode, negToPosFp0, closed)
-char *CDFname;
-Logical useFormat;
-long workingCache;
-long stageCache;
-long compressCache;
-long zMode;
-Logical negToPosFp0;
-Logical *closed;
+Logical EditCDFx (
+char *CDFname,
+Logical useFormat,
+long workingCache,
+long stageCache,
+long compressCache,
+long zMode,
+Logical negToPosFp0,
+Logical *closed)
 {
    CDFstatus status;
-   long readonlyMode = BOO(browseOnly,READONLYon,READONLYoff);
    long negToPosFp0Mode = BOO(negToPosFp0,NEGtoPOSfp0on,NEGtoPOSfp0off);
    AOSs3 (hLines, BLANKs78, BLANKs78, BLANKs78)
    static Logical first = TRUE;
@@ -1125,10 +1153,20 @@ Logical *closed;
        ***********************************************************************/
        case DELETECDFkey_EDIT:
 	 if (!browseOnly) {
-	   char delim, question[DU_MAX_NAME_LEN+15+1];
+	   char delim, question[78+1];
 	   delim = PickDelimiter (CDFname, strlen(CDFname));
 	   snprintf (question, (size_t) sizeof(question),
-		     "Delete CDF %c%s%c ?", delim, CDFname, delim);
+		     "Delete CDF %c%c ?", delim, delim);
+	   used = (int) strlen (question);
+	   numShown = numCharsShown (sizeof(question)-1, used, CDFname);
+	   if (numShown > 0)
+	     snprintf (question, (size_t) sizeof(question),
+		       "Delete CDF %c%.*s%c ?", delim, (int)strlen(CDFname),
+		       CDFname, delim);
+	   else
+	     snprintf (question, (size_t) sizeof(question),
+		       "Delete CDF %c%.*s%s%c ?", delim, -numShown, CDFname,
+		       dots3, delim);
 	   if (ConfirmWindow(12,80,question,NULL,FALSE,DELETECDFhelpID)) {
 	     status = CDFlib (DELETE_, CDF_,
 	 		      NULL_);
@@ -1242,9 +1280,9 @@ Logical *closed;
 * BuildCDFmenu.
 ******************************************************************************/
 
-Logical BuildCDFmenu (CDFname, IW)
-char *CDFname;
-struct ItemWindowStruct *IW;
+Logical BuildCDFmenu (
+char *CDFname,
+struct ItemWindowStruct *IW)
 {
   CDFstatus status;
   long format, encoding, majority, checksum;
@@ -1344,8 +1382,8 @@ struct ItemWindowStruct *IW;
 * specification was entered; FALSE otherwise.
 ******************************************************************************/
 
-Logical PromptForSpec (CDFspec)
-char CDFspec[DU_MAX_PATH_LEN+1];
+Logical PromptForSpec (
+char CDFspec[DU_MAX_PATH_LEN+1])
 {
   static char *header[] = {
     "Enter CDF(s) specification (without delimiters)...",
@@ -1422,9 +1460,9 @@ char CDFspec[DU_MAX_PATH_LEN+1];
 ******************************************************************************/
 
 #if defined(mac)
-Logical EditQOPs (argC, argV)
-int *argC;
-char **argV[];
+Logical EditQOPs (
+int *argC,
+char **argV[])
 {
   DialogPtr dialogP;
   DialogRecord dRecord;
