@@ -33,7 +33,8 @@
 * InitializeScreen.
 ******************************************************************************/
 
-void InitializeScreen () {
+void InitializeScreen (void) 
+{
   create_pasteboard ();
   set_cursor_mode (CURSORoff);
   return;
@@ -43,7 +44,8 @@ void InitializeScreen () {
 * CleanupScreen.
 ******************************************************************************/
 
-void CleanupScreen () {
+void CleanupScreen (void) 
+{
   delete_pasteboard (ERASE);
   set_cursor_mode (CURSORon);
   return;
@@ -53,9 +55,9 @@ void CleanupScreen () {
 * ReportStatus.
 ******************************************************************************/
 
-Logical ReportStatus (status, center)
-CDFstatus status;
-Logical center;
+Logical ReportStatus (
+CDFstatus status,
+Logical center)
 {
   if ((StatusINFO(status) && report[INFOs]) ||
       (StatusWARN(status) && report[WARNs]) ||
@@ -67,9 +69,9 @@ Logical center;
 * CDFstatusWindow.
 ******************************************************************************/
 
-void CDFstatusWindow (status, center)
-CDFstatus status;
-Logical center;
+void CDFstatusWindow (
+CDFstatus status,
+Logical center)
 {
    static char text[CDF_STATUSTEXT_LEN+1];
    CDFlib (SELECT_, CDF_STATUS_, status,
@@ -83,9 +85,9 @@ Logical center;
 * ProblemWindow.
 ******************************************************************************/
 
-void ProblemWindow (message, center)
-char *message;
-Logical center;
+void ProblemWindow (
+char *message,
+Logical center)
 {
    static int exitChars[] = { NUL };
    static struct EditWindowStruct EW = {
@@ -160,8 +162,9 @@ va_dcl
     EW.eText = (char *) cdf_AllocateMemory ((size_t)textLength + 1, FatalError);
     MakeNUL (EW.eText);
     for (lineN = 0; !NULstring(lineS[lineN]); lineN++) {
-       strcatX (EW.eText, lineS[lineN], textLength);
-       strcatX (EW.eText, "\n", textLength);
+       strcatX (EW.eText, lineS[lineN], strlen(lineS[lineN]),
+	        strlen(EW.eText), textLength);
+       strcatX (EW.eText, "\n", 1, strlen(EW.eText), textLength);
     }
     EW.NeRows = lineN;
     EW.label = label;
@@ -178,13 +181,13 @@ va_dcl
 * ConfirmWindow.
 ******************************************************************************/
 
-Logical ConfirmWindow (rowN, width, question1, question2, yesInitial, helpId)
-int rowN;
-int width;
-char *question1;
-char *question2;        /* If NULL, a one line question. */
-Logical yesInitial;     /* If TRUE, <YES> is initial current item. */
-int helpId;
+Logical ConfirmWindow (
+int rowN,
+int width,
+char *question1,
+char *question2,        /* If NULL, a one line question. */
+Logical yesInitial,     /* If TRUE, <YES> is initial current item. */
+int helpId)
 {
   static char label[] = " Confirmation ";
   static char *header[] = { NULL, NULL };
@@ -197,12 +200,13 @@ int helpId;
   static int iLineNs[] = { 1, 1 };
   static int iCols[] = { 18, 53 };
   static int iLens[] = { 5, 4 };
+  static int ibLens[] = { 5, 4 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt = {
-    0, 0, 0, label, 0, header, 3, items, 2, iLineNs, iCols, iLens, 3,
+    0, 0, 0, label, 0, header, 3, items, 2, iLineNs, iCols, iLens, ibLens, 3,
     1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
-  Logical answer;
+  Logical answer = FALSE;
   EncodeKeyDefinitions (1, trailer, ENTERkey_FSI, EXITkey_FSI,
                         HELPkey_FSI);
   IWt.hLines[0] = question1;
@@ -226,7 +230,7 @@ int helpId;
     }
   else
     answer = FALSE;
-    ItemWindow (DELETEiw, &IWt);
+  ItemWindow (DELETEiw, &IWt);
   return answer;
 }
 
@@ -234,13 +238,13 @@ int helpId;
 * ConfirmWindow2.
 ******************************************************************************/
 
-Logical ConfirmWindow2 (rowN, width, question1, question2, yesInitial, helpId)
-int rowN;
-int width;
-char *question1;
-char *question2;        /* If NULL, a one line question. */
-Logical yesInitial;     /* If TRUE, <YES> is initial current item. */
-int helpId;
+Logical ConfirmWindow2 (
+int rowN,
+int width,
+char *question1,
+char *question2,        /* If NULL, a one line question. */
+Logical yesInitial,     /* If TRUE, <YES> is initial current item. */
+int helpId)
 {
   static char label[] = " Confirmation ";
   static char *header[] = { NULL, NULL };
@@ -257,23 +261,23 @@ int helpId;
   };
   static int iLineNs1[] = { 1, 1 };
   static int iLineNs2[] = { 1, 1, 1 };
-  static int iCols[2];
-  static int iLens[2];
   static int iCols1[] = { 18, 53 };
   static int iLens1[] = { 5, 4 };
+  static int ibLens1[] = { 5, 4 };
   static int iCols2[] = { 11, 30, 53 };
   static int iLens2[] = { 11, 11, 4 };
+  static int ibLens2[] = { 11, 11, 4 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt;
   static struct ItemWindowStruct IWt1 = {
-    0, 0, 0, label, 0, header, 3, items1, 2, iLineNs1, iCols1, iLens1, 3,
-    1, trailer, exitChars, REFRESHkey_FSI, FALSE
+    0, 0, 0, label, 0, header, 3, items1, 2, iLineNs1, iCols1, iLens1, ibLens1,
+    3, 1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
   static struct ItemWindowStruct IWt2 = {
-    0, 0, 0, label, 0, header, 3, items2, 3, iLineNs2, iCols2, iLens2, 3,
-    1, trailer, exitChars, REFRESHkey_FSI, FALSE
+    0, 0, 0, label, 0, header, 3, items2, 3, iLineNs2, iCols2, iLens2, ibLens2,
+    3, 1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
-  Logical answer;
+  Logical answer = FALSE;
   EncodeKeyDefinitions (1, trailer, ENTERkey_FSI, EXITkey_FSI,
 			HELPkey_FSI);
   if (CDFgetFileBackwardEnvVar() == 1) 
@@ -326,9 +330,9 @@ int helpId;
 * EnterIW.
 ******************************************************************************/
 
-Logical EnterIW (IW, helpId)
-struct ItemWindowStruct *IW;
-int helpId;
+Logical EnterIW (
+struct ItemWindowStruct *IW,
+int helpId)
 {
   for (;;) {
      ItemWindow (READiw, IW);
@@ -348,12 +352,12 @@ int helpId;
 * EnterPW.
 ******************************************************************************/
 
-Logical EnterPW (PW, helpId)
-struct PromptWindowStruct *PW;
-int helpId;
+Logical EnterPW (
+struct PromptWindowStruct *PW,
+int helpId)
 {
   for (;;) {
-     PromptWindow (READiw, PW);
+     PromptWindow (READpw, PW);
      switch (PW->key) {
        case EXITkey_FSI:
 	 return FALSE;
@@ -370,10 +374,10 @@ int helpId;
 * IndexInList.
 ******************************************************************************/
 
-int IndexInList (match, nItems, items)
-char *match;
-int nItems;
-char **items;
+int IndexInList (
+char *match,
+int nItems,
+char **items)
 {
   int i;
   for (i = 0; i < nItems; i++) if (!strcmp(match,items[i])) return i;
@@ -384,8 +388,8 @@ char **items;
 * DataTypeItemN.
 ******************************************************************************/
 
-int DataTypeItemN (dataType)
-long dataType;
+int DataTypeItemN (
+long dataType)
 {
   static char *symbols[] = { DTiwSYMBOLS };
   static int colums[] = { DTiwCOLs };
@@ -395,7 +399,8 @@ long dataType;
   int itemN; char *symbol;
   for (itemN = 0; itemN < 15; itemN++) {
      strcpyX (token, "CDF_", 11);
-     strcatX (token, DataTypeToken(dataType), 11);
+     strcatX (token, DataTypeToken(dataType), strlen(DataTypeToken(dataType)),
+	      strlen(token), 11);
      symbol = &(symbols[lineNs[itemN]][colums[itemN]]);
      if (!strncmp(token,symbol,lengths[itemN])) return itemN;
   }
@@ -406,9 +411,9 @@ long dataType;
 * ShowFullName.
 ******************************************************************************/
 
-void ShowFullName (name, attr)
-char *name;
-Logical attr;   /* TRUE: attribute, FALSE: variable. */
+void ShowFullName (
+char *name,
+Logical attr)   /* TRUE: attribute, FALSE: variable. */
 {
   AOSs6 (lineS, " ",BLANKs78," ","  Enter any key to continue...  "," ","")
   size_t length = strlen (name);
@@ -425,7 +430,8 @@ Logical attr;   /* TRUE: attribute, FALSE: variable. */
 * SelectMajority.
 ******************************************************************************/
 
-Logical SelectMajority () {
+Logical SelectMajority (void)
+{
   long majority; int itemN; CDFstatus status;
   static char *header[] = { "Select new majority..." };
   AOSs1 (trailer, "Select: ________   Exit: ________   Help:   ________")
@@ -433,10 +439,11 @@ Logical SelectMajority () {
   static int iLineNs[] = { 0, 1 };
   static int iCols[] = { 0, 0 };
   static int iLens[] = { 3, 6 };
+  static int ibLens[] = { 3, 6 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt = {
-    12, 0, 80, NULL, 1, header, 2, items, 2, iLineNs, iCols, iLens, 3, 1,
-    trailer, exitChars, REFRESHkey_FSI, FALSE
+    12, 0, 80, NULL, 1, header, 2, items, 2, iLineNs, iCols, iLens, ibLens, 3,
+    1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
   EncodeKeyDefinitions (1, trailer, ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI);
   status = CDFlib (GET_, CDF_MAJORITY_, &majority,
@@ -471,7 +478,8 @@ Logical SelectMajority () {
 * SelectFormat.
 ******************************************************************************/
 
-Logical SelectFormat () {
+Logical SelectFormat (void) 
+{
   long format; int itemN; CDFstatus status;
   static char *header[] = { "Select new format..." };
   AOSs1 (trailer, "Select: ________   Exit: ________   Help:   ________")
@@ -479,10 +487,11 @@ Logical SelectFormat () {
   static int iLineNs[] = { 0, 1 };
   static int iCols[] = { 0, 0 };
   static int iLens[] = { 6, 5 };
+  static int ibLens[] = { 6, 5 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt = {
-    12, 0, 80, NULL, 1, header, 2, items, 2, iLineNs, iCols, iLens, 3, 1,
-    trailer, exitChars, REFRESHkey_FSI, FALSE
+    12, 0, 80, NULL, 1, header, 2, items, 2, iLineNs, iCols, iLens, ibLens, 3,
+    1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
   EncodeKeyDefinitions (1, trailer, ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI);
   status = CDFlib (GET_, CDF_FORMAT_, &format,
@@ -517,21 +526,24 @@ Logical SelectFormat () {
 * SelectEncoding.
 ******************************************************************************/
 
-Logical SelectEncoding () {
+Logical SelectEncoding (void) 
+{
   long encoding; int itemN; CDFstatus status;
   static char *header[] = { "Select new encoding..." };
   AOSs1 (trailer, "Select: ________   Exit: ________   Help:   ________")
   static char *items[] = {
     "HOST      SUN   IBMPC   SGi   HP     ALPHAVMSg   ALPHAVMSi   DECSTATION",
-    "NETWORK   VAX   IBMRS   PPC   NeXT   ALPHAVMSd   ALPHAOSF1"
+    "NETWORK   VAX   IBMRS   PPC   NeXT   ALPHAVMSd   ALPHAOSF1   ARM_LITTLE",
+    "ARM_BIG   IA64VMSi  IA64VMSd  IA64VMSg"
   };
-  static int iLineNs[] = { 0,0,0,0,0,0,0,0,1,1,1,1,1,1,1 };
-  static int iCols[] = { 0,10,16,24,30,37,49,61,0,10,16,24,30,37,49 };
-  static int iLens[] = { 4,3,5,3,2,9,9,10,7,3,5,3,4,9,9 };
+  static int iLineNs[] = { 0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,2,2,2,2 };
+  static int iCols[] = { 0,10,16,24,30,37,49,61,0,10,16,24,30,37,49,61,0,10,20,30 };
+  static int iLens[] = { 4,3,5,3,2,9,9,10,7,3,5,3,4,9,9,10,7,8,8,8 };
+  static int ibLens[] = { 4,3,5,3,2,9,9,10,7,3,5,3,4,9,9,10,7,8,8,8 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt = {
-    12, 0, 80, NULL, 1, header, 2, items, 15, iLineNs, iCols, iLens, 3, 1,
-    trailer, exitChars, REFRESHkey_FSI, FALSE
+    12, 0, 80, NULL, 1, header, 3, items, 20, iLineNs, iCols, iLens, ibLens, 3,
+    1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
   char selectedEncoding[10+1], delim = ' ', *selected = NULL, *tmpStr;
 
@@ -539,7 +551,7 @@ Logical SelectEncoding () {
   status = CDFlib (GET_, CDF_ENCODING_, &encoding,
 		   NULL_);
   if (!ReportStatus(status,FALSE)) return FALSE;
-  for (itemN = 0; itemN < 15; itemN++) {
+  for (itemN = 0; itemN < 20; itemN++) {
      if (!strncmp(EncodingToken(encoding),
 		  &(IWt.iLines[IWt.iLineNs[itemN]][IWt.iCols[itemN]]),
 		  IWt.iLens[itemN])) break;
@@ -576,9 +588,9 @@ Logical SelectEncoding () {
 * SelectSparseness.
 ******************************************************************************/
 
-Logical SelectSparseness (zVar, changed)
-Logical zVar;
-Logical *changed;	/* Assumed initialized to FALSE by caller. */
+Logical SelectSparseness (
+Logical zVar,
+Logical *changed)	/* Assumed initialized to FALSE by caller. */
 {
   long sRecordsType; CDFstatus status; static Logical first = TRUE;
   static char *header[] = { "Select sparseness..." };
@@ -589,10 +601,11 @@ Logical *changed;	/* Assumed initialized to FALSE by caller. */
   static int iLineNs[] = { 0,0,0 };
   static int iCols[] = { 0,16,33 };
   static int iLens[] = { 11,12,13 };
+  static int ibLens[] = { 11,12,13 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt = {
-    14, 0, 80, NULL, 1, header, 1, items, 3, iLineNs, iCols, iLens, 1, 1,
-    trailer, exitChars, REFRESHkey_FSI, TRUE
+    14, 0, 80, NULL, 1, header, 1, items, 3, iLineNs, iCols, iLens, ibLens, 1,
+    1, trailer, exitChars, REFRESHkey_FSI, TRUE
   };
   static long sRecordsTypes[] = {
     NO_SPARSERECORDS, PAD_SPARSERECORDS, PREV_SPARSERECORDS
@@ -629,12 +642,12 @@ Logical *changed;	/* Assumed initialized to FALSE by caller. */
 * SelectCompression.
 ******************************************************************************/
 
-Logical SelectCompression (forWhat, row, changed)
-int forWhat;
-int row;
-Logical *changed;	/* Assumed initialized to FALSE by caller. */
+Logical SelectCompression (
+int forWhat,
+int row,
+Logical *changed)	/* Assumed initialized to FALSE by caller. */
 {
-  long cType, cParms[CDF_MAX_PARMS], compressionItem;
+  long cType = 0, cParms[CDF_MAX_PARMS], compressionItem = 0;
   CDFstatus status; static Logical first = TRUE;
   static char *header[] = { "Select compression..." };
   AOSs1 (trailer, "Select: ________   Exit: ________   Help: ________")
@@ -644,10 +657,11 @@ Logical *changed;	/* Assumed initialized to FALSE by caller. */
   static int iLineNs[] = { 0,0,0,0,0 };
   static int iCols[] = { 0,9,19,30,42 };
   static int iLens[] = { 4,5,6,7,7 };
+  static int ibLens[] = { 4,5,6,7,7 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IW = {
     0, 0, 80, NULL, 1, header, 1, items, nCOMPRESSIONs, iLineNs, iCols,
-    iLens, 1, 1, trailer, exitChars, REFRESHkey_FSI, TRUE
+    iLens, ibLens, 1, 1, trailer, exitChars, REFRESHkey_FSI, TRUE
   };
   if (first) {
     EncodeKeyDefinitions (1, trailer, ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI);
@@ -693,7 +707,7 @@ Logical *changed;	/* Assumed initialized to FALSE by caller. */
 	   };
 	   static struct PromptWindowStruct PW = {
 	     "Enter GZIP compression parameters...", 0, 0, 80, 1, gzipHeader,
-	     MAX_GZIP_TOKEN_LEN, token, 1, gzipTrailer, gzipExit,
+	     MAX_GZIP_TOKEN_LEN+1, token, 1, gzipTrailer, gzipExit,
 	     REFRESHkey_FSI, SOLkey_FSI, EOLkey_FSI, INSERTorOVERkey_FSI
 	   };
 	   if (gzipFirst) {
@@ -761,10 +775,10 @@ Logical *changed;	/* Assumed initialized to FALSE by caller. */
 * SelectDataSpec.
 ******************************************************************************/
 
-Logical SelectDataSpec (dataType, numElems, label)
-long *dataType;         /* If NO_DATATYPE, start at item number 0. */
-long *numElems;         /* If NULL, don't prompt for number of elements. */
-char *label;            /* If NULL, no label. */
+Logical SelectDataSpec (
+long *dataType,         /* If NO_DATATYPE, start at item number 0. */
+long *numElems,         /* If NULL, don't prompt for number of elements. */
+char *label)            /* If NULL, no label. */
 {
   static char *header[] = { "Select data type..." };
   static char *items[] = { DTiwSYMBOLS };
@@ -772,10 +786,11 @@ char *label;            /* If NULL, no label. */
   static int iLineNs[] = { DTiwLINEnS };
   static int iCols[] = { DTiwCOLs };
   static int iLens[] = { DTiwLENs };
+  static int ibLens[] = { DTiwLENs };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt = {
-    4, 1, 78, NULL, 1, header, 3, items, 17, iLineNs, iCols, iLens, 3, 1,
-    trailer, exitChars, REFRESHkey_FSI, FALSE
+    4, 1, 78, NULL, 1, header, 3, items, 17, iLineNs, iCols, iLens, ibLens, 3,
+    1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
   static Logical first = TRUE; int itemN;
   char selectedDataType[15+1], delim = ' ', *selected = NULL, *tmpStr;
@@ -811,22 +826,24 @@ char *label;            /* If NULL, no label. */
 * SelectNumElems.
 ******************************************************************************/
 
-Logical SelectNumElems (dataType, numElems, label)
-long dataType;
-long *numElems;
-char *label;
+Logical SelectNumElems (
+long dataType,
+long *numElems,
+char *label)
 {
   static char *headerCHAR[] = {
-    "Enter number of elements (characters) for CDF_CHAR data type..."
+    "Enter number of elements (bytes not characters) for CDF_CHAR data type...",
+    "Note: Each UTF-8 encoding character could be a multi-byte character." 
   };
   static char *headerUCHAR[] = {
-    "Enter number of elements (characters) for CDF_UCHAR data type..."
+    "Enter number of elements (bytes not characters) for CDF_UCHAR data type...",
+    "Note: Each UTF-8 encoding character could be a multi-byte character."
   };
   AOSs1 (trailer, "Enter: ________    Exit: ________    Help: ________")
   static char value[MAX_NUMELEMS_LEN+1];
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct PromptWindowStruct PWt = {
-    NULL, 4, 1, 78, 1, NULL, MAX_NUMELEMS_LEN, value, 1, trailer, exitChars,
+    NULL, 4, 1, 78, 2, NULL, MAX_NUMELEMS_LEN, value, 1, trailer, exitChars,
     REFRESHkey_FSI, SOLkey_FSI, EOLkey_FSI, INSERTorOVERkey_FSI
   };
   static Logical first = TRUE; long tNumElems;
@@ -864,7 +881,8 @@ char *label;
 * SelectChecksum.
 ******************************************************************************/
 
-Logical SelectChecksum () {
+Logical SelectChecksum (void) 
+{
   long checksum; int itemN; CDFstatus status;
   static char *header[] = { "Select new checksum method..." };
   AOSs1 (trailer, "Select: ________   Exit: ________   Help:   ________")
@@ -872,10 +890,11 @@ Logical SelectChecksum () {
   static int iLineNs[] = { 0, 1 };
   static int iCols[] = { 0, 0 };
   static int iLens[] = { 4, 3 };
+  static int ibLens[] = { 4, 3 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt = {
-    12, 0, 80, NULL, 1, header, 2, items, 2, iLineNs, iCols, iLens, 3, 1,
-    trailer, exitChars, REFRESHkey_FSI, FALSE
+    12, 0, 80, NULL, 1, header, 2, items, 2, iLineNs, iCols, iLens, ibLens, 3,
+    1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
   EncodeKeyDefinitions (1, trailer, ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI);
   status = CDFlib (GET_, CDF_CHECKSUM_, &checksum,
