@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2014 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                            Calculate statistics.
 *
@@ -27,20 +32,22 @@
 * CALCstat.  Reads each record of a variable and calculates the statistics.
 ******************************************************************************/
 
-Logical CALCstat (Var)
-struct VarStruct *Var;
+Logical CALCstat (
+struct VarStructST *Var,
+int virtual)
 {
   CDFstatus status;
   long attrN;
   long varyCount;
-  int dimN;
+  int dimN, extra;
   long dimSizes[CDF_MAX_DIMS];
   size_t nValueBytes[1];
-  Byte **handles[1];
+  Byte1 **handles[1];
   long nHypers, hyperN;
   long nValues, valueN;
   struct GroupStruct groups;
-  struct HyperStruct hyper;
+  struct HyperStruct hyperSt;
+
   /****************************************************************************
   * Initialize for this variable.
   ****************************************************************************/
@@ -64,6 +71,9 @@ struct VarStruct *Var;
   else
     Var->checkMonotonicVar = FALSE;
   Var->nValueBytes = Var->numElemsV * CDFelemSize(Var->dataTypeV);
+  if (epochMonotonic) {
+    if (!virtual && !CDFepochDataType(Var->dataTypeV)) return TRUE;
+  }
   /****************************************************************************
   * Allocate memory.
   ****************************************************************************/
@@ -72,16 +82,18 @@ struct VarStruct *Var;
   AllocateBuffers (Var->varMaxRec + 1, Var->numDims, dimSizes, &groups, 0, 1,
 		   handles, nValueBytes, ROWmajor(majority), MINnHYPERS,
 		   FatalError);
-  Var->min = cdf_AllocateMemory ((size_t) Var->nValueBytes,
+  if (STRINGdataType(Var->dataTypeV)) extra = 1;
+  else extra = 0;
+  Var->min = cdf_AllocateMemory ((size_t) Var->nValueBytes+extra,
 			     FatalError);
-  Var->max = cdf_AllocateMemory ((size_t) Var->nValueBytes,
+  Var->max = cdf_AllocateMemory ((size_t) Var->nValueBytes+extra,
 			     FatalError);
-  Var->last = cdf_AllocateMemory ((size_t) Var->nValueBytes,
+  Var->last = cdf_AllocateMemory ((size_t) Var->nValueBytes+extra,
 			      FatalError);
   if (Var->rangeCheckVar) {
-    Var->minINrange = cdf_AllocateMemory ((size_t) Var->nValueBytes,
+    Var->minINrange = cdf_AllocateMemory ((size_t) Var->nValueBytes+extra,
 				      FatalError);
-    Var->maxINrange = cdf_AllocateMemory ((size_t) Var->nValueBytes,
+    Var->maxINrange = cdf_AllocateMemory ((size_t) Var->nValueBytes+extra,
 				      FatalError);
   }
   /****************************************************************************
@@ -90,42 +102,45 @@ struct VarStruct *Var;
   status = CDFlib (SELECT_, VAR(Var->Z), Var->varN,
 		   NULL_);
   if (!StatusHandlerStats(status)) return FALSE;
-  InitHyperParms (&hyper, &groups, Var->numDims, &nHypers, &nValues);
+  InitHyperParms (&hyperSt, &groups, Var->numDims, &nHypers, &nValues);
   for (hyperN = 0; hyperN < nHypers; hyperN++) {
      status = CDFlib (SELECT_, BOO(Var->Z,zVAR_RECNUMBER_,
-					  rVARs_RECNUMBER_), hyper.recNumber,
+					  rVARs_RECNUMBER_), hyperSt.recNumber,
 			       BOO(Var->Z,zVAR_RECCOUNT_,
-					  rVARs_RECCOUNT_), hyper.recCount,
-			       BOO(Var->Z,
-				   zVAR_RECINTERVAL_,
-				   rVARs_RECINTERVAL_), hyper.recInterval,
+					  rVARs_RECCOUNT_), hyperSt.recCount,
+			       BOO(Var->Z, zVAR_RECINTERVAL_,
+					   rVARs_RECINTERVAL_),
+			      				 hyperSt.recInterval,
 			       BOO(Var->Z,zVAR_DIMINDICES_,
-					  rVARs_DIMINDICES_), hyper.dimIndices,
+					  rVARs_DIMINDICES_),
+			      				 hyperSt.dimIndices,
 			       BOO(Var->Z,zVAR_DIMCOUNTS_,
-					  rVARs_DIMCOUNTS_), hyper.dimCounts,
-			       BOO(Var->Z,
-				   zVAR_DIMINTERVALS_,
-				   rVARs_DIMINTERVALS_), hyper.dimIntervals,
+					  rVARs_DIMCOUNTS_), hyperSt.dimCounts,
+			       BOO(Var->Z, zVAR_DIMINTERVALS_,
+					   rVARs_DIMINTERVALS_),
+			      				 hyperSt.dimIntervals,
 		      GET_, BOO(Var->Z,zVAR_HYPERDATA_,
 				       rVAR_HYPERDATA_), Var->buffer,
 		      NULL_);
      if (!StatusHandlerStats(status)) return FALSE;
      for (valueN = 0, Var->value = Var->buffer; valueN < nValues;
 	  valueN++, Var->value += (size_t) Var->nValueBytes) {
-	if (Var->minmaxInited)
-	  MinMaxCheck (Var);
-	else
-	  MinMaxInit (Var);
+	if (!epochMonotonic) {
+	  if (Var->minmaxInited)
+	    MinMaxCheck (Var);
+	  else
+	    MinMaxInit (Var);
+	}
 	if (Var->checkMonotonicVar) Monotonic (Var);
      }
-     IncrHyperParms (&hyper, &groups, Var->numDims, ROWmajor(majority),
+     IncrHyperParms (&hyperSt, &groups, Var->numDims, ROWmajor(majority),
 		     &nValues);
      CHECKforABORTso
   }
   /****************************************************************************
   * Display statistics.
   ****************************************************************************/
-  DISPstat (Var);
+  DISPstat (Var, virtual);
   /****************************************************************************
   * Update attribute(s) if requested.  (NOTE: macros/functions could be used).
   ****************************************************************************/
@@ -246,8 +261,8 @@ struct VarStruct *Var;
 * MinMaxInit.
 ******************************************************************************/
 
-void MinMaxInit (Var)
-struct VarStruct *Var;
+void MinMaxInit (
+struct VarStructST *Var)
 {
   Logical use;
   if (Var->ignoreFillsVar)
@@ -261,28 +276,37 @@ struct VarStruct *Var;
     use = TRUE;
   if (use) {
     ASSIGNx (Var->min, Var->value, Var->dataTypeV, Var->numElemsV);
+    if (STRINGdataType(Var->dataTypeV))
+      *(((char *)Var->min)+(int)Var->numElemsV) = '\0';
     ASSIGNx (Var->max, Var->value, Var->dataTypeV, Var->numElemsV);
+    if (STRINGdataType(Var->dataTypeV))
+      *(((char *)Var->max)+(int)Var->numElemsV) = '\0';
     if (Var->rangeCheckVar) {
       if (LTx(Var->value,Var->validmin,Var->dataTypeV,Var->numElemsV))
         Var->low++;
-      else
+      else {
         if (GTx(Var->value,Var->validmax,Var->dataTypeV,Var->numElemsV))
 	  Var->high++;
         else {
 	  Var->oneINrange = TRUE;
 	  ASSIGNx (Var->minINrange, Var->value, Var->dataTypeV,
 		   Var->numElemsV);
+	  if (STRINGdataType(Var->dataTypeV))
+	    *(((char *)Var->minINrange)+(int)Var->numElemsV) = '\0';
 	  ASSIGNx (Var->maxINrange, Var->value, Var->dataTypeV,
 		   Var->numElemsV);
+	  if (STRINGdataType(Var->dataTypeV))
+	    *(((char *)Var->maxINrange)+(int)Var->numElemsV) = '\0';
         }
+      }
     }
     Var->minmaxInited = TRUE;
   }
   return;
 }
 
-void MinMaxCheck (Var)
-struct VarStruct *Var;
+void MinMaxCheck (
+struct VarStructST *Var)
 {
   Logical use;
   if (Var->ignoreFillsVar)
@@ -295,38 +319,52 @@ struct VarStruct *Var;
   else
     use = TRUE;
   if (use) {
-    if (LTx(Var->value,Var->min,Var->dataTypeV,Var->numElemsV))
+    if (LTx(Var->value,Var->min,Var->dataTypeV,Var->numElemsV)) {
       ASSIGNx (Var->min, Var->value, Var->dataTypeV, Var->numElemsV);
-    else {
+      if (STRINGdataType(Var->dataTypeV))
+        *(((char *)Var->min)+(int)Var->numElemsV) = '\0'; 
+    } else {
       if (GTx(Var->value,Var->max,Var->dataTypeV,Var->numElemsV)) {
         ASSIGNx (Var->max, Var->value, Var->dataTypeV, Var->numElemsV);
+        if (STRINGdataType(Var->dataTypeV))
+          *(((char *)Var->max)+(int)Var->numElemsV) = '\0'; 
       }
     }
     if (Var->rangeCheckVar) {
       if (LTx(Var->value,Var->validmin,Var->dataTypeV,Var->numElemsV))
         Var->low++;
-      else
+      else {
         if (GTx(Var->value,Var->validmax,Var->dataTypeV,Var->numElemsV))
 	  Var->high++;
         else
 	  if (Var->oneINrange) {
-	    if (LTx(Var->value,Var->minINrange,Var->dataTypeV,Var->numElemsV))
+	    if (LTx(Var->value,Var->minINrange,Var->dataTypeV,Var->numElemsV)) {
 	      ASSIGNx (Var->minINrange, Var->value, Var->dataTypeV,
 		       Var->numElemsV);
-	    else
+              if (STRINGdataType(Var->dataTypeV))
+	        *(((char *)Var->minINrange)+(int)Var->numElemsV) = '\0'; 
+	    } else {
 	      if (GTx(Var->value,Var->maxINrange,
 		      Var->dataTypeV,Var->numElemsV)) {
 	        ASSIGNx (Var->maxINrange, Var->value, Var->dataTypeV,
 		         Var->numElemsV);
+                if (STRINGdataType(Var->dataTypeV))
+	          *(((char *)Var->maxINrange)+(int)Var->numElemsV) = '\0'; 
 	      }
+	    }
 	  }
 	  else {
 	    Var->oneINrange = TRUE;
 	    ASSIGNx (Var->minINrange, Var->value, Var->dataTypeV,
 		     Var->numElemsV);
+            if (STRINGdataType(Var->dataTypeV))
+	      *(((char *)Var->minINrange)+(int)Var->numElemsV) = '\0'; 
 	    ASSIGNx (Var->maxINrange, Var->value, Var->dataTypeV,
 		     Var->numElemsV);
+            if (STRINGdataType(Var->dataTypeV))
+	      *(((char *)Var->maxINrange)+(int)Var->numElemsV) = '\0'; 
 	  }
+      }
     }
   }
   return;
@@ -336,10 +374,11 @@ struct VarStruct *Var;
 * Monotonic.
 ******************************************************************************/
 
-void Monotonic (Var)
-struct VarStruct *Var;
+void Monotonic (
+struct VarStructST *Var)
 {
   Logical use;
+
   if (Var->ignoreFillsVar)
     if (NEx(Var->value,Var->fillval,Var->dataTypeV,Var->numElemsV))
       use = TRUE;
@@ -350,6 +389,8 @@ struct VarStruct *Var;
   if (use) {
     if (!Var->monoInited) {
       ASSIGNx (Var->last, Var->value, Var->dataTypeV, Var->numElemsV);
+      if (STRINGdataType(Var->dataTypeV))
+        *(((char *)Var->last)+(int)Var->numElemsV) = '\0'; 
       Var->monoState = _Init;
       Var->monoInited = TRUE;
     }
@@ -419,3 +460,127 @@ struct VarStruct *Var;
   }
   return;
 }
+
+/******************************************************************************
+* HandleVirtual.
+******************************************************************************/
+
+Logical HandleVirtual (
+CDFid id,
+struct VarStructST *Var)
+{
+  CDFstatus status;
+  struct VarStructST VirtualVar;
+  long numElemsE;                 /* number of elements for attribute entry */
+
+  /****************************************************************************
+  * Initialize pointers for memory to be allocated.
+  ****************************************************************************/
+  VirtualVar.buffer = NULL;
+  /****************************************************************************
+  * Find out the real variable has the epoch time values. 
+  ****************************************************************************/
+  status = CDFlib (SELECT_, ATTR_NAME_, "COMPONENT_0",
+			    BOO(Var->Z,zENTRY_,rENTRY_), Var->varN,
+		   GET_, BOO(Var->Z,zENTRY_NUMELEMS_,
+				    rENTRY_NUMELEMS_), &numElemsE,
+		         BOO(Var->Z,zENTRY_DATA_,
+				    rENTRY_DATA_), VirtualVar.varName,
+		   NULL_);
+  if (status == NO_SUCH_ENTRY) return TRUE;
+  VirtualVar.varName[(int)numElemsE] = '\0';
+  status = CDFlib (GET_, BOO(Var->Z,zVAR_NUMBER_,
+				    rVAR_NUMBER_), VirtualVar.varName,
+						   &VirtualVar.varN,
+		   NULL_);
+  if (status != CDF_OK) return FALSE;
+  status = CDFlib (SELECT_, BOO(Var->Z,zVAR_,rVAR_), VirtualVar.varN,
+		   GET_, BOO(Var->Z,zVAR_MAXREC_,
+				    rVAR_MAXREC_), &VirtualVar.varMaxRec,
+		   NULL_);
+  if (status != CDF_OK) return FALSE;
+  if (VirtualVar.varMaxRec <= 0) {
+    status = CDFlib (SELECT_, ATTR_NAME_, "COMPONENT_1",
+			      BOO(Var->Z,zENTRY_,rENTRY_), Var->varN,
+		     GET_, BOO(Var->Z,zENTRY_NUMELEMS_,
+				      rENTRY_NUMELEMS_), &numElemsE,
+		           BOO(Var->Z,zENTRY_DATA_,
+				      rENTRY_DATA_), VirtualVar.varName,
+		     NULL_);
+    if (status != CDF_OK) return FALSE;
+    VirtualVar.varName[(int)numElemsE] = '\0';
+    status = CDFlib (GET_, BOO(Var->Z,zVAR_NUMBER_,
+				      rVAR_NUMBER_), VirtualVar.varName,
+						     &VirtualVar.varN,
+		     NULL_);
+    if (status != CDF_OK) return FALSE;
+    status = CDFlib (SELECT_, BOO(Var->Z,zVAR_,rVAR_), VirtualVar.varN,
+		     GET_, BOO(Var->Z,zVAR_MAXREC_,
+				      rVAR_MAXREC_), &VirtualVar.varMaxRec,
+		     NULL_);
+    if (status != CDF_OK) return FALSE;
+  }
+  VirtualVar.validmin = NULL;
+  VirtualVar.validmax = NULL;
+  VirtualVar.fillval = NULL;
+  VirtualVar.format = NULL;
+  VirtualVar.min = NULL;
+  VirtualVar.max = NULL;
+  VirtualVar.last = NULL;
+  VirtualVar.minINrange = NULL;
+  VirtualVar.maxINrange = NULL;
+  VirtualVar.buffer = NULL;
+  VirtualVar.Z = Var->Z;
+  status = CDFlib (GET_, BOO(Var->Z,zVAR_NUMBER_,
+				    rVAR_NUMBER_), VirtualVar.varName,
+						   &VirtualVar.varN,
+		   NULL_);
+  if (status != CDF_OK) return FALSE;
+  status = CDFlib (SELECT_, BOO(Var->Z,zVAR_,rVAR_), VirtualVar.varN,
+		   GET_, BOO(Var->Z,zVAR_DATATYPE_,
+				    rVAR_DATATYPE_), &VirtualVar.dataTypeV,
+		         BOO(Var->Z,zVAR_NUMELEMS_,
+				    rVAR_NUMELEMS_), &VirtualVar.numElemsV,
+		         BOO(Var->Z,zVAR_NUMDIMS_,
+				    rVARs_NUMDIMS_), &VirtualVar.numDims,
+		         BOO(Var->Z,zVAR_DIMSIZES_,
+				    rVARs_DIMSIZES_), VirtualVar.dimSizes,
+		         BOO(Var->Z,zVAR_RECVARY_,
+				    rVAR_RECVARY_), &VirtualVar.recVary,
+		         BOO(Var->Z,zVAR_DIMVARYS_,
+				    rVAR_DIMVARYS_), VirtualVar.dimVarys,
+		         BOO(Var->Z,zVAR_MAXREC_,
+				    rVAR_MAXREC_), &VirtualVar.varMaxRec,
+		   NULL_);
+  if (status != CDF_OK) return FALSE;
+  /****************************************************************************
+  * If fill values are to be ignored, get the fill value.
+  ****************************************************************************/
+  if (ignoreFills) {
+    long dataTypeE, numElemsE;
+    status = GetFILLVALEntry (id, Var->Z, VirtualVar.varN,  &dataTypeE,
+			      &numElemsE, &(VirtualVar.fillval));
+    if (status != CDF_OK) {
+      if (status == BAD_DATA_TYPE) {
+	if (VirtualVar.fillval != NULL) {
+          cdf_FreeMemory (VirtualVar.fillval, FatalError);
+          VirtualVar.fillval = NULL;
+        }
+      }
+      VirtualVar.ignoreFillsVar = FALSE;
+    } else
+      VirtualVar.ignoreFillsVar = TRUE;
+  }
+  else
+    VirtualVar.ignoreFillsVar = FALSE;
+  /****************************************************************************
+  * Read each record and calculate statistics.
+  ****************************************************************************/
+  if (!CALCstat(&VirtualVar, TRUE)) return FALSE;
+  FreeVarMem(&VirtualVar);
+  /****************************************************************************
+  * Return - note that memory allocated will be freed by caller.
+  ****************************************************************************/
+  return TRUE;
+}
+
