@@ -31,9 +31,9 @@
 * DISPstat.
 ******************************************************************************/
 
-void DISPstat (Var, virtual)
-struct VarStructST *Var;
-int virtual;
+void DISPstat (
+struct VarStructST *Var,
+int virtual)
 {
   char line[MAX_SCREENLINE_LEN+1];
 
@@ -48,35 +48,37 @@ int virtual;
     if (Var->monoInited)
       switch (Var->monoState) {
         case _Init:
-          strcatX (line, "Steady (one value)", MAX_SCREENLINE_LEN);
+          strcatX (line, "Steady (one value)", 18, strlen(line),
+		   MAX_SCREENLINE_LEN);
           break;
         case _Steady:
-          strcatX (line, "Steady (all values the same)", MAX_SCREENLINE_LEN);
+          strcatX (line, "Steady (all values the same)", 28, strlen(line),
+		   MAX_SCREENLINE_LEN);
           break;
         case _Increase:
-          strcatX (line, "Increase", MAX_SCREENLINE_LEN);
+          strcatX (line, "Increase", 8, strlen(line), MAX_SCREENLINE_LEN);
           break;
         case _Decrease:
-          strcatX (line, "Decrease", MAX_SCREENLINE_LEN);
+          strcatX (line, "Decrease", 8, strlen(line), MAX_SCREENLINE_LEN);
           break;
         case _noIncrease:
-          strcatX (line, "noIncrease (some values the same)",
+          strcatX (line, "noIncrease (some values the same)", 33, strlen(line),
 		   MAX_SCREENLINE_LEN);
           break;
         case _noDecrease:
-          strcatX (line, "noDecrease (some values the same)",
+          strcatX (line, "noDecrease (some values the same)", 33, strlen(line),
 		   MAX_SCREENLINE_LEN);
           break;
         case _False:
-          strcatX (line, "False", MAX_SCREENLINE_LEN);
+          strcatX (line, "False", 5, strlen(line), MAX_SCREENLINE_LEN);
           break;
       }
     else
       strcatX (line, (virtual==1?"n/a (0 or 1 record)":"n/a (all fill values)"),
-	       MAX_SCREENLINE_LEN);
+	       (virtual==1?19:21), strlen(line), MAX_SCREENLINE_LEN);
   else
-    strcatX (line, "n/a", MAX_SCREENLINE_LEN);
-  strcatX (line, "\n\n", MAX_SCREENLINE_LEN);
+    strcatX (line, "n/a", 3, strlen(line), MAX_SCREENLINE_LEN);
+  strcatX (line, "\n\n", 2, strlen(line), MAX_SCREENLINE_LEN);
   WriteOut (OUTfp, line);
 
   return;
@@ -86,8 +88,8 @@ int virtual;
 * DisplayMin.
 ******************************************************************************/
 
-void DisplayMin (Var)
-struct VarStructST *Var;
+void DisplayMin (
+struct VarStructST *Var)
 { 
   char line[MAX_SCREENLINE_LEN+1];
   int style;
@@ -129,7 +131,7 @@ struct VarStructST *Var;
       if (!isnan(*(double *)Var->min) &&
           *(double *)Var->min <= DEFAULT_EPOCH_PADVALUE) {
         EncodeValuesFormat (Var->dataTypeV, Var->numElemsV, Var->min,
-		            &line[strlen(line)], Var->format, 0, /* or NULL, 0 */
+		            &line[strlen(line)], Var->format, 0, /*or NULL,0, */
 		            MAX_SCREENLINE_LEN - strlen(line), style,
 		    	    (size_t) sizeof(line)-strlen(line));
       } else
@@ -143,7 +145,7 @@ struct VarStructST *Var;
           *(double *)Var->min <= DEFAULT_EPOCH16_PADVALUE &&
           *(((double *)Var->min)+1) <= DEFAULT_EPOCH16_PADVALUE) {
         EncodeValuesFormat (Var->dataTypeV, Var->numElemsV, Var->min,
-		            &line[strlen(line)], Var->format, 0, /* or NULL, 0 */
+		            &line[strlen(line)], Var->format, 0, /*or NULL,0, */
 		            MAX_SCREENLINE_LEN - strlen(line), style,
 		    	    (size_t) sizeof(line)-strlen(line));
       } else
@@ -151,14 +153,15 @@ struct VarStructST *Var;
                             &line[strlen(line)], Var->format, 0,
                             MAX_SCREENLINE_LEN - strlen(line), style,
                             (size_t) sizeof(line)-strlen(line));
-    } else 
+    } else
       EncodeValuesFormat (Var->dataTypeV, Var->numElemsV, Var->min,
 		          &line[strlen(line)], Var->format, -1,
 		          MAX_SCREENLINE_LEN - strlen(line), style,
 		    	  (size_t) sizeof(line)-strlen(line));
   } else
-    strcatX (line, "n/a (all fill values)", MAX_SCREENLINE_LEN);
-  strcatX (line, "\n", MAX_SCREENLINE_LEN);
+    strcatX (line, "n/a (all fill values)", 21, strlen(line), 
+	     MAX_SCREENLINE_LEN);
+  strcatX (line, "\n", 1, strlen(line), MAX_SCREENLINE_LEN);
   WriteOut (OUTfp, line);
 
   if (Var->rangeCheckVar) {
@@ -221,10 +224,11 @@ struct VarStructST *Var;
 			      MAX_SCREENLINE_LEN - strlen(line), style,
 			      (size_t) sizeof(line)-strlen(line));
       } else
-        strcatX (line, "(none)", MAX_SCREENLINE_LEN);
+        strcatX (line, "(none)", 6, strlen(line), MAX_SCREENLINE_LEN);
     else
-      strcatX (line, "n/a (all fill values)", MAX_SCREENLINE_LEN);
-    strcatX (line, "\n", MAX_SCREENLINE_LEN);
+      strcatX (line, "n/a (all fill values)", 21, strlen(line),
+	       MAX_SCREENLINE_LEN);
+    strcatX (line, "\n", 1, strlen(line), MAX_SCREENLINE_LEN);
     WriteOut (OUTfp, line);
 
     strcpyX (line, "       valid min: ", MAX_SCREENLINE_LEN);
@@ -286,7 +290,7 @@ struct VarStructST *Var;
     if (Var->minmaxInited) 
       snprintf (&line[strlen(line)], (size_t) sizeof(line)-strlen(line),
 	        ", %ld low value%s", Var->low, (Var->low <= 1 ? "" : "s"));
-    strcatX (line, "\n\n", MAX_SCREENLINE_LEN);
+    strcatX (line, "\n\n", 2, strlen(line), MAX_SCREENLINE_LEN);
     WriteOut (OUTfp, line);
   }
   return;
@@ -296,8 +300,8 @@ struct VarStructST *Var;
 * DisplayMax.
 ******************************************************************************/
 
-void DisplayMax (Var)
-struct VarStructST *Var;
+void DisplayMax (
+struct VarStructST *Var)
 { 
   char line[MAX_SCREENLINE_LEN+1];
   int style;
@@ -367,8 +371,9 @@ struct VarStructST *Var;
 		          MAX_SCREENLINE_LEN - strlen(line), style,
 			  (size_t) sizeof(line)-strlen(line));
   } else
-    strcatX (line, "n/a (all fill values)", MAX_SCREENLINE_LEN);
-  strcatX (line, "\n", MAX_SCREENLINE_LEN);
+    strcatX (line, "n/a (all fill values)", 21, strlen(line),
+	     MAX_SCREENLINE_LEN);
+  strcatX (line, "\n", 1, strlen(line), MAX_SCREENLINE_LEN);
   WriteOut (OUTfp, line);
 
   if (Var->rangeCheckVar) {
@@ -431,10 +436,11 @@ struct VarStructST *Var;
 			      MAX_SCREENLINE_LEN - strlen(line), style,
 			      (size_t) sizeof(line)-strlen(line));
       } else
-        strcatX (line, "(none)", MAX_SCREENLINE_LEN);
+        strcatX (line, "(none)", 6, strlen(line), MAX_SCREENLINE_LEN);
     else
-      strcatX (line, "n/a (all fill values)", MAX_SCREENLINE_LEN);
-    strcatX (line, "\n", MAX_SCREENLINE_LEN);
+      strcatX (line, "n/a (all fill values)", 21, strlen(line),
+	       MAX_SCREENLINE_LEN);
+    strcatX (line, "\n", 1, strlen(line), MAX_SCREENLINE_LEN);
     WriteOut (OUTfp, line);
 
     strcpyX (line, "       valid max: ", MAX_SCREENLINE_LEN);
@@ -496,7 +502,7 @@ struct VarStructST *Var;
     if (Var->minmaxInited) 
       snprintf (&line[strlen(line)], (size_t) sizeof(line)-strlen(line),
 	        ", %ld high value%s", Var->high, (Var->high <= 1 ? "" : "s"));
-    strcatX (line, "\n\n", MAX_SCREENLINE_LEN);
+    strcatX (line, "\n\n", 2, strlen(line), MAX_SCREENLINE_LEN);
     WriteOut (OUTfp, line);
   }
   return;
@@ -506,8 +512,8 @@ struct VarStructST *Var;
 * DisplayFill.
 ******************************************************************************/
 
-void DisplayFill (Var)
-struct VarStructST *Var;
+void DisplayFill (
+struct VarStructST *Var)
 {
   char line[MAX_SCREENLINE_LEN+1];
   int style;
@@ -578,7 +584,7 @@ struct VarStructST *Var;
 		  	  (size_t) sizeof(line)-strlen(line));
     snprintf (&line[strlen(line)], (size_t) sizeof(line)-strlen(line),
 	      ", %ld fill value%s", Var->fills, (Var->fills <= 1 ? "" : "s"));
-    strcatX (line, "\n\n", MAX_SCREENLINE_LEN);
+    strcatX (line, "\n\n", 2, strlen(line), MAX_SCREENLINE_LEN);
     WriteOut (OUTfp, line);
   }
   return;
