@@ -82,9 +82,9 @@ MAIN {
 * CalculateStatistics.
 ******************************************************************************/
 
-Logical CalculateStatistics (argC, argV)
-int argC;
-char *argV[];
+Logical CalculateStatistics (
+int argC,
+char *argV[])
 {
   CDFstatus status; CDFid id;
   char oSpec[DU_MAX_PATH_LEN+1], oDir[DU_MAX_DIR_LEN+1];
@@ -284,7 +284,8 @@ char *argV[];
     OUTfp = stdout;
   else {
     ParsePath (oSpec, oDir, oName);
-    if (strchr(oName,'.') == NULL) strcatX (oSpec, ".sts", DU_MAX_PATH_LEN);
+    if (strchr(oName,'.') == NULL)
+      strcatX (oSpec, ".sts", 4, strlen(oSpec), DU_MAX_PATH_LEN);
     OUTfp = fopen (oSpec, "w");
     if (OUTfp == NULL) {
       DisplayError ("Unable to open output file.");
@@ -304,9 +305,10 @@ char *argV[];
   }
   WriteOut (OUTfp, CDFname);
   if (!NULstring(oSpec)) WriteOut (stdout, CDFname);
-  if (!EndsWithIgCase(CDFname, ".cdf"))
+  if (!EndsWithIgCase(CDFname, ".cdf")) {
     WriteOut (OUTfp, ".cdf");
     if (!NULstring(oSpec)) WriteOut (stdout, ".cdf");
+  }
   if (!NULstring(oSpec)) {
     WriteOut (stdout, "\"  to  \"");
     WriteOut (stdout, oSpec);
@@ -440,9 +442,9 @@ char *argV[];
 * SetupVar.
 ******************************************************************************/
 
-Logical SetupVar (id, Var)
-CDFid id;
-struct VarStructST *Var;
+Logical SetupVar (
+CDFid id,
+struct VarStructST *Var)
 {
   CDFstatus status;
   char line[MAX_SCREENLINE_LEN_stats+1];
@@ -485,7 +487,7 @@ struct VarStructST *Var;
   strcpyX (line, "\n", MAX_SCREENLINE_LEN_stats);
   delim = PickDelimiter (Var->varName, strlen(Var->varName));
   snprintf (EofS(line), (size_t) sizeof(line)-strlen(line),
-  	    "%3ld.  %c%s%c", Var->varN + 1, delim, Var->varName, delim);
+  	    "%3ld.  %c%.*s%c", Var->varN + 1, delim, 230, Var->varName, delim);
   snprintf (EofS(line), (size_t) sizeof(line)-strlen(line),
   	    "%s", (virtual==1?" (V)":" "));
   if (Var->Z) {
@@ -493,12 +495,13 @@ struct VarStructST *Var;
 	      "   %ld:[", Var->numDims);
     if (Var->numDims > 0) {
       for (dimN = 0; dimN < Var->numDims; dimN++) {
-    	 if (dimN > 0) strcatX (line, ",", MAX_SCREENLINE_LEN_stats);
+    	 if (dimN > 0)
+	   strcatX (line, ",", 1, strlen(line), MAX_SCREENLINE_LEN_stats);
 	 snprintf (EofS(line), (size_t) sizeof(line)-strlen(line),
 		   "%ld", Var->dimSizes[dimN]);
       }
     }
-    strcatX (line, "]", MAX_SCREENLINE_LEN_stats);
+    strcatX (line, "]", 1, strlen(line), MAX_SCREENLINE_LEN_stats);
   }
   snprintf (EofS(line), (size_t) sizeof(line)-strlen(line),
 	    "   %s/", TFvarianceToken(Var->recVary));
@@ -508,7 +511,8 @@ struct VarStructST *Var;
   }
   snprintf (EofS(line), (size_t) sizeof(line)-strlen(line),
 	    "   (CDF_%s/%ld)", DataTypeToken(Var->dataTypeV), Var->numElemsV);
-  strcatX (line, "\n\n", MAX_SCREENLINE_LEN_stats);
+  strcatX (line, "\n\n", 2, strlen(line),
+	   MAX_SCREENLINE_LEN_stats);
   WriteOut (OUTfp, line);
   /****************************************************************************
   * Return early if no records written.
@@ -620,35 +624,6 @@ struct VarStructST *Var;
       Var->ignoreFillsVar = FALSE;
     } else
       Var->ignoreFillsVar = TRUE;
-/*
-    status = CDFlib (SELECT_, ATTR_, fillvalAttrN,
-			      BOO(Var->Z,zENTRY_,rENTRY_), Var->varN,
-		     GET_, BOO(Var->Z,zENTRY_DATATYPE_,
-				      rENTRY_DATATYPE_), &dataTypeE,
-			   BOO(Var->Z,zENTRY_NUMELEMS_,
-				      rENTRY_NUMELEMS_), &numElemsE,
-		     NULL_);
-    if (status == NO_SUCH_ENTRY)
-      Var->ignoreFillsVar = FALSE;
-    else {
-      if (!StatusHandlerStats(status)) return FALSE;
-      temp = cdf_AllocateMemory ((size_t) (CDFelemSize(dataTypeE) * numElemsE),
-			     FatalError);
-      status = CDFlib (GET_, BOO(Var->Z,zENTRY_DATA_,rENTRY_DATA_), temp,
-		       NULL_);
-      if (!StatusHandlerStats(status)) {
-	cdf_FreeMemory (temp, FatalError);
-	return FALSE;
-      }
-      Var->fillval = cdf_AllocateMemory ((size_t) (CDFelemSize(Var->dataTypeV) *
-					       Var->numElemsV),
-				     FatalError);
-      ConvertDataType (dataTypeE, numElemsE, temp, Var->dataTypeV,
-		       Var->numElemsV, Var->fillval);
-      cdf_FreeMemory (temp, FatalError);
-      Var->ignoreFillsVar = TRUE;
-    }
-*/
   }
   else
     Var->ignoreFillsVar = FALSE;
@@ -690,8 +665,8 @@ struct VarStructST *Var;
 * FreeVarMem.
 ******************************************************************************/
 
-void FreeVarMem (Var)
-struct VarStructST *Var;
+void FreeVarMem (
+struct VarStructST *Var)
 {
   if (Var->validmin != NULL) cdf_FreeMemory (Var->validmin,
 					     FatalError);
@@ -714,8 +689,8 @@ struct VarStructST *Var;
 * StatusHandlerStats.
 ******************************************************************************/
 
-Logical StatusHandlerStats (status)
-CDFstatus status;
+Logical StatusHandlerStats (
+CDFstatus status)
 {
   char text[CDF_STATUSTEXT_LEN + 1];
 
@@ -763,9 +738,9 @@ CDFstatus status;
 ******************************************************************************/
 
 #if defined(mac)
-Logical StatisticsQOPs (argC, argV)
-int *argC;
-char **argV[];
+Logical StatisticsQOPs (
+int *argC,
+char **argV[])
 {
   DialogPtr dialogP;
   DialogRecord dRecord;
