@@ -51,9 +51,9 @@ static void SaveStatusLine PROTOARGs((char *text));
 * MacExecuteSO.
 ******************************************************************************/
 
-void MacExecuteSO (exeFnc, qopFnc)
-Logical (*exeFnc) PROTOARGs((int argC, char *argV[]));
-Logical (*qopFnc) PROTOARGs((int *argC, char **argV[]));
+void MacExecuteSO (
+Logical (*exeFnc) PROTOARGs((int argC, char *argV[])),
+Logical (*qopFnc) PROTOARGs((int *argC, char **argV[])))
 {
   int argC; char **argV; EventRecord event; WindowPtr whichWindow;
   InitMacUI ();
@@ -294,10 +294,10 @@ Logical (*qopFnc) PROTOARGs((int *argC, char **argV[]));
 * MacExecuteTimer.
 ******************************************************************************/
 
-void MacExecuteTimer (exeFnc, argC, argV)
-Logical (*exeFnc) PROTOARGs((int argC, char *argV[]));
-int argC;
-char *argV[];
+void MacExecuteTimer (
+Logical (*exeFnc) PROTOARGs((int argC, char *argV[])),
+int argC,
+char *argV[])
 {
   char text[SO_STATUS_LINE_LEN+1]; clock_t endClock, totalClock;
   int hour, minute, second, hundredths, i;
@@ -335,7 +335,8 @@ char *argV[];
 *   Initialize the Macintosh User Interface.
 ******************************************************************************/
 
-void InitMacUI () {
+void InitMacUI () 
+{
   InitGraf (&qd.thePort);
   InitFonts ();
   FlushEvents ((short) everyEvent, (short) 0);
@@ -382,7 +383,8 @@ void InitMacSO () {
 *   Initialize the Macintosh menus for the standard output window.
 ******************************************************************************/
 
-void InitMacMenusSO () {
+void InitMacMenusSO () 
+{
   appleMenuHso = GetMenu (APPLEri);
   AddResMenu (appleMenuHso, *((long *) "DRVR"));
   InsertMenu (appleMenuHso, 0);
@@ -399,8 +401,8 @@ void InitMacMenusSO () {
 * UpdateCursorSO.
 ******************************************************************************/
 
-static void UpdateCursorSO (event)
-EventRecord *event;
+static void UpdateCursorSO (
+EventRecord *event)
 {
   WindowPtr whichWindow;
   switch (FindWindow(event->where,&whichWindow)) {
@@ -424,9 +426,9 @@ EventRecord *event;
 * MacMessageDialog.
 ******************************************************************************/
 
-void MacMessageDialog (severityText, messageText)
-char *severityText;
-char *messageText;
+void MacMessageDialog (
+char *severityText,
+char *messageText)
 {
   DialogRecord dRecord; DialogPtr dialogP; static Rect rect0s = { 0,0,0,0 };
   WindowPtr behind = (WindowPtr) -1;
@@ -468,8 +470,8 @@ char *messageText;
 * Note that `soStatusLine' is blank padded just in case it got shorter.
 ******************************************************************************/
 
-void DrawStatusLine (text)
-char *text;
+void DrawStatusLine (
+char *text)
 {
   int i;
   MoveTo ((short) soStatusRect.left, (short) soStatusRect.top);
@@ -491,8 +493,8 @@ char *text;
 * SaveStatusLine.
 ******************************************************************************/
 
-static void SaveStatusLine (text)
-char *text;
+static void SaveStatusLine (
+char *text)
 {
   strcpyX (text, soStatusLine, SO_STATUS_LINE_LEN);
   return;
@@ -502,9 +504,9 @@ char *text;
 * FreeMacQOPs.
 ******************************************************************************/
 
-void FreeMacQOPs (argC, argV)
-int argC;
-char *argV[];
+void FreeMacQOPs (
+int argC,
+char *argV[])
 {
   int argN;
   for (argN = 0; argN < argC; argN++) cdf_FreeMemory (argV[argN], FatalError);
@@ -516,12 +518,12 @@ char *argV[];
 * CalcBounds.
 ******************************************************************************/
 
-void CalcBounds (rect, width, height, topPct, leftPct)
-Rect *rect;
-int width;
-int height;
-double topPct;
-double leftPct;
+void CalcBounds (
+Rect *rect,
+int width,
+int height,
+double topPct,
+double leftPct)
 {
   Rect screenRect = qd.screenBits.bounds;
   short screenWidth = screenRect.right - screenRect.left;
@@ -540,8 +542,8 @@ double leftPct;
 * ResetSO.
 ******************************************************************************/
 
-void ResetSO (clear)
-Logical clear;
+void ResetSO (
+Logical clear)
 {
   if (clear) {
     TEScroll ((short) 0, soAtPoint.v, soTextH);
@@ -571,7 +573,8 @@ Logical clear;
 * Currently only a vertical scroll bar is used.
 ******************************************************************************/
 
-void UpdateSOscrollBars (void) {
+void UpdateSOscrollBars (void) 
+{
   float pct = BOO(soDestHeight == 0,0.0,
 		  ((float) soAtPoint.v) / ((float) soDestHeight));
   short value = SCROLLsoMIN + (pct * (SCROLLsoMAX - SCROLLsoMIN));
@@ -584,8 +587,8 @@ void UpdateSOscrollBars (void) {
 * Returns TRUE if the standard output was successfully saved.
 ******************************************************************************/
 
-Logical SaveSO (as)
-Logical as;		/* If TRUE, prompt for file in which to save output. */
+Logical SaveSO (
+Logical as)		/* If TRUE, prompt for file in which to save output. */
 {
   Logical overWrite = FALSE;
   char errorMsg[] = "Unable to save output.";
@@ -693,10 +696,10 @@ Logical as;		/* If TRUE, prompt for file in which to save output. */
 
 #define ROOT_dirID	2
 
-Logical BuildMacPath (spec, path, stripExt)
-FSSpec *spec;			/* In: File specification from File Manager. */
-char path[DU_MAX_PATH_LEN+1];	/* Out: Full/relative path. */
-Logical stripExt;		/* In: If TRUE, strip off file extension. */
+Logical BuildMacPath (
+FSSpec *spec,			/* In: File specification from File Manager. */
+char path[DU_MAX_PATH_LEN+1],	/* Out: Full/relative path. */
+Logical stripExt)		/* In: If TRUE, strip off file extension. */
 {
   long parID = spec->parID,	/* Parent directory identifier. */
        curID;			/* Current directory identifier. */
@@ -735,7 +738,8 @@ Logical stripExt;		/* In: If TRUE, strip off file extension. */
 * DisplayAbout.
 ******************************************************************************/
 
-void DisplayAbout () {
+void DisplayAbout () 
+{
   DialogRecord dRecord;
   DialogPtr dialogP;
   WindowPtr behind = (WindowPtr) -1;
@@ -769,8 +773,8 @@ void DisplayAbout () {
 * WriteOutMacSO.
 ******************************************************************************/
 
-void WriteOutMacSO (text)
-char *text;
+void WriteOutMacSO (
+char *text)
 {
   char *ptr = text, *ptrNL; size_t len;
   /**************************************************************************
@@ -833,9 +837,9 @@ char *text;
 * ('\015' and '\012', respectively).
 ******************************************************************************/
 
-void WriteStringSO (string, length)
-char *string;
-size_t length;
+void WriteStringSO (
+char *string,
+size_t length)
 {
   int i; char *ptr;
   if (length > 0 && (*soTextH)->teLength == 0) {
@@ -860,7 +864,8 @@ size_t length;
 * MacSOoverFlow.
 ******************************************************************************/
 
-void MacSOoverFlow () {
+void MacSOoverFlow () 
+{
   DialogPtr dialog; DialogRecord dRecord;
   WindowPtr behind = (WindowPtr) -1; static Rect rect0s = { 0,0,0,0 };
   char savedStatusLine[SO_STATUS_LINE_LEN+1];
@@ -911,8 +916,8 @@ void MacSOoverFlow () {
 * `standard output' programs.
 ******************************************************************************/
 
-void MacReadKeySO (key)
-char *key;
+void MacReadKeySO (
+char *key)
 {
   EventRecord event;
   for (;;) {
@@ -970,7 +975,8 @@ char *key;
 * CheckForAbortSOmac.
 ******************************************************************************/
 
-void CheckForAbortSOmac () {
+void CheckForAbortSOmac () 
+{
   EventRecord event; clock_t currentClock, totalClock;
   int hour, minute, second; char text[SO_STATUS_LINE_LEN+1];
   SystemTask ();
@@ -1047,11 +1053,13 @@ void CheckForAbortSOmac () {
 * OutlineDefaultButton.
 ******************************************************************************/
 #ifndef __MWERKS__
-pascal void OutlineDefaultButton (window, itemN)
-DialogPtr window;
-short itemN;
+pascal void OutlineDefaultButton (
+DialogPtr window,
+short itemN)
 #else
-pascal void OutlineDefaultButton (DialogPtr window, SInt16 itemN)
+pascal void OutlineDefaultButton (
+DialogPtr window, 
+SInt16 itemN)
 #endif
 {
   short itemType; Handle handle; Rect rect;
@@ -1068,8 +1076,8 @@ pascal void OutlineDefaultButton (DialogPtr window, SInt16 itemN)
 * FilterForSKTs.
 ******************************************************************************/
 
-pascal Boolean FilterForSKTs (pb)
-ParmBlkPtr pb;
+pascal Boolean FilterForSKTs (
+ParmBlkPtr pb)
 {
   char *name = PtoCstr (pb->fileParam.ioNamePtr);
   Boolean filterOut = (!Trailer(name,".skt") && !Trailer(name,".SKT") &&
@@ -1082,8 +1090,8 @@ ParmBlkPtr pb;
 * FilterForCDFs.
 ******************************************************************************/
 
-pascal Boolean FilterForCDFs (pb)
-ParmBlkPtr pb;
+pascal Boolean FilterForCDFs (
+ParmBlkPtr pb)
 {
   char *name = PtoCstr (pb->fileParam.ioNamePtr);
   Boolean filterOut = (!Trailer(name,".cdf") && !Trailer(name,".CDF") &&
@@ -1095,13 +1103,13 @@ ParmBlkPtr pb;
 /******************************************************************************
 * FilterDialogQOPfsi.
 ******************************************************************************/
-pascal Boolean FilterDialogQOPfsi (dialog, event, itemN)
-DialogPtr dialog;
-EventRecord *event;
+pascal Boolean FilterDialogQOPfsi (
+DialogPtr dialog,
+EventRecord *event,
 #ifndef __MWERKS__
-short *itemN;
+short *itemN)
 #else
-SInt16 *itemN;
+SInt16 *itemN)
 #endif
 {
   switch (event->what) {
@@ -1130,13 +1138,13 @@ SInt16 *itemN;
 * FilterDialogQOPso.
 ******************************************************************************/
 
-pascal Boolean FilterDialogQOPso (dialog, event, itemN)
-DialogPtr dialog;
-EventRecord *event;
+pascal Boolean FilterDialogQOPso (
+DialogPtr dialog,
+EventRecord *event,
 #ifndef __MWERKS__
-short *itemN;
+short *itemN)
 #else
-SInt16 *itemN;
+SInt16 *itemN)
 #endif
 {
   switch (event->what) {
@@ -1162,9 +1170,9 @@ SInt16 *itemN;
 * FlashButton.
 ******************************************************************************/
 
-static void FlashButton (dialog, itemN)
-DialogPtr dialog;
-int itemN;
+static void FlashButton (
+DialogPtr dialog,
+int itemN)
 {
   short itemType, ovalWH = 15; Handle handle; Rect rect; GrafPtr currentPort;
   GetDItem (dialog, (short) itemN, &itemType, &handle, &rect);
@@ -1184,8 +1192,8 @@ int itemN;
 * delay.
 ******************************************************************************/
 
-static void delay (seconds)
-double seconds;
+static void delay (
+double seconds)
 {
   EventRecord event; long untilTick; short nullEventMask = 0;
   EventAvail (nullEventMask, &event);
