@@ -188,7 +188,8 @@ static char *ControlKey PROTOARGs((int, int));
 * begin_pasteboard_update.
 ******************************************************************************/
 
-int begin_pasteboard_update () {
+int begin_pasteboard_update (void) 
+{
 #if defined(SMGui)
   if (StatusBad(smg$begin_pasteboard_update(&pbid))) return FALSE;
   return TRUE;
@@ -201,19 +202,20 @@ int begin_pasteboard_update () {
   batchCount++;
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * change_rendition.
 ******************************************************************************/
 
-int change_rendition (wid, row, col, num_rows, num_cols, rendition)
-WINDOWid wid;
-int row;
-int col;
-int num_rows;
-int num_cols;
-int rendition;
+int change_rendition (
+WINDOWid wid,
+int row,
+int col,
+int num_rows,
+int num_cols,
+int rendition)
 {
 #if defined(SMGui)
   long rowN = row + 1;
@@ -224,7 +226,7 @@ int rendition;
   return TRUE;
 #endif
 #if defined(CURSESui)
-  int i,k; size_t iz;
+  int i, k; size_t iz;
   char bstring[401]; wchar_t wstring[101];
   int rend = RenditionMapping(rendition);
   for (i = 0; i < num_rows; i++) {
@@ -232,7 +234,6 @@ int rendition;
     wstring[num_cols] = L'\0';
 #if !defined(WIN32)
     k = (int) wcstombs (bstring, wstring, 400);
-/*    bstring[k] = (char) '\0'; */
 #else
     wcstombs_s (&iz, bstring, 400, wstring, 100);
 #endif
@@ -253,13 +254,15 @@ int rendition;
   if (!RefreshWINDs(UPDATE_)) return FALSE;
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * create_pasteboard.
 ******************************************************************************/
 
-int create_pasteboard () {
+int create_pasteboard (void) 
+{
 #if defined(SMGui)
   if (StatusBad(smg$create_pasteboard(&pbid,NULL,NULL,NULL,NULL,NULL))) {
     return FALSE;
@@ -335,6 +338,7 @@ int create_pasteboard () {
 #endif
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
@@ -343,12 +347,12 @@ int create_pasteboard () {
 * used.
 ******************************************************************************/
 
-int create_virtual_display (num_rows, num_cols, wid, borderMode, rendition)
-int num_rows;
-int num_cols;
-WINDOWid *wid;
-int borderMode;			/* If BORDER, draw border around display. */
-int rendition;			/* Rendition of border (if bordered). */
+int create_virtual_display (
+int num_rows,
+int num_cols,
+WINDOWid *wid,
+int borderMode,			/* If BORDER, draw border around display. */
+int rendition)			/* Rendition of border (if bordered). */
 {
 #if defined(SMGui)
   LocalId id;
@@ -392,14 +396,15 @@ int rendition;			/* Rendition of border (if bordered). */
 					    num_cols - 1, rendition);
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * delete_pasteboard.
 ******************************************************************************/
 
-int delete_pasteboard (eraseMode)
-int eraseMode;
+int delete_pasteboard (
+int eraseMode)
 {
 #if defined(SMGui)
   uLongx flags = (eraseMode == ERASE ? SMG$M_ERASE_PBD : 0);
@@ -436,14 +441,15 @@ int eraseMode;
 #endif
   return status;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * delete_virtual_display.
 ******************************************************************************/
 
-int delete_virtual_display (wid)
-WINDOWid wid;
+int delete_virtual_display (
+WINDOWid wid)
 {
   if (!DeleteWIND(wid)) return FALSE;
   return TRUE;
@@ -453,13 +459,13 @@ WINDOWid wid;
 * draw_horizontal_line.
 ******************************************************************************/
 
-int draw_horizontal_line (wid, rowN, LcolN, RcolN, rendition, teeEnds)
-WINDOWid wid;           /* Window id. */
-int rowN;               /* Row number. */
-int LcolN;              /* Left column number (start) -- numbered from zero. */
-int RcolN;              /* Right column number (stop) -- numbered from zero. */
-int rendition;          /* Rendition to use. */
-Logical teeEnds;	/* If TRUE, draw ACS_LTEE and ACS_RTEE at the ends of
+int draw_horizontal_line (
+WINDOWid wid,           /* Window id. */
+int rowN,               /* Row number. */
+int LcolN,              /* Left column number (start) -- numbered from zero. */
+int RcolN,              /* Right column number (stop) -- numbered from zero. */
+int rendition,          /* Rendition to use. */
+Logical teeEnds)	/* If TRUE, draw ACS_LTEE and ACS_RTEE at the ends of
 			   the line (ACS_HLINE is drawn at all of the other
 			   positions).  If FALSE, draw ACS_HLINE at all of the
 			   positions.  On SMG systems (VAX/VMS), this option
@@ -507,19 +513,20 @@ Logical teeEnds;	/* If TRUE, draw ACS_LTEE and ACS_RTEE at the ends of
    if (!RefreshWINDs(UPDATE_)) return FALSE;
    return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * draw_vertical_line.
 ******************************************************************************/
 
-int draw_vertical_line (wid, TrowN, BrowN, colN, rendition, teeEnds)
-WINDOWid wid;           /* Window id. */
-int TrowN;              /* Top row number (start) -- numbered from zero. */
-int BrowN;              /* Bottom row number (stop) -- numbered from zero. */
-int colN;               /* Column number -- numbered from zero. */
-int rendition;          /* Rendition to use. */
-Logical teeEnds;	/* If TRUE, draw ACS_TTEE and ACS_BTEE at the ends of
+int draw_vertical_line (
+WINDOWid wid,           /* Window id. */
+int TrowN,              /* Top row number (start) -- numbered from zero. */
+int BrowN,              /* Bottom row number (stop) -- numbered from zero. */
+int colN,               /* Column number -- numbered from zero. */
+int rendition,          /* Rendition to use. */
+Logical teeEnds)	/* If TRUE, draw ACS_TTEE and ACS_BTEE at the ends of
 			   the line (ACS_VLINE is drawn at all of the other
 			   positions).  If FALSE, draw ACS_VLINE at all of the
 			   positions.  On SMG systems (VAX/VMS), this option
@@ -567,19 +574,20 @@ Logical teeEnds;	/* If TRUE, draw ACS_TTEE and ACS_BTEE at the ends of
    if (!RefreshWINDs(UPDATE_)) return FALSE;
    return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * draw_rectangle.
 ******************************************************************************/
 
-int draw_rectangle (wid, Trow, Lcol, Brow, Rcol, rendition)
-WINDOWid wid;
-int Trow;		/* Top row number. */
-int Lcol;		/* Left column number. */
-int Brow;		/* Bottom row number. */
-int Rcol;		/* Right column number. */
-int rendition;		/* Video attributes. */
+int draw_rectangle (
+WINDOWid wid,
+int Trow,		/* Top row number. */
+int Lcol,		/* Left column number. */
+int Brow,		/* Bottom row number. */
+int Rcol,		/* Right column number. */
+int rendition)		/* Video attributes. */
 {
 #if defined(SMGui)
   long startRow = Trow + 1;
@@ -646,13 +654,14 @@ int rendition;		/* Video attributes. */
   if (!RefreshWINDs(UPDATE_)) return FALSE;
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * end_pasteboard_update.
 ******************************************************************************/
 
-int end_pasteboard_update ()
+int end_pasteboard_update (void)
 {
 #if defined(SMGui)
   if (StatusBad(smg$end_pasteboard_update(&pbid))) return FALSE;
@@ -668,6 +677,7 @@ int end_pasteboard_update ()
   if (!RefreshWINDs(UPDATE_)) return FALSE;
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
@@ -676,12 +686,12 @@ int end_pasteboard_update ()
 * positions (which is different from what SMG$ERASE_DISPLAY does on a VAX).
 ******************************************************************************/
 
-int erase_display (wid, startRow, startCol, endRow, endCol)
-WINDOWid wid;
-int startRow;
-int startCol;
-int endRow;
-int endCol;
+int erase_display (
+WINDOWid wid,
+int startRow,
+int startCol,
+int endRow,
+int endCol)
 {
 #if defined(SMGui)
   long startRowN = startRow + 1;
@@ -717,6 +727,7 @@ int endCol;
   if (!RefreshWINDs(UPDATE_)) return FALSE;
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
@@ -725,29 +736,27 @@ int endCol;
 * This is only used by CDFlist and CDFwalk (ie. expendable).
 ******************************************************************************/
 
-int input_field (wid, field, fieldRow, fieldCol, fieldLen, exitKeys, exitKey,
-		 toggleInsertModeKey, moveToSOLkey, moveToEOLkey,
-		 deleteToSOLkey, deleteToEOLkey, refreshKey)
-WINDOWid wid;
-char *field;                    /* The field may contain an initial value. */
-int fieldRow;
-int fieldCol;
-int fieldLen;                   /* Maximum length of field. */
-int *exitKeys;                  /* Keys which cause input field to be
+int input_field (
+WINDOWid wid,
+char *field,                    /* The field may contain an initial value. */
+int fieldRow,
+int fieldCol,
+int fieldLen,                   /* Maximum length of field. */
+int *exitKeys,                  /* Keys which cause input field to be
 				   exited (NUL-terminated). */
-int *exitKey;			/* Key which actually caused exit. */
-int toggleInsertModeKey;        /* Key causing insert mode to be toggled
+int *exitKey,			/* Key which actually caused exit. */
+int toggleInsertModeKey,        /* Key causing insert mode to be toggled
 				   (between insert and overstrike). */
-int moveToSOLkey;		/* Key causing cursor to move to the start
+int moveToSOLkey,		/* Key causing cursor to move to the start
 				   of the field. */
-int moveToEOLkey;		/* Key causing cursor to move to the end of
+int moveToEOLkey,		/* Key causing cursor to move to the end of
 				   the field. */
-int deleteToSOLkey;		/* Key causing the characters in front of
+int deleteToSOLkey,		/* Key causing the characters in front of
 				   the cursor to be deleted (and then the
 				   cursor/remaining characters are moved up. */
-int deleteToEOLkey;		/* Key causing the characters starting at the
+int deleteToEOLkey,		/* Key causing the characters starting at the
 				   cursor to be deleted. */
-int refreshKey;			/* Key causing the screen to be refreshed. */
+int refreshKey)			/* Key causing the screen to be refreshed. */
 {
   int curLen = UTF8StrChars (field, (int)strlen(field));
   int insertMode = FALSE;	/* Initially in insert mode. */
@@ -755,7 +764,11 @@ int refreshKey;			/* Key causing the screen to be refreshed. */
   int lastCol = fieldCol + fieldLen - 1;
   int curChar, colN, i;
   int len, width;
+#if defined(WIN32)
+  int key;
+#else
   wint_t key;
+#endif
   /****************************************************************************
   * Write current field contents and position cursor.
   ****************************************************************************/
@@ -817,7 +830,7 @@ int refreshKey;			/* Key causing the screen to be refreshed. */
      *************************************************************************/
      if (key == KB_DELETE) {
        if (curChar > 0) {
-	 int charLen; int ix, iy, total;
+	 int ix, iy, total;
 	 int charsToEnd = curLen - curChar;
          iy = (int) strlen(field);
 	 ix = UTF8StrChars (field, iy);
@@ -993,8 +1006,8 @@ int refreshKey;			/* Key causing the screen to be refreshed. */
 * inq_cursor_mode.
 ******************************************************************************/
 
-int inq_cursor_mode (cursorMode)
-int *cursorMode;
+int inq_cursor_mode (
+int *cursorMode)
 {
   *cursorMode = (cursorOn ? CURSORon : CURSORoff);
   return TRUE;
@@ -1004,10 +1017,10 @@ int *cursorMode;
 * label_border.
 ******************************************************************************/
 
-int label_border(wid, label, rendition)
-WINDOWid wid;
-char *label;
-int rendition;
+int label_border(
+WINDOWid wid,
+char *label,
+int rendition)
 {
 #if defined(SMGui)
   int len = (int) strlen(label);
@@ -1029,7 +1042,7 @@ int rendition;
 #endif
 #if defined(CURSESui)
   int len = (int) strlen (label);
-  int nRows, nCols, i, startCol;
+  int nRows, nCols, startCol;
   WindowSize (wid->id, &nRows, &nCols);
   if (!wid->bordered) return FALSE;
   if (len > nCols - 2) return FALSE;
@@ -1056,6 +1069,7 @@ int rendition;
   if (!RefreshWINDs(UPDATE_)) return FALSE;
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
@@ -1065,10 +1079,10 @@ int rendition;
 * that is being batched.
 ******************************************************************************/
 
-int paste_virtual_display (wid, row, col)
-WINDOWid wid;
-int row;
-int col;
+int paste_virtual_display (
+WINDOWid wid,
+int row,
+int col)
 {
 #if defined(SMGui)
   long rowN = row + 1;
@@ -1097,20 +1111,21 @@ int col;
   if (!RefreshWINDs(UPDATE_)) return FALSE;
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * put_chars.
 ******************************************************************************/
 
-int put_chars (wid, string, chars, row, col, eraseMode, rendition)
-WINDOWid wid;
-char *string;
-int chars;			/* The number of characters - not bytes */
-int row;
-int col;
-int eraseMode;
-int rendition;
+int put_chars (
+WINDOWid wid,
+char *string,
+int chars,			/* The number of characters - not bytes */
+int row,
+int col,
+int eraseMode,
+int rendition)
 {
 #if defined(SMGui)
   static struct dsc$descriptor_s descr = {0,DSC$K_DTYPE_T,DSC$K_CLASS_S,NULL};
@@ -1133,9 +1148,9 @@ int rendition;
   return TRUE;
 #endif
 #if defined(CURSESui)
-  /* **** Linux   ****/
+  /* **** Linux   **** */
   int nRows, nCols, colN, rend, code; size_t it;
-  int i, j, ix, iy, iz, charLen; wchar_t wch[2], blankw = L' ', *wchars;
+  int i, j, ix, iy, iz; wchar_t wch[2], blankw = L' ', *wchars;
   cchar_t onecc;
   iy = (int) strlen(string);
   ix = UTF8StrChars (string, iy);
@@ -1161,9 +1176,6 @@ int rendition;
     wch[1] = 0;
     setcchar (&onecc, wch, (chtype) rend, 0, (void *)0);
     code = mvwadd_wch (wid->id, row, col + j, &onecc);
-/*
-    j += GetWideCharWidth (wch[0]);
-*/
     j += UTF8WCharWidth (wch[0]);
   }
   free (wchars);
@@ -1194,6 +1206,7 @@ int rendition;
   if (!RefreshWINDs(UPDATE_)) return FALSE;
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
@@ -1201,10 +1214,10 @@ int rendition;
 * Use only by CDFlist and CDFwalk (ie. expendable).
 ******************************************************************************/
 
-int read_display (wid, row, string)
-WINDOWid wid;
-int row;
-char *string;
+int read_display (
+WINDOWid wid,
+int row,
+char *string)
 {
 #if defined(SMGui)
   static struct dsc$descriptor_s descr = {0,DSC$K_DTYPE_T,DSC$K_CLASS_S,NULL};
@@ -1251,6 +1264,7 @@ char *string;
   string[nChars] = NUL;
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
@@ -1269,19 +1283,15 @@ char *string;
 
 int read_input (
 #if defined(CURSESui)
-		wid,
-#endif
-		     tcode, mode, block)
-#if defined(CURSESui)
-WINDOWid wid;
+WINDOWid wid,
 #endif
 #if defined(WIN32)
-int *tcode;		/* Out: key entered. */
+int *tcode,		/* Out: key entered. */
 #else
-wint_t *tcode;		/* Out: key entered (wide character). */
+wint_t *tcode,		/* Out: key entered (wide character). */
 #endif
-int mode;		/* Case conversion mode. */
-Logical block;		/* Block until key available? */
+int mode,		/* Case conversion mode. */
+Logical block)		/* Block until key available? */
 {
 #if defined(SMGui)
   /****************************************************************************
@@ -1544,13 +1554,15 @@ Logical block;		/* Block until key available? */
   }
 #endif
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * repaint_screen.
 ******************************************************************************/
 
-int repaint_screen () {
+int repaint_screen (void) 
+{
 #if defined(SMGui)
   if (StatusBad(smg$repaint_screen(&pbid))) return FALSE;
   return TRUE;
@@ -1567,16 +1579,17 @@ int repaint_screen () {
   if (!RefreshWINDs(HARD_)) return FALSE;
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * repaste_virtual_display.
 ******************************************************************************/
 
-int repaste_virtual_display (wid, row, col)
-WINDOWid wid;
-int row;
-int col;
+int repaste_virtual_display (
+WINDOWid wid,
+int row,
+int col)
 {
 #if defined(SMGui)
   long rowN = row + 1;
@@ -1601,13 +1614,15 @@ int col;
   if (!RefreshWINDs(UPDATE_)) return FALSE;
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * ring_bell.
 ******************************************************************************/
 
-int ring_bell () {
+int ring_bell (void) 
+{
 #if defined(SMGui)
   long nRows = 1;
   long nCols = 1;
@@ -1647,6 +1662,7 @@ int ring_bell () {
 #endif
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
@@ -1658,10 +1674,10 @@ int ring_bell () {
 * screen cursor where the `top' window's virtual cursor is.
 ******************************************************************************/
 
-int set_cursor_abs (wid, row, col)
-WINDOWid wid;
-int row;
-int col;
+int set_cursor_abs (
+WINDOWid wid,
+int row,
+int col)
 {
 #if defined(SMGui)
   long rowN = row + 1;
@@ -1670,7 +1686,6 @@ int col;
   return TRUE;
 #endif
 #if defined(CURSESui)
-int ir, ic;
   wmove (wid->id, row, col);
   wrefresh (wid->id);
   return TRUE;
@@ -1706,14 +1721,15 @@ int ir, ic;
   }
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * set_cursor_mode.
 ******************************************************************************/
 
-int set_cursor_mode (cursorMode)
-int cursorMode;                         /* CURSORon/CURSORoff */
+int set_cursor_mode (
+int cursorMode)                         /* CURSORon/CURSORoff */
 {
 #if defined(SMGui)
   uLongx mode = (cursorMode == CURSORon ? SMG$M_CURSOR_ON :
@@ -1760,14 +1776,15 @@ int cursorMode;                         /* CURSORon/CURSORoff */
   }
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * unpaste_virtual_display.
 ******************************************************************************/
 
-int unpaste_virtual_display (wid)
-WINDOWid wid;
+int unpaste_virtual_display (
+WINDOWid wid)
 {
 #if defined(SMGui)
    if (StatusBad(smg$unpaste_virtual_display(&(wid->id),&pbid))) return FALSE;
@@ -1805,8 +1822,8 @@ WINDOWid wid;
 * Sleep, get it?
 ******************************************************************************/
 
-int zzzzz (seconds)
-double seconds;
+int zzzzz (
+double seconds)
 {
 #if defined(SMGui)					/* ie. VMS */
 #if defined(alphavmsI) || defined(ia64vmsI)
@@ -1865,16 +1882,17 @@ double seconds;
 #endif
   return TRUE;
 #endif
+  return FALSE;
 }
 
 /******************************************************************************
 * AddWIND.  Add a WIND to the linked list (at the end).
 ******************************************************************************/
 
-static WINDOWid AddWIND (id, pasted, bordered)
-LocalId id;
-Logical pasted;
-Logical bordered;
+static WINDOWid AddWIND (
+LocalId id,
+Logical pasted,
+Logical bordered)
 {
   WINDOWid newWIND, tW;
   newWIND = (WINDOWid) cdf_AllocateMemory ((size_t)sizeof(WIND), FatalError);
@@ -1898,8 +1916,8 @@ Logical bordered;
 * at the end of the linked list is handled (but not as a special case).
 ******************************************************************************/
 
-static Logical MoveWINDtoEnd (wid)
-WINDOWid wid;
+static Logical MoveWINDtoEnd (
+WINDOWid wid)
 {
   WINDOWid tW = WINDhead;
   WINDOWid prevW = NULL;
@@ -1929,8 +1947,8 @@ WINDOWid wid;
 * DeleteWIND.  Delete a WIND from the linked list.
 ******************************************************************************/
 
-static Logical DeleteWIND (wid)
-WINDOWid wid;
+static Logical DeleteWIND (
+WINDOWid wid)
 {
   WINDOWid tW = WINDhead;
   WINDOWid prevW = NULL;
@@ -1975,7 +1993,8 @@ WINDOWid wid;
 * DeleteWINDs.  Delete all of the WINDs.
 ******************************************************************************/
 
-static Logical DeleteWINDs () {
+static Logical DeleteWINDs (void) 
+{
   while (WINDhead != NULL) {
     if (!DeleteWIND(WINDhead)) return FALSE;
   }
@@ -1989,8 +2008,8 @@ static Logical DeleteWINDs () {
 ******************************************************************************/
 
 #if defined(CURSESui)
-static Logical RefreshWINDs (level)
-int level;
+static Logical RefreshWINDs (
+int level)
 {
   WINDOWid tW;
   switch (level) {
@@ -2014,8 +2033,8 @@ int level;
 #endif
 
 #if defined(COWui)
-static Logical RefreshWINDs (level)
-int level;
+static Logical RefreshWINDs (
+int level)
 {
   WINDOWid tW;
   char *savePtr;
@@ -2252,10 +2271,10 @@ int level;
 ******************************************************************************/
 
 #if defined(COWui)
-static Logical CharOccluded (wid, rowN, colN)
-WINDOWid wid;
-int rowN;
-int colN;
+static Logical CharOccluded (
+WINDOWid wid,
+int rowN,
+int colN)
 {
   WINDOWid tW = wid->next;
   int pbRowN = wid->id->atRowN + rowN,
@@ -2279,10 +2298,10 @@ int colN;
 
 #if defined(COWui)
 #if defined(mac)
-static void InvertCursor (wid, rowN, colN)
-WINDOWid wid;
-int rowN;
-int colN;
+static void InvertCursor (
+WINDOWid wid,
+int rowN,
+int colN)
 {
   Rect iRect;
   int startX = (FONTfsiWIDTH * (wid->id->atColN + colN)) + MARGINfsiSIZE,
@@ -2304,10 +2323,10 @@ int colN;
 ******************************************************************************/
 
 #if defined(CURSESui)
-static void WindowLocation (id, row, col)
-LocalId id;
-int *row;
-int *col;
+static void WindowLocation (
+LocalId id,
+int *row,
+int *col)
 {
 #if defined(unix) || defined(posixSHELL)
 #if GETBEGavail
@@ -2331,10 +2350,10 @@ int *col;
 ******************************************************************************/
 
 #if defined(CURSESui) || defined(SMGui)
-static void WindowSize (id, rows, cols)
-LocalId id;
-int *rows;
-int *cols;
+static void WindowSize (
+LocalId id,
+int *rows,
+int *cols)
 {
 #if defined(SMGui)
   long height = -1, width = -1;
@@ -2366,10 +2385,11 @@ int *cols;
 * NORMAL).  On IBM PCs it overrides all other renditions.
 ******************************************************************************/
 
-static int RenditionMapping (rendition)
-int rendition;
+static int RenditionMapping (
+int rendition)
 {
   int mapped;
+  mapped = 0;
 #if defined(SMGui)
   mapped = 0;
   if ((rendition & BOLD) != 0) mapped = mapped | SMG$M_BOLD;
@@ -2430,8 +2450,8 @@ int rendition;
 ******************************************************************************/
 
 #if defined(CURSESui)
-static int EraseWindow (id)
-LocalId id;
+static int EraseWindow (
+LocalId id)
 {
 #if WERASEworks
   werase (id);
@@ -2463,9 +2483,9 @@ LocalId id;
 ******************************************************************************/
 
 #if defined(mac)
-void MacExecuteFSI (exeFnc, qopFnc)
-Logical (*exeFnc) PROTOARGs((int argC, char *argV[]));
-Logical (*qopFnc) PROTOARGs((int *argC, char **argV[]));
+void MacExecuteFSI (
+Logical (*exeFnc) PROTOARGs((int argC, char *argV[])),
+Logical (*qopFnc) PROTOARGs((int *argC, char **argV[])))
 {
   int argC;
   char **argV;
@@ -2489,7 +2509,8 @@ Logical (*qopFnc) PROTOARGs((int *argC, char **argV[]));
 ******************************************************************************/
 
 #if defined(mac)
-void InitMacMenusFSI () {
+void InitMacMenusFSI (void) 
+{
   appleMenuHfsi = GetMenu (APPLEri);
   AddResMenu (appleMenuHfsi, *((long *) "DRVR"));
   InsertMenu (appleMenuHfsi, 0);
@@ -2504,7 +2525,8 @@ void InitMacMenusFSI () {
 ******************************************************************************/
 
 #if defined(mac)
-void InitMacFSI () {
+void InitMacFSI (void) 
+{
   static WindowRecord wRecord;
   WindowPtr behindWindow = (WindowPtr) -1;
   fsiWindowP = GetNewWindow (FSIri, &wRecord, behindWindow);
@@ -2569,9 +2591,9 @@ va_dcl
 * Return address of character string for key.
 ******************************************************************************/
 
-static char *KeyToken(key,maxL)
-int key;
-int maxL;
+static char *KeyToken(
+int key,
+int maxL)
 {
   switch (key) {
     case KB_a: return AlphaKey('a',maxL);
@@ -2748,9 +2770,9 @@ int maxL;
 * AlphaKey.
 ******************************************************************************/
 
-static char *AlphaKey (key, maxL)
-int key;
-int maxL;
+static char *AlphaKey (
+int key,
+int maxL)
 {
   static char token[MAX_KEY_TOKEN_LEN+1];
   switch (maxL) {
@@ -2768,9 +2790,9 @@ int maxL;
 * ControlKey.
 ******************************************************************************/
 
-static char *ControlKey (key, maxL)
-int key;
-int maxL;
+static char *ControlKey (
+int key,
+int maxL)
 {
   static char token[MAX_KEY_TOKEN_LEN+1];
   switch (maxL) {
@@ -2795,7 +2817,8 @@ int maxL;
 ******************************************************************************/
 
 #if defined(SMGui)
-void KeyWaitingAST () {
+void KeyWaitingAST (void) 
+{
   keyWaiting++;
   return;
 }
